(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1570492,      29797]*)
(*NotebookOutlinePosition[   1571171,      29821]*)
(*  CellTagsIndexPosition[   1571127,      29817]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[BoxData[
    \(Needs["\<Controls`LinearControl`\>"]\)], "Input"],

Cell[BoxData[{
    \(par[r1_, r2_] := 1\/\(1\/r1 + 1\/r2\)\), "\[IndentingNewLine]", 
    \(ser[r1_, r2_] := r1 + r2\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sol = \(Solve[{Vout \[Equal] G\ V2, 
            V2 \[Equal] \(Z3\/\(Z2 + Z3\)\) 
                V1, \((Vout - V1)\)\/Z4 + \((Vin - V1)\)\/Z1 + \((V2 - \
V1)\)\/Z2 \[Equal] 0}, 
          Vout, {V1, 
            V2}]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\)], "Input"],

Cell[BoxData[
    \({Vout \[Rule] \(-\(\(G\ Vin\ Z3\ Z4\)\/\(\(-Z1\)\ Z2 - Z1\ Z3 + 
                G\ Z1\ Z3 - Z1\ Z4 - Z2\ Z4 - Z3\ Z4\)\)\)}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(getZPK[
        f_] := \[IndentingNewLine]Block[{num, den, K0, Kinf, Q, freq, 
          sl}, \[IndentingNewLine]num = 
          Coefficient[Numerator[f], s, {0, 1, 2}]; 
        den = Coefficient[Denominator[f], 
            s, {0, 1, 2}]; \[IndentingNewLine]K0 = 
          Simplify[
            num\[LeftDoubleBracket]1\[RightDoubleBracket]/
              den\[LeftDoubleBracket]1\[RightDoubleBracket]]; 
        Kinf = Simplify[
            num\[LeftDoubleBracket]3\[RightDoubleBracket]/
              den\[LeftDoubleBracket]3\[RightDoubleBracket]]; \
\[IndentingNewLine]Print["\<K(f=0) = \>", \ K0, \ "\< (\>", 
          N[K0], "\<)\>"]; \[IndentingNewLine]Print["\<K(f=\[Infinity]) = \
\>", \ Kinf, \ "\< (\>", N[Kinf], "\<)\>"]; \[IndentingNewLine]sl = 
          Solve[Denominator[f] \[Equal] 0, 
            s]; \[IndentingNewLine]Print["\<Poles at = \>", \((\(s/2\)/\[Pi] /. 
              sl\[LeftDoubleBracket]1\[RightDoubleBracket])\), \ "\< and \>", \
\((\(s/2\)/\[Pi] /. 
              sl\[LeftDoubleBracket]2\[RightDoubleBracket])\), "\< \>"]; 
        freq = \(\@\(\((s /. sl\[LeftDoubleBracket]1\[RightDoubleBracket])\) \
\((s /. sl\[LeftDoubleBracket]2\[RightDoubleBracket])\)\)/2\)/\[Pi] // 
            PowerExpand; \[IndentingNewLine]Print["\<Pole frequency = \>", 
          freq, \ "\< (\>", 
          N[freq], "\<)\>"]; \[IndentingNewLine]Q = \(1/\((\(den\
\[LeftDoubleBracket]2\[RightDoubleBracket]/
                      den\[LeftDoubleBracket]3\[RightDoubleBracket]\)/\ \
\@\(den\[LeftDoubleBracket]1\[RightDoubleBracket]/den\[LeftDoubleBracket]3\
\[RightDoubleBracket]\))\) // Simplify\) // 
            PowerExpand; \[IndentingNewLine]Print["\<Pole Q = \>", 
          Q, \ "\< (\>", N[Q], "\<)\>"]; \[IndentingNewLine]sl = 
          Solve[Numerator[f] \[Equal] 0, 
            s]; \[IndentingNewLine]freq = \(\@\(\((s /. \
sl\[LeftDoubleBracket]1\[RightDoubleBracket])\) \((s /. \
sl\[LeftDoubleBracket]2\[RightDoubleBracket])\)\)/2\)/\[Pi] // 
            PowerExpand; \[IndentingNewLine]Print["\<Zero frequency = \>", 
          freq, "\< (\>", 
          N[freq], "\<)\>"]; \[IndentingNewLine]Q = \(1/\((\(num\
\[LeftDoubleBracket]2\[RightDoubleBracket]/
                      num\[LeftDoubleBracket]3\[RightDoubleBracket]\)/\ \
\@\(num\[LeftDoubleBracket]1\[RightDoubleBracket]/num\[LeftDoubleBracket]3\
\[RightDoubleBracket]\))\) // Simplify\) // 
            PowerExpand; \[IndentingNewLine]Print["\<Zero Q = \>", 
          Q, \ "\< (\>", N[Q], "\<)\>"];\[IndentingNewLine]]\)], "Input"],

Cell[CellGroupData[{

Cell["High Pass", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] 1\/\(s\ C\), Z2 \[Rule] 1\/\(s\ C\), 
          Z3 \[Rule] R, Z4 \[Rule] R, G \[Rule] 3 - \@2} // 
      Simplify\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {R \[Rule] 1, C \[Rule] 1/\((2  \[Pi])\), 
          s \[Rule] 2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(\((\(-3\) + \@2)\)\ C\^2\ R\^2\ s\^2\)\/\(1 + \@2\ C\ R\ s + 
            C\^2\ R\^2\ s\^2\)\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]0\[InvisibleSpace]" ("\
\[InvisibleSpace]0.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=0) = ", 0, " (", 0.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]\(3 - \@2\)\
\[InvisibleSpace]" ("\[InvisibleSpace]1.5857864376269049`\[InvisibleSpace]")"\
\),
      SequenceForm[ "K(f=\[Infinity]) = ", 
        Plus[ 3, 
          Times[ -1, 
            Power[ 2, 
              Rational[ 1, 2]]]], " (", 1.5857864376269049, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = "\[InvisibleSpace]1\/\(2\ C\ \[Pi]\ \
R\)\[InvisibleSpace]" ("\[InvisibleSpace]0.15915494309189535`\/\(C\ R\)\
\[InvisibleSpace]")"\),
      SequenceForm[ "Pole frequency = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ C, -1], 
          Power[ Pi, -1], 
          Power[ R, -1]], " (", 
        Times[ .15915494309189535, 
          Power[ C, -1], 
          Power[ R, -1]], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]1\/\@2\[InvisibleSpace]" \
("\[InvisibleSpace]0.7071067811865475`\[InvisibleSpace]")"\),
      SequenceForm[ "Pole Q = ", 
        Power[ 2, 
          Rational[ -1, 2]], " (", .70710678118654746, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]Indeterminate\
\[InvisibleSpace]" ("\[InvisibleSpace]Indeterminate\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", Indeterminate, " (", Indeterminate, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.587286 0.00762758 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .12963 -18 -4.5 ]
[-0.0125 .12963 0 4.5 ]
[-0.0125 .28218 -18 -4.5 ]
[-0.0125 .28218 0 4.5 ]
[-0.0125 .43473 -18 -4.5 ]
[-0.0125 .43473 0 4.5 ]
[-0.0125 .58729 -6 -4.5 ]
[-0.0125 .58729 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12963 m
1 .12963 L
s
0 .28218 m
1 .28218 L
s
0 .43473 m
1 .43473 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12963 m
.00625 .12963 L
s
[(-60)] -0.0125 .12963 1 0 Mshowa
0 .28218 m
.00625 .28218 L
s
[(-40)] -0.0125 .28218 1 0 Mshowa
0 .43473 m
.00625 .43473 L
s
[(-20)] -0.0125 .43473 1 0 Mshowa
0 .58729 m
.00625 .58729 L
s
[(0)] -0.0125 .58729 1 0 Mshowa
.125 Mabswid
0 .16777 m
.00375 .16777 L
s
0 .20591 m
.00375 .20591 L
s
0 .24405 m
.00375 .24405 L
s
0 .32032 m
.00375 .32032 L
s
0 .35846 m
.00375 .35846 L
s
0 .3966 m
.00375 .3966 L
s
0 .47287 m
.00375 .47287 L
s
0 .51101 m
.00375 .51101 L
s
0 .54915 m
.00375 .54915 L
s
0 .09149 m
.00375 .09149 L
s
0 .05336 m
.00375 .05336 L
s
0 .01522 m
.00375 .01522 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .00763 m
.03955 .04887 L
.06699 .08278 L
.08762 .10827 L
.1043 .12887 L
.11959 .14777 L
.1325 .16373 L
.14471 .17881 L
.15529 .19188 L
.16457 .20335 L
.17363 .21454 L
.18168 .2245 L
.1889 .23341 L
.19608 .24229 L
.20256 .2503 L
.20906 .25832 L
.21496 .26561 L
.22034 .27227 L
.22579 .279 L
.23079 .28518 L
.23585 .29143 L
.24052 .2972 L
.24482 .30252 L
.24922 .30795 L
.25309 .31273 L
s
.25309 .31273 m
.28646 .35396 L
.31391 .38785 L
.33453 .4133 L
.35121 .43385 L
.3665 .45265 L
.37942 .46847 L
.39162 .48334 L
.4022 .49614 L
.41148 .50725 L
.42054 .51798 L
.4286 .52737 L
.43581 .53562 L
.44299 .54366 L
.44948 .55072 L
.45597 .55757 L
.46187 .56356 L
.46726 .56881 L
.4727 .57389 L
.4777 .57831 L
.48277 .58254 L
.48743 .58621 L
.49174 .58938 L
.49613 .5924 L
.5 .59487 L
s
.5 .59487 m
.50873 .59983 L
.51754 .60397 L
.53337 .60945 L
.54093 .61132 L
.54845 .6128 L
.56082 .61457 L
.56654 .61517 L
.57241 .61568 L
.58233 .61633 L
.59127 .61675 L
.60001 .61705 L
.60753 .61724 L
.61412 .61737 L
.62042 .61746 L
.62689 .61754 L
.63325 .6176 L
.63897 .61765 L
.64473 .61768 L
.64969 .61771 L
.65908 .61775 L
.66792 .61777 L
.67578 .61779 L
.68356 .6178 L
.69055 .61781 L
.69687 .61781 L
.70321 .61782 L
.70898 .61782 L
.71479 .61782 L
.72011 .61782 L
.72498 .61783 L
.72993 .61783 L
.7345 .61783 L
.73871 .61783 L
.74302 .61783 L
.74691 .61783 L
s
.74691 .61783 m
.75564 .61783 L
.76446 .61783 L
.77294 .61783 L
.78029 .61783 L
.78792 .61783 L
.79443 .61783 L
.80147 .61783 L
.80773 .61783 L
.81317 .61783 L
.81864 .61783 L
.82781 .61783 L
.83674 .61783 L
.84447 .61783 L
.85243 .61783 L
.85923 .61783 L
.86578 .61783 L
.87249 .61783 L
.87899 .61783 L
.88456 .61783 L
.89502 .61783 L
.89981 .61783 L
.90476 .61783 L
.9139 .61783 L
.92201 .61783 L
.92928 .61783 L
.93651 .61783 L
.94303 .61783 L
.94956 .61783 L
.9555 .61783 L
.96091 .61783 L
.96639 .61783 L
.97141 .61783 L
.97602 .61783 L
.98073 .61783 L
.98507 .61783 L
.9895 .61783 L
.9936 .61783 L
.99383 .61783 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo0017Oooo0018000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agoo00<007oo00005goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`008Woo0017Ool00`00Ool0000GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`04001oo`0?000FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`80000300moo`0001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l00Woo00<007ooOol04Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`02Ool00`00Oomoo`0BOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?00=oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l017oo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`05Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?00Ioo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l01goo00<007ooOol03Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`07Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?00Qoo`03001oogoo00aoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l02Goo00<007ooOol02goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0:Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?00]oo`03001oogoo00Uoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol02Woo00<007ooOol027oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0<Ool00`00Oomoo`08Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?00eoo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l03Woo00<007ooOol01Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0?Ool00`00Oomoo`05Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?011oo`03001oogoo00Ao
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l04Goo00<007ooOol0
0goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0AOol00`00Oomo
o`03Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?019oo`03001o
ogoo009oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l04goo00D0
07ooOomoo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l057oo00@007ooOol0
3`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l057oo00@007ooOol03`eoo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol04goo00<007oo00l03Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0FOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Ioo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300l007oo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo00002goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol01@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000dOol4
0004Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol003=oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0G
Ool00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003=oo`03001oogoo
009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`04Ool00`00Oomo
o`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol003=oo`8000=oo`04001oogoo0004Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
02Uoo`H000Aoo`03001oo`00008000=oo`03001oogoo009oo`03001oogoo00Aoo`<002003`030000
3`0?0?l03b403`03001oogoo021oo`00<goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol01goo00D0
07ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Woo0`000goo
10001goo00<007oo00l05goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<007ooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?001oo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo00001goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01Goo00<007oo00l01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool0
0`0000moo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03001oogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00@03gooOol000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00D03gooOomoo`0000=oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol00Woo00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00Woo
00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l0
1Woo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000moo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03001oogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Ool00004Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moo`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol0
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00D03gooOomoo`00009oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00Woo00<007oo00l017oo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?001oo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00H03gooOol0
07oo00l4Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0600moogooOol0000?17oo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<007ooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?001oo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Aoo`@000Aoo`@000Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moo`00009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo00000Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?
Oomoo`00Ool03`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00<Woo1P000goo00<007ooOol00Woo00<007ooOol017oo0`00A`0?
00<0000?00l0n@0?00<007ooOol087oo000YOol60004Ool01000Oomoo`0017oo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000K
Ool4000DOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03`00Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0BOol0
0`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Ool007oo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol001Yoo`03001oogoo009oo`03001oogoo019oo`03001oo`0000Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moo`00Ool0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`006Woo00<007ooOol00Woo00<007ooOol04goo0P001Goo10001goo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOol0000?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000GOol01000Oomoo`000goo00<007oo
Ool09Woo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`00009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000GOol9000W
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00lHOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`007goo00<007ooOol09Goo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?001oo`0?67oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0800moogooOol03goo00003aQoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<007ooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol001Qoo`03001oogoo00Aoo`03001oogoo02Eoo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?001oo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`0067oo20009goo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`000goo00<007ooOol09Goo0P0000<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moo`0001Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`000goo00<007oo
Ool09Goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`0067oo00@0
07ooOol000=oo`03001oogoo02Eoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool01@0?Oomoogoo000057oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol04Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Uoo`800004Ool00000000XOol0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol0
4Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`03Ool00`00Oomo
o`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Aoo`03001o
ogoo00moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol01Goo00<0
07ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`06Ool0
0`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Io
o`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
1goo00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`08Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo00Uoo`03001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol02Woo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0:Ool00`00Oomoo`09Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo00]oo`03001oogoo00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0=Ool00`00Oomoo`06Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo00ioo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol03goo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0?Ool00`00Oomoo`04Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo011oo`03001oogoo00=oo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol04Goo00<007ooOol00Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0BOol01@00Oomoogoo00l03Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0COol01000Oomoo`0?3Goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Aoo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Goo
00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`00Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300l007oo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo00002goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol0039oo`H000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol01@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol00Woo
00<007ooOol01Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003=oo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00=oo`03001oogoo00Eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000YOol60006Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3001_
00l00`0000l03`3A00l00`00Oomoo`0POol003Ioo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00<Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`06Ool00`00Oomo
o`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<goo10001Goo10001goo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Moo`05001oogooOol0
3`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Qoo`04001oogoo00l9Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03`00
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03001o
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00@03gooOol000Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol00Woo00@007ooOol03`Eoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool00goo00<007oo00l01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00
00moo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00@03gooOol0009oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00L0
3gooOomoo`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo009oo`030000
3goo00=oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<007ooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`800003
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01P0?Oomoo`00Ool03`Aoo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00H03gooOomo
o`0000l4Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03001oogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo0080000500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000lOol40007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00H03gooOomoo`0000l3Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`05001oogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03`00001oo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol003]oo`03001oogoo009oo`03001oogoo00Aoo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`020003Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00
Oomoo`04Ool3000GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00H03gooOomoo`0?0002Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool2000GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300l0
000001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003aoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
01Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOomoo`<0015oo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol017oo0`003Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`07Ool50009Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool0000GOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol05Woo
00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00aoo`H000=oo`03001oogoo00]oo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003
Ool01@00Oomoogoo00005goo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo000ROol0
04Moo`03001oo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00
Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol04Woo90001Goo00<007ooOol00goo00D007oo
Oomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007oo
Ool0029oo`00Agooo`00B0008Woo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5o
o`00ogoo/Goo003EOol4003GOol00=Uoo`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo0031Ool3
0003Ool30003Ool50003Ool300000goo001oo`02Ool30002Ool300000goo000000050005Ool40004
Ool300000goo00000002Ool300000goo00000004Ool4002POol00<9oo`03001oogoo00=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`2MOol00<9oo`04001oogoo0002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2ROol0
0<9oo`07001oo`00Ool007oo000017oo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`H009moo`00`Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol0
0<9oo`07001oo`00Ool007oo000017oo0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Ao
o`<000Eoo`L0009oo`8000=oo`8000=oo`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P000goo0P00
:7oo00<007ooOol04Woo00<007ooOol0Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0BOol00`00
Oomoo`2WOol00>Uoo`03001oogoo01Uoo`800:Uoo`00jGoo00<007ooOol0a7oo003oOonaOol00?mo
ok5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -93.8113, \
0.0186604, 0.60406}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 1.24258 0.00345762 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .03241 -24 -4.5 ]
[-0.0125 .03241 0 4.5 ]
[-0.0125 .11885 -24 -4.5 ]
[-0.0125 .11885 0 4.5 ]
[-0.0125 .20529 -24 -4.5 ]
[-0.0125 .20529 0 4.5 ]
[-0.0125 .29173 -24 -4.5 ]
[-0.0125 .29173 0 4.5 ]
[-0.0125 .37817 -24 -4.5 ]
[-0.0125 .37817 0 4.5 ]
[-0.0125 .46461 -24 -4.5 ]
[-0.0125 .46461 0 4.5 ]
[-0.0125 .55105 -24 -4.5 ]
[-0.0125 .55105 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -20 ]
[-0.01875 .30902 -24 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .03241 m
1 .03241 L
s
0 .11885 m
1 .11885 L
s
0 .20529 m
1 .20529 L
s
0 .29173 m
1 .29173 L
s
0 .37817 m
1 .37817 L
s
0 .46461 m
1 .46461 L
s
0 .55105 m
1 .55105 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .03241 m
.00625 .03241 L
s
[(-350)] -0.0125 .03241 1 0 Mshowa
0 .11885 m
.00625 .11885 L
s
[(-325)] -0.0125 .11885 1 0 Mshowa
0 .20529 m
.00625 .20529 L
s
[(-300)] -0.0125 .20529 1 0 Mshowa
0 .29173 m
.00625 .29173 L
s
[(-275)] -0.0125 .29173 1 0 Mshowa
0 .37817 m
.00625 .37817 L
s
[(-250)] -0.0125 .37817 1 0 Mshowa
0 .46461 m
.00625 .46461 L
s
[(-225)] -0.0125 .46461 1 0 Mshowa
0 .55105 m
.00625 .55105 L
s
[(-200)] -0.0125 .55105 1 0 Mshowa
.125 Mabswid
0 .0497 m
.00375 .0497 L
s
0 .06698 m
.00375 .06698 L
s
0 .08427 m
.00375 .08427 L
s
0 .10156 m
.00375 .10156 L
s
0 .13614 m
.00375 .13614 L
s
0 .15342 m
.00375 .15342 L
s
0 .17071 m
.00375 .17071 L
s
0 .188 m
.00375 .188 L
s
0 .22258 m
.00375 .22258 L
s
0 .23986 m
.00375 .23986 L
s
0 .25715 m
.00375 .25715 L
s
0 .27444 m
.00375 .27444 L
s
0 .30902 m
.00375 .30902 L
s
0 .32631 m
.00375 .32631 L
s
0 .34359 m
.00375 .34359 L
s
0 .36088 m
.00375 .36088 L
s
0 .39546 m
.00375 .39546 L
s
0 .41275 m
.00375 .41275 L
s
0 .43003 m
.00375 .43003 L
s
0 .44732 m
.00375 .44732 L
s
0 .4819 m
.00375 .4819 L
s
0 .49919 m
.00375 .49919 L
s
0 .51647 m
.00375 .51647 L
s
0 .53376 m
.00375 .53376 L
s
0 .01512 m
.00375 .01512 L
s
0 .56834 m
.00375 .56834 L
s
0 .58563 m
.00375 .58563 L
s
0 .60291 m
.00375 .60291 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .6174 m
.03955 .61638 L
.06699 .61526 L
.08762 .61421 L
.1043 .61321 L
.11959 .61213 L
.1325 .6111 L
.14471 .61 L
.15529 .60894 L
.16457 .60792 L
.17363 .60684 L
.18168 .60579 L
.1889 .60479 L
.19608 .60372 L
.20256 .60269 L
.20906 .60159 L
.21496 .60054 L
.22034 .59952 L
.22579 .59844 L
.23079 .5974 L
.23585 .59629 L
.24052 .59522 L
.24482 .59419 L
.24922 .5931 L
.25309 .59209 L
s
.25309 .59209 m
.28646 .58172 L
.31391 .5703 L
.33453 .55944 L
.35121 .54885 L
.3665 .53741 L
.37942 .52622 L
.39162 .51411 L
.4022 .50225 L
.41148 .49064 L
.42054 .47811 L
.4286 .46587 L
.43581 .45398 L
.44299 .4412 L
.44948 .42883 L
.45597 .41566 L
.46187 .403 L
.46726 .3909 L
.4727 .37815 L
.4777 .36607 L
.48277 .35347 L
.48743 .34163 L
.49174 .33054 L
.49613 .31911 L
.5 .30902 L
s
.5 .30902 m
.53337 .22569 L
.56082 .16993 L
.58144 .13707 L
.59812 .1154 L
.61342 .09873 L
.62633 .08665 L
.63854 .07665 L
.64912 .06896 L
.65839 .06287 L
.66745 .05745 L
.67551 .05303 L
.68272 .04936 L
.68991 .04596 L
.69639 .04309 L
.70288 .04039 L
.70878 .03808 L
.71417 .03608 L
.71962 .03417 L
.72461 .0325 L
.72968 .03088 L
.73435 .02946 L
.73865 .02821 L
.74305 .02698 L
.74691 .02594 L
s
.74691 .02594 m
.78029 .01839 L
.80773 .01374 L
.82836 .01095 L
.84504 .00906 L
.86033 .00756 L
.87324 .00646 L
.88545 .00553 L
.89603 .00481 L
.90531 .00423 L
.91437 .00371 L
.92242 .00328 L
.92964 .00293 L
.93682 .0026 L
.9433 .00232 L
.9498 .00206 L
.9557 .00183 L
.96108 .00163 L
.96653 .00144 L
.97153 .00128 L
.97659 .00112 L
.98126 .00098 L
.98556 .00086 L
.98996 .00074 L
.99383 .00063 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0`000Woo0`000Woo1P00^Woo003W
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000^Woo003WOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00>Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;Yoo`00igoo1P000goo00D007ooOomoo`000;]oo`00igoo00<007ooOol00Woo00@007ooOomoo`H0
0;Yoo`00igoo00<007ooOol00Woo00<007ooOol0`Goo003VOol30002Ool30032Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000nOol40006Ool20006Ool40004Ool7000cOol40006Ool20005Ool7
0011Ool70015Ool70003Ool4000mOol70003Ool40005Ool4000GOol003eoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol0
03eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Eoo`03
001oogoo009oo`03001oogoo00]oo`<004Eoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03]oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003ioo`@000io
o`@000Moo`03001oogoo03Aoo`@0011oo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0041oo`03001oogoo00Aoo`@000Eoo`@001Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo001;Oooo0018000NOol004]oo`03001oo`0001Qoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007oo
Ool001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05OolI00000goo001oo`0MOol004]oo`03001oo`0001Qoo`03001o
ogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007ooOol0
01Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00
Ool0000@0005Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00L007ooOomoo`00Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`03Ool:0008Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0DOol70008Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0<Ool800000goo00moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`06Ool60009
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`@000Eoo`@000Eoo`@000Mo
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`03
Ool3000?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0000<0019oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00<Woo00<007ooOol01Woo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol03goo1000
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol00`00Oomoo`06Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00<0
3goo00000`000Woo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000TOol60006Ool20009Ool01@00Oomoogoo000017oo00<007ooOol017oo0`00j@0?0P00F00?00<0
07ooOol077oo000bOol00`00Oomoo`02Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Ool0000200001@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool20003Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?0000000200000`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool50004Ool40007
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool20004Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0100?Oomoogoo0P0000=oo`0?Ool00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00@03goo000000=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300l0
07oo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00=oo`8000Ioo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0400moogooOol200000goo00moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0100?Oomoo`000goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03`00000017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<007ooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01Goo0P0000<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol00goo0P000Woo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00D03gooOomoo`0000Eoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0400moogoo0006Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Ool00007Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?001oo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`00Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0;Ool00`0000moo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0:Ool00`00Ool03`09Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`09Ool01000Oomoo`0?2Goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol027oo00D007ooOomoo`0?00Uoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`@000Aoo`H000Aoo`@000Mo
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00Moo`03001oogoo009oo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`03001o
ogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol01Woo00<007ooOol00goo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00<Woo00<007ooOol00Woo00<0
07ooOol02Woo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol01Goo00<007oo
Ool017oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00<Woo00<007ooOol00goo00<007ooOol02Goo00<007ooOol017oo0`00_`0?00<0
000?00l0P@0?00<007ooOol077oo000TOol60006Ool20007Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`04Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol00`00
Oomoo`05Ool00`00Oomoo`03Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`03Ool0
0`00Oomoo`06Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo000bOol01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol027oo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol00Woo00<007ooOol01goo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Goo00<007oo
Ool00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0500moogooOol0000:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool40005Ool50006Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol01@0?Oomoogoo00002Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00@03gooOol0
00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00l007oo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`03
00003goo00eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`0300003goo00eoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aEoo`03001oo`0?00ioo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aAoo`04001oogoo00l>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lDOol01000Oomoo`0?3Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?4goo00D007ooOomoo`0?00ioo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a5oo`03
001oogoo00=oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a5oo`03001oogoo
00=oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a1oo`03001oogoo00Aoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a1oo`03001oogoo00Aoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002io
o`@000Eoo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol002eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?3Woo00<007ooOol01Woo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
<Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00l>Ool00`00Oomoo`06Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000bOol01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`<00:h03`0300003`0?09803`03001oogoo01aoo`0097oo
1P001Woo0P0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03`eoo`03001oogoo00Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0039oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?37oo00<007ooOol0
27oo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`00<Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00
Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00l<Ool00`00Oomoo`08Ool00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`@000Eoo`@0
00Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
04]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Moo`@0031oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`03001oogoo
02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03
001oogoo009oo`03001oogoo02eoo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Ioo`03001oogoo009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001o
ogoo00aoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol001=oo`04001oogoo0003Ool00`00Oomoo`0^Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l8Ool00`00Oomoo`0<Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000COol9000_Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000KOol00`00Oomoo`0]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l6Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l6
Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l6Ool00`00
Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l5Ool00`00
Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00l5Ool00`00Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool0
0`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00l4Ool00`00Oomoo`0@Ool00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l4Ool00`00Oomoo`0@
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool3000HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l3
Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol200000goo001oo`0_Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00l3Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool60006Ool00`00Oomoo`04
Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00l3Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00l2Ool00`00Oomoo`0BOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000C
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l2Ool0
0`00Oomoo`0BOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02Ool01000Oomoo`0047oo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol017oo0`00XP0?00<0000?00l0WP0?00<007ooOol0
77oo000FOol00`00Oomoo`02Ool01000Oomoo`001Goo1P001Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01P0?Oomoo`0?Ool001Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Io
o`03001oogoo009oo`04001oogoo000BOol00`00Oomoo`06Ool00`00Oomoo`03Ool40007Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0600moogoo00moo`005Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo00@007ooOol000=oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Qoo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOol03`0001Ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`P000moo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo00l0000F
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000FOol00`00Oomoo`0EOol40004Ool60004Ool50006Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol6000_Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
o`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000GOol01@00Oomoogoo0000;goo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?001o
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol00Woo00<007ooOol0;Goo0`0067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?001o
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?001oo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol0<Woo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0000moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@00
00moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo1000<7oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0000moogoo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`00
Ool03`02Ool00`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomo
o`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?009oo`03001oo`0?009oo`0300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03
001oo`00009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo00l00Woo00<03gooOol05Goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0700moogooOol03goo00000Woo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol001Moo`800003Ool007oo02moo`<001Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01`0?Oomoogoo00moo`00009oo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00H03gooOomoo`0?0003Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
;Goo1P0017oo10001Goo10001goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0600moogooOol03`000goo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
02eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol017oo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool00004Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo10004goo00<007ooOol02Woo
00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo000017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Ioo`03001oo`00009oo`03001oogoo015oo`03001oogoo00Uoo`05001oogooOol00004
Ool00`00Oomoo`04Ool3002G00l00`0000l03`2Y00l00`00Oomoo`0LOol001Ioo`03001oo`00009o
o`03001oogoo00Ioo`H000Ioo`03001oogoo00Qoo`05001oogooOol00004Ool00`00Oomoo`04Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0
000?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomo
o`0COol00`00Oomoo`03Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol200000goo001oo`0AOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool50004Ool40007Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<0000?Ool00Woo00<03gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`00
00moo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700moogooOol007oo00l00goo00<03gooOol00Woo
00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0300moogoo009oo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00@03gooOol0009oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0400moogoo0002Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00003Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Ool00003Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`00Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0000moo`04Ool01@0?Oomoogoo00l017oo
00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?
Oomoogoo001oo`0?00Eoo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo00l01Goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool60003Ool60004Ool40007
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03goo00000goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000^Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03goo00000goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000_Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03`00Ool00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000TOol6
0006Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`04Ool3002900l00`0000l03`2g00l0
0`00Oomoo`0LOol0035oo`03001oogoo00Ioo`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol002eoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool017oo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol027oo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Woo10001Goo10001Goo1@001Woo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo009oo`04
001oogoo00l5Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0400moogoo0004Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3
000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo009oo`03001o
ogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03goo00001goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo0P0027oo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool60004
Ool40005Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`07Ool20002
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`03001oogoo00Eoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000_Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`0097oo1P001Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`<006h03`800=<03`03001oogoo01aoo`00<Goo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol002eoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo008000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00;Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
00002goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000^Ool40005Ool40005Ool40007
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo0P0037oo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol04goo0P0000<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol047oo0`000Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Woo0P00
1Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol037oo0P001goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo0P002Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol01goo0`002goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
0goo10003Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo00000`004Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo0`005Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoogoo0`0000=o
o`0?Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool0100?Oomoogoo1@0000D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol01P0000=oo`0?Ool00Woo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol01P000Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03goo000020000goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
00<007oo00l067oo00<03gooOol02goo00<03`0000002@001Woo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00005goo40002Goo00<007ooOol0
1Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001o
ogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001o
ogoo00=oo`05001oogooOol00004Ool01000Oomoo`005goo00<007ooOol037oo00<007ooOol01goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo
00=oo`03001oogoo00=oo`05001oogooOol00003Ool01`00Oomoogoo001oo`0001ioo`00Bgoo00<0
07oo00005`0000=oo`00Ool037oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]o
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol0
0004Ool01000Oomoo`005goo00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05
001oogooOol00003Ool01`00Oomoogoo001oo`0001ioo`00Bgooo`00B0007Woo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo
003IOol50004Ool30002Ool30003Ool50003Ool50005Ool4002]Ool00=Yoo`03001oogoo00Ioo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol0ZWoo003JOol00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00<007ooOol01goo00D007ooOomoo`000;5oo`00fWoo1@0017oo00<007ooOol00Woo00<007oo
Ool00Woo10001Goo100017oo1P00[7oo003JOol00`00Oomoo`02Ool01000Oomoogoo0P000goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`2ZOol00=Yoo`03001oogoo009oo`06001oogooOol007oo0`001Goo0`001Woo1@0017oo1000[Goo
003JOol00`00Oomoo`02Ool01@00Oomoogoo0000c7oo003IOol60004Ool00`00Oomoo`3:Ool00>9o
o`800<aoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.96984, -396.471, \
0.0186604, 1.33257}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Low Pass", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] R, Z2 \[Rule] R, 
          Z3 \[Rule] 1\/\(s\ C\), Z4 \[Rule] 1\/\(s\ C\), G \[Rule] 3 - \@2} // 
      Simplify\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {R \[Rule] 1, C \[Rule] 1/\((2  \[Pi])\), 
          s \[Rule] 2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\(3 - \@2\)\/\(1 + \@2\ C\ R\ s + C\^2\ R\^2\ s\^2\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]\(3 - \@2\)\
\[InvisibleSpace]" ("\[InvisibleSpace]1.5857864376269049`\[InvisibleSpace]")"\
\),
      SequenceForm[ "K(f=0) = ", 
        Plus[ 3, 
          Times[ -1, 
            Power[ 2, 
              Rational[ 1, 2]]]], " (", 1.5857864376269049, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]0\
\[InvisibleSpace]" ("\[InvisibleSpace]0.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=\[Infinity]) = ", 0, " (", 0.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = "\[InvisibleSpace]1\/\(2\ C\ \[Pi]\ \
R\)\[InvisibleSpace]" ("\[InvisibleSpace]0.15915494309189535`\/\(C\ R\)\
\[InvisibleSpace]")"\),
      SequenceForm[ "Pole frequency = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ C, -1], 
          Power[ Pi, -1], 
          Power[ R, -1]], " (", 
        Times[ .15915494309189535, 
          Power[ C, -1], 
          Power[ R, -1]], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]1\/\@2\[InvisibleSpace]" \
("\[InvisibleSpace]0.7071067811865475`\[InvisibleSpace]")"\),
      SequenceForm[ "Pole Q = ", 
        Power[ 2, 
          Rational[ -1, 2]], " (", .70710678118654746, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = "\[InvisibleSpace]\(\@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]1\[RightDoubleBracket]\)\ \@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]2\[RightDoubleBracket]\)\)\/\(2\ \
\[Pi]\)\[InvisibleSpace]" ("\[InvisibleSpace]\(0.15915494309189535`\ \@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]1\[RightDoubleBracket]\)\ \@\(s \
/. \[InvisibleSpace]{}\[LeftDoubleBracket]2\[RightDoubleBracket]\)\)\
\[InvisibleSpace]")"\),
      SequenceForm[ "Zero frequency = ", 
        Times[ 
          Rational[ 1, 2], 
          Power[ Pi, -1], 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 1]], 
            Rational[ 1, 2]], 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 2]], 
            Rational[ 1, 2]]], " (", 
        Times[ .15915494309189535, 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 1]], 
            Rational[ 1, 2]], 
          Power[ 
            ReplaceAll[ s, 
              Part[ {}, 2]], 
            Rational[ 1, 2]]], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]Indeterminate\
\[InvisibleSpace]" ("\[InvisibleSpace]Indeterminate\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", Indeterminate, " (", Indeterminate, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.586934 0.00762301 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .12955 -18 -4.5 ]
[-0.0125 .12955 0 4.5 ]
[-0.0125 .28201 -18 -4.5 ]
[-0.0125 .28201 0 4.5 ]
[-0.0125 .43447 -18 -4.5 ]
[-0.0125 .43447 0 4.5 ]
[-0.0125 .58693 -6 -4.5 ]
[-0.0125 .58693 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12955 m
1 .12955 L
s
0 .28201 m
1 .28201 L
s
0 .43447 m
1 .43447 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12955 m
.00625 .12955 L
s
[(-60)] -0.0125 .12955 1 0 Mshowa
0 .28201 m
.00625 .28201 L
s
[(-40)] -0.0125 .28201 1 0 Mshowa
0 .43447 m
.00625 .43447 L
s
[(-20)] -0.0125 .43447 1 0 Mshowa
0 .58693 m
.00625 .58693 L
s
[(0)] -0.0125 .58693 1 0 Mshowa
.125 Mabswid
0 .16767 m
.00375 .16767 L
s
0 .20578 m
.00375 .20578 L
s
0 .2439 m
.00375 .2439 L
s
0 .32013 m
.00375 .32013 L
s
0 .35824 m
.00375 .35824 L
s
0 .39636 m
.00375 .39636 L
s
0 .47259 m
.00375 .47259 L
s
0 .5107 m
.00375 .5107 L
s
0 .54882 m
.00375 .54882 L
s
0 .09144 m
.00375 .09144 L
s
0 .05332 m
.00375 .05332 L
s
0 .01521 m
.00375 .01521 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .61746 m
.0149 .61746 L
.02372 .61746 L
.0322 .61746 L
.03955 .61746 L
.04718 .61746 L
.05368 .61746 L
.06073 .61746 L
.06699 .61746 L
.07242 .61746 L
.0779 .61746 L
.08707 .61746 L
.096 .61746 L
.10373 .61746 L
.11169 .61746 L
.11849 .61746 L
.12503 .61746 L
.13175 .61746 L
.13776 .61746 L
.14382 .61746 L
.14928 .61746 L
.1549 .61746 L
.16459 .61746 L
.17368 .61746 L
.18176 .61746 L
.18899 .61746 L
.19619 .61746 L
.20269 .61746 L
.2092 .61746 L
.21511 .61746 L
.22051 .61746 L
.22597 .61746 L
.23097 .61746 L
.23557 .61746 L
.24026 .61746 L
.24459 .61746 L
.24901 .61746 L
.25309 .61746 L
s
.25309 .61746 m
.26182 .61746 L
.27063 .61746 L
.27912 .61745 L
.28646 .61745 L
.2941 .61745 L
.3006 .61744 L
.30765 .61744 L
.31391 .61743 L
.31934 .61742 L
.32481 .61742 L
.33398 .6174 L
.34291 .61737 L
.35065 .61734 L
.35861 .61729 L
.3654 .61725 L
.37195 .61719 L
.37867 .61711 L
.38467 .61702 L
.39073 .61691 L
.3962 .61678 L
.40181 .61662 L
.4115 .61627 L
.42059 .61579 L
.42867 .61523 L
.4359 .61456 L
.4431 .61372 L
.44961 .61276 L
.45611 .61158 L
.46202 .61027 L
.46742 .60886 L
.47288 .6072 L
.47788 .60543 L
.48249 .60359 L
.48718 .6015 L
.49151 .59935 L
.49593 .59693 L
.5 .59452 L
s
.5 .59452 m
.53337 .56787 L
.56082 .5391 L
.58144 .51534 L
.59812 .49545 L
.61342 .47692 L
.62633 .46116 L
.63854 .44619 L
.64912 .43319 L
.65839 .42177 L
.66745 .41061 L
.67551 .40067 L
.68272 .39178 L
.68991 .38292 L
.69639 .37491 L
.70288 .3669 L
.70878 .35962 L
.71417 .35297 L
.71962 .34624 L
.72461 .34007 L
.72968 .33382 L
.73435 .32806 L
.73865 .32274 L
.74305 .31731 L
.74691 .31254 L
s
.74691 .31254 m
.78029 .27133 L
.80773 .23743 L
.82836 .21196 L
.84504 .19137 L
.86033 .17248 L
.87324 .15653 L
.88545 .14146 L
.89603 .1284 L
.90531 .11694 L
.91437 .10575 L
.92242 .0958 L
.92964 .08689 L
.93682 .07802 L
.9433 .07001 L
.9498 .062 L
.9557 .05471 L
.96108 .04806 L
.96653 .04133 L
.97153 .03516 L
.97659 .0289 L
.98126 .02314 L
.98556 .01783 L
.98996 .0124 L
.99383 .00762 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo0017Oooo0018000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agoo00<007oo00005goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo
00Qoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00002Ool01000Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
001oogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000l2Ool00`00Oomo
o`0POol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00l2Ool00`00Oomoo`0P
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00l2Ool00`00Oomoo`0POol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogoo00003`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3goo001oo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500l007ooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool01P0?Oomoogoo00003`=oo`0400moogoo00l2Ool00`00Oomoo`0POol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?
Oomoogoo00003`=oo`0400moogoo00l2Ool00`00Oomoo`0POol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool0
3`=oo`0400moogoo00l2Ool00`00Oomoo`0POol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Ool00002Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<007ooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
1P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00H03gooOomoo`0000l4Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0600moogoo001oo`0?17oo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Ool00002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00l007oo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<007ooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`00Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300003goo00=oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol00Woo00<007oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0500moogooOol00002
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0400moogoo0003Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moo`0000Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`03001oogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol00goo00<0000?
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`02Ool00`00Ool03`06Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0500moogooOol00002Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0400moogoo0003Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo100017oo10001goo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moo`0000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol00`00Oomoo`02Ool01000Oomo
o`0017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300l007oo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000cOol00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300l007oo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol20003Ool01000Oomoo`0017oo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03001oogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000YOol60004
Ool00`00Ool000020003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3003o00lQ00l00`0000l03`0P
00l00`00Oomoo`0POol003=oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`00Ool03`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=7oo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Eoo`04001oogoo00l6
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Aoo`05001oogooOol03`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Woo0`000goo10001goo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00=oo`03001oogoo009oo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol00Woo00<007ooOol00goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`03Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0500moogooOol00006Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0400moogoo0007Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moo`0000Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo0000
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?001oo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03001oogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<007ooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0:Ool00`0000moo`09Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00Uoo`03001oo`0?00Yoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol027oo00@007oo
Ool03`Yoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Yo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Yoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Aoo`03001oogoo00Aoo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00goo00<007ooOol01Goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo009oo`03001oogoo00Ioo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00D03gooOomoo`0000Uoo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00@03gooOol000Yoo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03goo00002goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?001oo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300l007oo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<007ooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0FOol00`0000moo`0<Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`03001oo`0?00eoo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05Goo00<007oo00l03Goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0DOol01000Oomoo`0?3Goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0C
Ool01@00Oomoogoo00l03Goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0BOol00`00
Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?015o
o`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
4Goo00<007ooOol00goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0@Ool00`00Oomoo`04Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?00moo`03001oogoo00Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l03Woo00<007ooOol01Woo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0=Ool00`00Oomoo`07Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?00aoo`03001oogoo00Qoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l037oo00<007ooOol027oo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0;Ool00`00Oomoo`09Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00=7oo100017oo10001goo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?00Yoo`03001oogoo00Yoo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l02Goo00<007ooOol02goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool003Ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`08Ool00`00Oomoo`0<Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo1P000goo00<007ooOol0
0Woo00<007ooOol017oo0`00n00?00<0000?00l0B00?00<007ooOol087oo000YOol60004Ool01000
Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Moo`03001oogoo00eoo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000KOol4000DOol01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?00Ioo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Ool00004Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l01Goo00<007ooOol03goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Yoo`03001oogoo009oo`03001oogoo019oo`03001oo`0000Aoo`03
001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`04Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`006Woo00<007ooOol00Woo00<007ooOol04goo0P001Goo10001goo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
00=oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000G
Ool01000Oomoo`000goo00<007ooOol09Woo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`03001oogoo019oo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000GOol9000WOol00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<007ooOol04Woo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001moo`03001oogoo02Eoo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00005Goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogooOol03`005Woo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol0000GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`0067oo00<007ooOol017oo00<007ooOol09Goo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOol0000?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000HOol8000WOol00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoo`0000l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol2
00000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?000007oo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04001oogoo
0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@00Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@00Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Qoo`04001oogoo0003Ool00`00Oomoo`0UOol00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`0000moo`02Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Goo0P0000Aoo`00000002Qo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009oo`0300003goo009o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0900moogooOol03goo001oo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0600moogooOol03`000Woo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol00003Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOol0000?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Ool007oo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500l007ooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@00Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300003goo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0000moo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00L03gooOomoo`00Ool03`03Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@0
3gooOol0009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo00000goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<007ooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0000moo`04Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo
00l01Goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03`00Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300003goo00Aoo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
1@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo1P00
17oo10001goo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00<Woo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo00001Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00<goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000dOol00`00
Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol002Uoo`H000Ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00Aoo`<00<l03`0300003`0?07403`03001oogoo021oo`00=Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
000bOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000bOol00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
000cOol40005Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Aoo`04001oogoo00l7Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00=oo`05001oogooOol03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo009oo`03
001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00Woo
00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool01@0?Oomoogoo
00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Ool00007Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Yoo`03
00003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02Goo00<007oo00l02Goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08Ool01000Oomoo`0?2Goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol017oo00<007ooOol017oo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00D03gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00@03gooOol000Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03goo00002goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?001o
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03001oogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<007ooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
4Woo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04Woo00@007oo
Ool03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400mo
ogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04Goo00D007ooOomoo`0?00eo
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol047oo00<007ooOol00Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`03001oogoo00Aoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Goo00<007ooOol01Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0<Ool00`00Oomoo`06
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00]oo`03001oogoo
00Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007oo
Ool027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`09Ool00`00
Oomoo`09Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Qoo`03
001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01goo
00<007ooOol02goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`05
Ool2000>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo000lOol40007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
00Aoo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol003]oo`03001oogoo009oo`03001oogoo00Aoo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol03goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00>goo
00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`02Ool00`00
Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04Ool3000GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0500moogooOol0000COol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moo`00000DOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300l007oo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool003]oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<007ooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0600moogooOol0
3goo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00?7oo10001goo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogooOol20002
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03`000000000?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool0100?Oomoogoo0P000goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`0600000goo
00moo`02Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00005goo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo00Moo`03
001oogoo00Eoo`03001oogoo00H0009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomo
o`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol0
0002Ool01000Oomoo`008Woo0017Ool00`00Ool0002;0003Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000G
Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agooo`00B0008Woo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003EOol4003GOol00=Uo
o`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo0031Ool30003Ool30003Ool50003Ool300000goo
001oo`02Ool30002Ool300000goo000000050005Ool40004Ool300000goo00000002Ool300000goo
00000004Ool4002POol00<9oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo0000
0goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00@0
07ooOol000=oo`80009oo`04001oogooOol20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol00<9o
o`04001oogoo0002Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2ROol00<9oo`07001oo`00Ool007oo000017oo
10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`H009mo
o`00`Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`80
00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo
0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol00<9oo`07001oo`00Ool007oo000017oo
0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Aoo`<000Eoo`L0009oo`8000=oo`8000=o
o`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P000goo0P00:7oo00<007ooOol04Woo00<007ooOol0
Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0BOol00`00Oomoo`2WOol00>Uoo`03001oogoo01Uo
o`800:Uoo`00jGoo00<007ooOol0a7oo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -93.8213, \
0.0186604, 0.604422}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.610378 0.00340285 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .01488 -24 -4.5 ]
[-0.0125 .01488 0 4.5 ]
[-0.0125 .09995 -24 -4.5 ]
[-0.0125 .09995 0 4.5 ]
[-0.0125 .18502 -24 -4.5 ]
[-0.0125 .18502 0 4.5 ]
[-0.0125 .27009 -24 -4.5 ]
[-0.0125 .27009 0 4.5 ]
[-0.0125 .35516 -18 -4.5 ]
[-0.0125 .35516 0 4.5 ]
[-0.0125 .44024 -18 -4.5 ]
[-0.0125 .44024 0 4.5 ]
[-0.0125 .52531 -18 -4.5 ]
[-0.0125 .52531 0 4.5 ]
[-0.0125 .61038 -6 -4.5 ]
[-0.0125 .61038 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -20 ]
[-0.01875 .30902 -24 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .09995 m
1 .09995 L
s
0 .18502 m
1 .18502 L
s
0 .27009 m
1 .27009 L
s
0 .35516 m
1 .35516 L
s
0 .44024 m
1 .44024 L
s
0 .52531 m
1 .52531 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01488 m
.00625 .01488 L
s
[(-175)] -0.0125 .01488 1 0 Mshowa
0 .09995 m
.00625 .09995 L
s
[(-150)] -0.0125 .09995 1 0 Mshowa
0 .18502 m
.00625 .18502 L
s
[(-125)] -0.0125 .18502 1 0 Mshowa
0 .27009 m
.00625 .27009 L
s
[(-100)] -0.0125 .27009 1 0 Mshowa
0 .35516 m
.00625 .35516 L
s
[(-75)] -0.0125 .35516 1 0 Mshowa
0 .44024 m
.00625 .44024 L
s
[(-50)] -0.0125 .44024 1 0 Mshowa
0 .52531 m
.00625 .52531 L
s
[(-25)] -0.0125 .52531 1 0 Mshowa
0 .61038 m
.00625 .61038 L
s
[(0)] -0.0125 .61038 1 0 Mshowa
.125 Mabswid
0 .03189 m
.00375 .03189 L
s
0 .04891 m
.00375 .04891 L
s
0 .06592 m
.00375 .06592 L
s
0 .08294 m
.00375 .08294 L
s
0 .11696 m
.00375 .11696 L
s
0 .13398 m
.00375 .13398 L
s
0 .15099 m
.00375 .15099 L
s
0 .16801 m
.00375 .16801 L
s
0 .20204 m
.00375 .20204 L
s
0 .21905 m
.00375 .21905 L
s
0 .23606 m
.00375 .23606 L
s
0 .25308 m
.00375 .25308 L
s
0 .28711 m
.00375 .28711 L
s
0 .30412 m
.00375 .30412 L
s
0 .32114 m
.00375 .32114 L
s
0 .33815 m
.00375 .33815 L
s
0 .37218 m
.00375 .37218 L
s
0 .38919 m
.00375 .38919 L
s
0 .40621 m
.00375 .40621 L
s
0 .42322 m
.00375 .42322 L
s
0 .45725 m
.00375 .45725 L
s
0 .47426 m
.00375 .47426 L
s
0 .49128 m
.00375 .49128 L
s
0 .50829 m
.00375 .50829 L
s
0 .54232 m
.00375 .54232 L
s
0 .55933 m
.00375 .55933 L
s
0 .57635 m
.00375 .57635 L
s
0 .59336 m
.00375 .59336 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .60762 m
.03955 .60661 L
.06699 .60552 L
.08762 .60448 L
.1043 .60349 L
.11959 .60244 L
.1325 .60142 L
.14471 .60034 L
.15529 .5993 L
.16457 .59829 L
.17363 .59723 L
.18168 .5962 L
.1889 .59521 L
.19608 .59416 L
.20256 .59314 L
.20906 .59206 L
.21496 .59102 L
.22034 .59002 L
.22579 .58896 L
.23079 .58793 L
.23585 .58684 L
.24052 .58579 L
.24482 .58478 L
.24922 .5837 L
.25309 .58271 L
s
.25309 .58271 m
.28646 .57251 L
.31391 .56126 L
.33453 .55058 L
.35121 .54016 L
.3665 .5289 L
.37942 .51788 L
.39162 .50597 L
.4022 .49429 L
.41148 .48287 L
.42054 .47054 L
.4286 .45849 L
.43581 .44679 L
.44299 .43421 L
.44948 .42204 L
.45597 .40908 L
.46187 .39662 L
.46726 .38471 L
.4727 .37216 L
.4777 .36027 L
.48277 .34787 L
.48743 .33622 L
.49174 .32531 L
.49613 .31406 L
.5 .30412 L
s
.5 .30412 m
.53337 .22212 L
.56082 .16724 L
.58144 .1349 L
.59812 .11357 L
.61342 .09716 L
.62633 .08527 L
.63854 .07543 L
.64912 .06787 L
.65839 .06187 L
.66745 .05654 L
.67551 .05219 L
.68272 .04858 L
.68991 .04523 L
.69639 .0424 L
.70288 .03975 L
.70878 .03748 L
.71417 .03551 L
.71962 .03363 L
.72461 .03198 L
.72968 .03039 L
.73435 .029 L
.73865 .02776 L
.74305 .02655 L
.74691 .02553 L
s
.74691 .02553 m
.78029 .0181 L
.80773 .01352 L
.82836 .01078 L
.84504 .00891 L
.86033 .00744 L
.87324 .00636 L
.88545 .00544 L
.89603 .00473 L
.90531 .00416 L
.91437 .00365 L
.92242 .00323 L
.92964 .00288 L
.93682 .00256 L
.9433 .00228 L
.9498 .00202 L
.9557 .0018 L
.96108 .00161 L
.96653 .00142 L
.97153 .00126 L
.97659 .0011 L
.98126 .00097 L
.98556 .00084 L
.98996 .00072 L
.99383 .00062 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0`000Woo0`000Woo1P00^Woo003W
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000^Woo003WOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00>Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;Yoo`00igoo1P000goo00D007ooOomoo`000;]oo`00igoo00<007ooOol00Woo00@007ooOomoo`H0
0;Yoo`00igoo00<007ooOol00Woo00<007ooOol0`Goo003VOol30002Ool30032Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000nOol40006Ool20006Ool40004Ool7000cOol40006Ool20005Ool7
0011Ool70015Ool70003Ool4000mOol70003Ool40005Ool4000GOol003eoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol0
03eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Eoo`03
001oogoo009oo`03001oogoo00]oo`<004Eoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03]oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003ioo`@000io
o`@000Moo`03001oogoo03Aoo`@0011oo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0041oo`03001oogoo00Aoo`@000Eoo`@001Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo001;Oooo0018000NOol004]oo`03001oo`0001Qoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007oo
Ool001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05OolI00000goo001oo`0MOol002eoo`L000Eoo`03001oogoo00Ao
o`@000Moo`03001oo`0001Qoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool0
1@00Oomoogoo000017oo00@007ooOol001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00
Oomoo`0EOol00`00Oomoo`0;Ool00`00Ool0000@0005Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo00L007ooOomoo`00Ool0000NOol0031oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool:0008Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0DOol70008Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
031oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Aoo`<001Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0<Ool800000goo00moo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol002Aoo`H000Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Ao
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`06
Ool60009Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00Mo
o`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`03Ool3000?Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool0031oo`03001oogoo00Qoo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool00003000BOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol002ioo`<000Eoo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Qoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`05000F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`H000Ao
o`D000Ioo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0300moo`00008000=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00@03gooOomoo`<0009oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0600moo`00001oo`0?0goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol010000goo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03`0000000Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol00goo0P0017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol00`0000=oo`0?Ool00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03`00000017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
07ooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol00goo00<0000?Ool01Goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00@03gooOomoo`800003Ool03goo00Eoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0400moo`00
0003Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool20005Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`06Ool00`0000moo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`04Ool200000goo00moo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01Woo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool00P001Goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo00001goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00;Goo1`000goo10001Goo
10001goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03`00Ool01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00<7oo00<007ooOol00goo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`03001oogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L0
3gooOomoo`0?Ool0000NOol0031oo`03001oogoo00Qoo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0;Ool00`0000moo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`08Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol02Woo00<0
07oo00l02Goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`0097oo1P001Woo00<007ooOol027oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`<00<@03`03
00003`0?07`03`03001oogoo01aoo`00<7oo00<007ooOol017oo100017oo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol027oo00D007ooOomoo`0?00Uoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00Moo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002ioo`<000Ioo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Ioo`03001oogoo
00=oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol0031oo`03001oogoo00Aoo`D000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00Eoo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Aoo`03
001oogoo00Eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Aoo`03001oogoo
00Eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00=oo`03001oogoo00Ioo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo009oo`03001oogoo00Moo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0500moogooOol0000:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol01@0?Oomoogoo00002Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00@03gooOol000]o
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00@03gooOol03aMoo`0300moo`0000aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300l0
07oo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`03001oogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`030000
3goo00eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aIoo`0300003goo00eoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aEoo`03001oo`0?00ioo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aAo
o`04001oogoo00l>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lDOol01000Oomoo`0?3Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?4goo00D007ooOomoo`0?00ioo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`L0009oo`H000Aoo`@000Moo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo
00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lAOol00`00Oomoo`03Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`04Ool00`00Oomoo`0:
Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lAOol00`00Oomoo`03Ool00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000`Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00l@Ool00`00Oomoo`04Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000TOol60006Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool3002a00l00`0000l03`2?00l00`00Oomoo`0LOol0031oo`03001o
ogoo00Moo`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Qoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`moo`03001oogoo00Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002io
o`<000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3`ioo`03001oogoo00Ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00Aoo`@000Eoo`D000Io
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`ioo`03001oogoo00Ioo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03`eoo`03001oogoo00Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3`eoo`03001oogoo00Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`aoo`03
001oogoo00Qoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`aoo`03001oogoo
00Qoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Moo`@0031oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03`Uoo`03001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`03001o
ogoo02eoo`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001o
ogoo009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol001Ioo`03001oogoo009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Moo`03
001oogoo00eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol001=oo`04001oogoo0003Ool00`00Oomoo`0^Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000COol9000_Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l7Ool00`00Oomoo`0=Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000KOol00`00Oomoo`0]
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00l6Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00l6Ool00`00Oomoo`0>Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00l5Ool00`00Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000]Ool70003Ool40005Ool40007Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l5Ool00`00Oomoo`0?Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000EOol00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?17oo00<007ooOol047oo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007oo
Ool04Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`Aoo`03001oogoo011oo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00
009oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`04Ool3002U00l00`0000l03`2K00l00`00Oomoo`0LOol001Ioo`03001oo`00009oo`03001o
ogoo00Ioo`H000Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0400moogoo00l3Ool00`00Oomoo`0AOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol0
0`00Ool00002Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?0goo00<007ooOol04Goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`005goo0P0000=oo`00Ool057oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`9oo`03001oogoo019oo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol002ioo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00l2Ool00`00Oomoo`0BOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`04
Ool40005Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00l2Ool00`00Oomoo`0BOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000GOol4000`Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0600moogoo00moo`005Goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo
Ool00Woo00@007ooOol002aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00H03gooOol03goo000EOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000FOol00`00Oomoo`02Ool01000Oomoo`00;7oo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoo`0?00005Woo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`005Woo00<007ooOol00Woo00@007ooOol002aoo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOol03`00
01Ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol001Moo`04001oogoo0003Ool00`00Oomoo`0ZOol00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol8000]Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo000FOol00`00Oomoo`0bOol00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moo`0000lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moo`0000lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moo`0000lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo000FOol6000_Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400l007oo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000G
Ool01@00Oomoogoo0000;goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?001oo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo
00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`005Woo00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`005Woo00<007ooOol0<Woo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0000moogoo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0000moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@00
00moogoo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`00Ool03`02Ool00`0?Oomo
o`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000GOol4000NOol00`00Oomoo`04Ool40007Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009oo`03
001oo`0?009oo`0300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001o
ogoo01]oo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo00l0
0Woo00<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol06goo
00<007ooOol027oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0700moogooOol03goo00000Woo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Ioo`03001oo`00009oo`03001oogoo01aoo`03001oogoo00Moo`03001oogoo00Aoo`<0
09X03`0300003`0?0:H03`03001oogoo01aoo`005Woo00<007oo00000Woo00<007ooOol03goo1P00
1goo00<007ooOol01goo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0600moogooOol03`000goo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol001Moo`800003Ool007oo01ioo`03001oogoo00=oo`@000Moo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l000=oo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000kOol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0000Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000fOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`08Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0000Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000fOol60004Ool50006
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Ool0000?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool3000HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
001oo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00
Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03goo001oo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol200000goo001o
o`0_Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03`00Oomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D007ooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
07ooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00<03gooOol0
0Woo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0000moo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0700moogooOol007oo00l00goo00<03gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001o
o`0?00=oo`0300moogoo009oo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03gooOol0009oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0400moogoo0002Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Ool00003Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`<001Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00003Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol003Moo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?001oo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol003Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<007ooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000kOol01@00Oomoogoo000017oo00<007ooOol0
17oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03001oogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00>goo00D007ooOomoo`0000Ao
o`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0000mo
o`04Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol002eoo`H000Qo
o`05001oogooOol00004Ool00`00Oomoo`04Ool3002<00l00`0000l03`2d00l00`00Oomoo`0LOol0
03Moo`@000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool01`0?Oomoogoo001oo`0?00Eoo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00=goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol003Moo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Moo`D000Aoo`@000Mo
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?001oo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0000moo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0000mo
o`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool00`00Ool03`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`02Ool01000Oomoo`0?1Goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`0000=oo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0500moogooOol00003Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3goo00001Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<007ooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Woo00<0
000?Ool01Woo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lG
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
17oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
03Ioo`H000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000f
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0400moogoo0006Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol003Moo`03001oogoo00Yoo`03001oogoo00Aoo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Ool0
0007Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol003Qoo`03001oogoo00Uoo`03001oogoo00Aoo`<007L0
3`0300003`0?0<T03`03001oogoo01aoo`00;Goo1P001Woo00<007ooOol027oo00<007ooOol017oo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00>Woo00<007ooOol00goo10001goo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00=Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol027oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Qoo`800003Ool03goo00Qoo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
=Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Ioo`8000=oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00=goo10001Goo1@001Woo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Eoo`03001oogoo00=oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00=oo`8000Ioo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo008000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moo`0000]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`8000aoo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01=oo`80
000300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo011oo`<0009oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`8000Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo00aoo`8000Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo00Yoo`8000Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Moo`<000]o
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00=oo`@000ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0000<0019oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`<0
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo
00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00<03goo0000100000=oo`0?Ool05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool000040002Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?000000040003Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool70004Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool900000`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo0010Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?0000000600000goo00moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol@0009Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000G00000goo00moo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000HOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol0
1Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Aoo`04001oogoo000GOol00`00
Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`07001oogoo
Ool007oo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000HOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000Aoo`04001oogoo000G
Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`07
001oogooOol007oo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Oooo0018000NOol003mo
o`03001oogoo009oo`03001oogoo0?moofYoo`00@7oo1000ogooKGoo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00=Uoo`D000Aoo`<0009oo`<000=o
o`D000=oo`D000Eoo`@00:eoo`00fWoo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`2ZOol00=Yo
o`03001oogoo00Ioo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`07Ool01@00Oomo
ogoo0000/Goo003JOol50004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool40005Ool40004Ool6002/
Ool00=Yoo`03001oogoo009oo`04001oogooOol20003Ool01@00Oomoogoo00000goo00<007ooOol0
0Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo0:Yoo`00fWoo00<007ooOol00Woo
00H007ooOomoo`00Ool30005Ool30006Ool50004Ool4002]Ool00=Yoo`03001oogoo009oo`05001o
ogooOol0003<Ool00=Uoo`H000Aoo`03001oogoo0<Yoo`00hWoo0P00c7oo003oOonaOol00?mook5o
o`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.96984, -217.067, \
0.0186604, 1.35402}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Whitening", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C\), R2], 
          Z2 \[Rule] par[1\/\(s\ C\), R2], Z3 \[Rule] R, Z4 \[Rule] R, 
          G \[Rule] 1} // Simplify\), "\[IndentingNewLine]", 
    \(\(% /. {R \[Rule] 1.1, C \[Rule] 1/\((2  \[Pi])\), 
          R2 \[Rule] 10};\)\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\((R + C\ R\ R2\ s)\)\^2\/\((R + R2 + C\ R\ R2\ s)\)\^2\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]0.009820631442253066`\
\[InvisibleSpace]" \
("\[InvisibleSpace]0.009820631442253066`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=0) = ", .0098206314422530656, " (", .0098206314422530656, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]1.`\
\[InvisibleSpace]" ("\[InvisibleSpace]1.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=\[Infinity]) = ", 1.0, " (", 1.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Poles at = "\[InvisibleSpace]\(-1.009090909090909`\)\
\[InvisibleSpace]" and "\[InvisibleSpace]\(-1.009090909090909`\)\
\[InvisibleSpace]" "\),
      SequenceForm[ 
      "Poles at = ", -1.009090909090909, " and ", -1.009090909090909, " "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]1.009090909090909`\[InvisibleSpace]" \
("\[InvisibleSpace]1.009090909090909`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Pole frequency = ", 1.009090909090909, " (", 1.009090909090909, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.5000000000000001`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.5000000000000001`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Pole Q = ", .50000000000000011, " (", .50000000000000011, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = "\[InvisibleSpace]0.1`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.1`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Zero frequency = ", .10000000000000001, " (", .10000000000000001, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.616426 0.0153272 [
[.00617 -0.0125 -14.5625 -16.375 ]
[.00617 -0.0125 14.5625 0 ]
[.25309 -0.0125 -10.9688 -16.375 ]
[.25309 -0.0125 10.9688 0 ]
[.5 -0.0125 -5.59375 -16.375 ]
[.5 -0.0125 5.59375 0 ]
[.74691 -0.0125 -9.1875 -16.375 ]
[.74691 -0.0125 9.1875 0 ]
[.99383 -0.0125 -12.7813 -16.375 ]
[.99383 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.90625 -32.75 ]
[.5 -0.0125 9.90625 -16.375 ]
[-0.0125 .00334 -27.375 -8.1875 ]
[-0.0125 .00334 0 8.1875 ]
[-0.0125 .15661 -27.375 -8.1875 ]
[-0.0125 .15661 0 8.1875 ]
[-0.0125 .30988 -27.375 -8.1875 ]
[-0.0125 .30988 0 8.1875 ]
[-0.0125 .46315 -27.375 -8.1875 ]
[-0.0125 .46315 0 8.1875 ]
[-0.0125 .61643 -11.1875 -8.1875 ]
[-0.0125 .61643 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.75 -9.90625 ]
[-0.01875 .30902 -27.375 9.90625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -32.125 0 ]
[.5 .63053 32.125 16.375 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .15661 m
1 .15661 L
s
0 .30988 m
1 .30988 L
s
0 .46315 m
1 .46315 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75.5625 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
88.125 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
77.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
84.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.9063 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
78.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00334 m
.00625 .00334 L
s
gsave
-0.0125 .00334 -88.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .15661 m
.00625 .15661 L
s
gsave
-0.0125 .15661 -88.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .30988 m
.00625 .30988 L
s
gsave
-0.0125 .30988 -88.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .46315 m
.00625 .46315 L
s
gsave
-0.0125 .46315 -88.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .61643 m
.00625 .61643 L
s
gsave
-0.0125 .61643 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03399 m
.00375 .03399 L
s
0 .06465 m
.00375 .06465 L
s
0 .0953 m
.00375 .0953 L
s
0 .12596 m
.00375 .12596 L
s
0 .18727 m
.00375 .18727 L
s
0 .21792 m
.00375 .21792 L
s
0 .24857 m
.00375 .24857 L
s
0 .27923 m
.00375 .27923 L
s
0 .34054 m
.00375 .34054 L
s
0 .37119 m
.00375 .37119 L
s
0 .40185 m
.00375 .40185 L
s
0 .4325 m
.00375 .4325 L
s
0 .49381 m
.00375 .49381 L
s
0 .52446 m
.00375 .52446 L
s
0 .55512 m
.00375 .55512 L
s
0 .58577 m
.00375 .58577 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -106.469 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
70.9063 12.1875 translate
90 rotate
-70.9063 -12.1875 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
78.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -93.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
123.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .00224 m
.02372 .00275 L
.03955 .00336 L
.05352 .00408 L
.06699 .00497 L
.08806 .00686 L
.10505 .00901 L
.12058 .01161 L
.13367 .01442 L
.14491 .01738 L
.1557 .02078 L
.16516 .02428 L
.17353 .02785 L
.18178 .03183 L
.18916 .03582 L
.19649 .04023 L
.2031 .04461 L
.2091 .04892 L
.21513 .05362 L
.22064 .05822 L
.22619 .06318 L
.23129 .06801 L
.23597 .0727 L
.24074 .07772 L
.24514 .08258 L
.2492 .08726 L
.25309 .09191 L
s
.25309 .09191 m
.28646 .13857 L
.31391 .18507 L
.33453 .22367 L
.35121 .25646 L
.3665 .28728 L
.37942 .31354 L
.39162 .33832 L
.4022 .3596 L
.41148 .378 L
.42054 .39564 L
.4286 .41098 L
.43581 .42439 L
.44299 .43739 L
.44948 .4488 L
.45597 .45988 L
.46187 .46963 L
.46726 .47825 L
.4727 .48668 L
.4777 .49415 L
.48277 .50146 L
.48743 .50795 L
.49174 .51374 L
.49613 .51943 L
.5 .52426 L
s
.5 .52426 m
.51754 .54409 L
.53337 .5591 L
.56082 .57914 L
.58072 .5896 L
.5985 .59663 L
.61321 .60111 L
.62691 .60441 L
.63864 .60669 L
.64882 .60832 L
.65869 .60965 L
.66741 .61064 L
.67517 .61141 L
.68285 .61207 L
.68977 .61259 L
.69666 .61304 L
.7029 .61341 L
.70858 .61371 L
.71432 .61398 L
.71956 .61421 L
.72487 .61442 L
.72974 .61459 L
.73423 .61474 L
.73881 .61487 L
.74304 .61499 L
.74691 .61509 L
s
.74691 .61509 m
.76446 .61546 L
.78029 .61571 L
.79426 .61587 L
.80773 .616 L
.81928 .61608 L
.8288 .61614 L
.84579 .61621 L
.86079 .61627 L
.87347 .6163 L
.88549 .61633 L
.89592 .61634 L
.90507 .61636 L
.91403 .61637 L
.92199 .61638 L
.92986 .61638 L
.93693 .61639 L
.94331 .61639 L
.94972 .6164 L
.95554 .6164 L
.9614 .6164 L
.96675 .6164 L
.97167 .61641 L
.97666 .61641 L
.98126 .61641 L
.9855 .61641 L
.98984 .61641 L
.99383 .61641 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00igoo0P001goo0P0000=oo`0000001`00
]7oo003WOol20007Ool200000goo00000007002dOol00>Moo`8000Moo`800004Ool00000002jOol0
0>Moo`8000Moo`80009oo`<00;Uoo`00igoo0P001goo0P000goo0`00^7oo003WOol20007Ool20004
Ool3002gOol00>Moo`8000Moo`8000Eoo`<00;Ioo`00igoo2`001Woo0`00]Goo003WOol;0007Ool3
002dOol00>Moo`8000Moo`80009oo`P00;Aoo`00igoo0P001goo0P000Woo2000]7oo003WOol20007
Ool2002nOol00>Moo`8000Moo`800;ioo`00igoo0P001goo0P00_Woo003WOol20007Ool2002nOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00Cgoo1@001Goo0P001Goo1@0027oo0P00;goo1@001Goo0P001goo
0P00?goo0P00@Woo0P001goo1@00=Woo0P001goo1@001Woo1@007Goo001>Ool70004Ool20004Ool7
0007Ool2000^Ool70004Ool20007Ool2000oOol20012Ool20006Ool7000eOol20006Ool70004Ool7
000LOol004ioo`8000=oo`8000Yoo`8000=oo`8000Moo`8002ioo`8000=oo`8000eoo`8003moo`80
049oo`8000Ioo`8000=oo`8003Eoo`8000Ioo`8000=oo`8000Aoo`8000=oo`8001aoo`00CGoo0P00
1Goo0P0027oo0P001Goo0P001Woo0P00;Goo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P00
1Goo0P00=7oo0P001Goo0P001Goo0P000Woo0P001Goo0P006goo001=Ool20005Ool20008Ool20005
Ool20006Ool2000]Ool20005Ool2000<Ool2000oOol20012Ool20005Ool20005Ool2000dOol20005
Ool20005Ool20002Ool20005Ool2000KOol004eoo`8000Eoo`8000Qoo`8000Eoo`8000Ioo`8002eo
o`8000Eoo`8000aoo`8003moo`80049oo`8000Eoo`8000Eoo`8003Aoo`8000Eoo`8000Eoo`80009o
o`8000Eoo`8001]oo`00CGoo0P001Goo0P0027oo0P001Goo0P001Woo0P00;Goo0P001Goo0P0037oo
0P00?goo0P00@Woo0P001Goo0P001Goo0P00=7oo0P001Goo0P001Goo0P000Woo0P001Goo0P006goo
001=Ool20005Ool20008Ool20005Ool20006Ool2000]Ool20005Ool2000<Ool2000oOol20012Ool2
0005Ool20005Ool2000dOol20005Ool20005Ool20002Ool20005Ool2000KOol004eoo`8000Eoo`80
00Qoo`8000Eoo`8000Ioo`8002eoo`8000Eoo`8000aoo`8003moo`80049oo`8000Eoo`8000Eoo`80
03Aoo`8000Eoo`8000Eoo`80009oo`8000Eoo`8001]oo`00CGoo0P001Goo0P0027oo0P001Goo0P00
1Woo0P00;Goo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=7oo0P001Goo0P00
1Goo0P000Woo0P001Goo0P006goo001=Ool20005Ool20008Ool20005Ool20003Ool200000goo0000
000]Ool20005Ool20009Ool200000goo0000000lOol200000goo0000000oOol200000goo00000005
Ool20005Ool2000aOol200000goo00000005Ool20005Ool20002Ool20005Ool2000KOol004eoo`80
00Eoo`8000Qoo`8000Eoo`8000=oo`D002eoo`8000Eoo`8000Uoo`D003aoo`D003moo`D000Eoo`80
00Eoo`80035oo`D000Eoo`8000Eoo`80009oo`8000Eoo`8001]oo`00CWoo0P000goo0P002Woo0P00
0goo0P001Woo0`00;Woo0P000goo0P0037oo0`00?Woo0`00@Goo0`001Woo0P000goo0P00=7oo0`00
1Woo0P000goo0P0017oo0P000goo0P0077oo001>Ool7000:Ool70007Ool2000^Ool7000=Ool2000o
Ool20012Ool20006Ool7000eOol20006Ool70004Ool7000LOol004moo`D000aoo`D000Qoo`8002mo
o`D000ioo`8003moo`80049oo`8000Moo`D003Ioo`8000Moo`D000Ioo`D001eoo`00ogoo/Goo003o
OonaOol004Ioo`8000Ioo`D00?mooeioo`00AWoo0P001Goo1`00ogooGGoo0016Ool20005Ool20003
Ool2003oOomMOol0041oo`X0009oo`8000Eoo`800?mooeaoo`00@7oo2P000Woo0P001Goo0P0027oo
o`00;000:7oo000dOol;00000goo00000004Ool20004Ool20005Ool20008Ool>000:Ool00`00Oomo
o`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00@007ooOol001Eoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`005Goo00<007ooOol0
2Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00@007ooOol000=oo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoogoo0P00:7oo
0011Ool20003Ool20004Ool20005Ool20008Ool2000<Ool900000goo001oo`0;Ool00`00Oomoo`06
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007oo
Ool001Eoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00003Ool01000Oomoo`005Goo00<007ooOol02Woo00<007ooOol01Woo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=o
o`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo009oo`05001oogooOol00003Ool01000Oomoogoo0P00:7oo0012Ool20002Ool20004
Ool20005Ool20008Ool00`0000moo`0DOol;0003Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00@Woo0P000Woo0P0017oo0P001Goo0P0027oo00<0
000?Ool05Goo00<03gooOol01goo100027oo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Oomoo`0?000XOol004=oo`800003Ool0000000Aoo`8000Eoo`8000Qoo`0300003goo01Eoo`0300mo
ogoo00Yoo`0400l000000005Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l0
02Qoo`00A7oo100017oo0P001Goo0P0027oo00<0000?Ool05Goo00<03gooOol02Woo00@03gooOomo
o`@00003Ool03goo00Eoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0015Ool30004Ool2
0005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool30005Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoogoo00l002Qoo`00AGoo0`001Goo0P000goo0P002Goo00<0000?Ool05Goo
00<03gooOol02Woo00<03gooOol01Woo00@03goo000000=oo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
Ool03`00:7oo0016Ool20005Ool70009Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool0100?Oomoogoo0`0000<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol004Moo`03001oogoo
00Aoo`D000Yoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`80
00Aoo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo001MOol2000FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool0100?Ool000000Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0700moogooOol007oo00l017oo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?
000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300003goo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool20003Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?
Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00H03goo
000007oo00l3Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool01P0?Oomoogoo00003`=oo`0500moogooOol03`02Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`05001oogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600mo
ogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?001oogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
0000000?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000X
Ool005eoo`8001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol00003Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0900moogooOol03goo001oo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l00Woo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`00
00moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00D0000?Oomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`800003Ool0
3goo01Aoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400l007oo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Oomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Ool0000?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol001Eoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qo
o`00GGoo0P005Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogoo00l0000DOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?
Oomoo`0?000057oo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`00
00moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000COol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00<007ooOol047oo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001M
Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`=oo`03001oogoo00moo`0300mo
ogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00l3Ool00`00Oomoo`0?Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Oomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?17oo00<0
07ooOol03Woo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000mo
o`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`Eoo`03001oogoo00eoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00l5Ool00`00Oomoo`0=Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000X
Ool005eoo`8001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?1Woo00<007ooOol037oo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03`Moo`03001oogoo00]oo`0300moogoo00Yoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
ogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l8Ool00`00
Oomoo`0:Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?27oo00<007ooOol02Woo00<03gooOol02Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo0013Ool50006Ool5000:Ool00`0000moo`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`Uoo`03001oogoo00Uoo`0300moogoo00Yoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoogoo00l002Qoo`00@Woo1`0017oo1`002Goo00<0000?Ool05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00l:Ool00`00Oomoo`08Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000X
Ool0045oo`<000=oo`<000=oo`8000=oo`8000Uoo`0300003goo01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?2Woo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00
:7oo0011Ool20005Ool20002Ool20005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03`]oo`03001oogoo00Moo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l0
02Qoo`00B7oo0P000Woo0P001Goo0P0027oo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00l;Ool00`00Oomoo`07Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
03Aoo`/000Uoo`80009oo`8000Eoo`8000Qoo`8005H03`0300003`0?0<l03`03001oogoo02Ioo`00
Agoo0`000Woo0P001Goo0P0027oo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l<
Ool00`00Oomoo`06Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol004Eoo`@0
00=oo`8000Eoo`8000Qoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?3Goo00<0
07ooOol01Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0015Ool20005Ool2
0005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`ioo`03001oogoo
00Aoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00AWoo0`000goo0P001Goo
0P0027oo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l>Ool00`00Oomoo`04Ool0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol004Moo`8000=oo`8000Eoo`8000Qo
o`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?3goo00<007ooOol00goo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0011Ool20004Ool20003Ool20005Ool20008
Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`moo`03001oogoo00=oo`0300mo
ogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00@Goo0`000Woo0`0017oo0P000goo0P00
2Goo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l@Ool00`00Oomoo`02Ool00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0049oo`H000Eoo`L000Uoo`0300003goo
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?47oo00<007ooOol00Woo00<03gooOol02Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo0013Ool40007Ool5000:Ool2000FOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03a5oo`05001oogooOol03`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
05eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?4Woo00@007ooOol03`aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lBOol01000Oomoo`0?37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`00
00moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03a=oo`03001oo`0?00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lC
Ool00`00Ool03`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?57oo00<0000?Ool02goo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol0
3`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aAoo`0300003goo
00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`00Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eo
o`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<007ooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300l007oo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo0P005Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?001oo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?
000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo0000
2Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moo`0000Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo
00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0100?Oomoo`002Goo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0400moogoo0009Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00D03gooOomoo`0000Qoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool01@0?Oomoogoo000027oo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo009oo`03001oogoo00Eoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`02Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
05eoo`8001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol00goo00<007ooOol0
17oo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00=oo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo
00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`04Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol01Goo00<007ooOol00Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Eoo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00
GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`06Ool01@00
Oomoogoo00l02Goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Ioo`05001oogooOol03`09Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eo
o`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol01goo00@007oo
Ool03`Uoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoogoo00l002Qoo`0087oo1@00>7oo00<0000?Ool05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`07Ool01000Oomoo`0?2Goo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo000NOol9
000fOol2000FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Qoo`03001oo`0?
00Uoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01P0?Oomoogoo00l002Qoo`007Goo0`001Goo0`00=Goo00<0000?Ool05Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`08Ool00`00Ool03`09Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol001eo
o`8000Moo`8003Eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Goo00<0000?Ool027oo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo000MOol20007Ool2000IOol90004Ool5000:
Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Uoo`030000
3goo00Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoogoo00l002Qoo`007Goo0P001goo0P006Goo2@000goo1`002Goo00<0000?Ool0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`00Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Oomoo`0?000XOol001ioo`8000Eoo`8001]oo`8000Uoo`8000=oo`8000Uoo`0300003goo01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<007ooOol01goo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol0
3`00:7oo000IOol?000KOol20007Ool20005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300l007oo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`006Goo
3`0077oo0P001Woo0P001Goo0P0027oo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?001oo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol003Aoo`/000Ioo`8000Eo
o`8000Eoo`8000Qoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03goo00001goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0016Ool20004Ool20005Ool20008Ool2001^
00l00`0000l03`2g00l00`00Oomoo`0VOol004Moo`8000=oo`8000Eoo`8000Qoo`0300003goo01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00@03gooOol000Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
ogoo00l002Qoo`006Goo3`0087oo00@007ooOomoo`8000Eoo`8000Qoo`0300003goo01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00@03gooOol000Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l0
02Qoo`006Goo3`0087oo0P000Woo0P001Goo0P0027oo00<0000?Ool05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool01@0?Oomoogoo00001Goo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo000I
Ool20004Ool20005Ool2000POol20002Ool20005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0500moogooOol00005Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000X
Ool001Uoo`8000Aoo`8000Eoo`8001Uoo`8000Eoo`80009oo`8000Eoo`8000Qoo`0300003goo01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol00Woo00<007oo
Ool00Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogooOol03`00:7oo000IOol20004Ool20005Ool2000JOol20004Ool20003Ool20003
Ool20009Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo009oo`03001oogoo009oo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
ogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`006Goo0P0017oo0P001Goo0P00
6Woo1`0017oo1`002Goo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01Woo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo000IOol30002Ool30005Ool2000K
Ool50006Ool5000:Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00=oo`05001oogooOol03`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol001Yoo`P000=oo`<003Eoo`8001Io
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol017oo00@007oo
Ool03`Ioo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
ogoo00l002Qoo`006goo10000Woo1P00=Woo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`04Ool01000Oomoo`0?1Woo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo000ROol4000gOol0
0`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00Eoo`03001oo`0?00Ioo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`00Ool03`06Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<0000?
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
Ool03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300003goo00Eoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`00Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
05eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01goo00<007ooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300l007oo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo0P005Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?001o
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomo
o`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01goo00<03goo000017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moo`0000Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00
GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Ool00004Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00@03gooOol000=oo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?
Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
100?Oomoo`000goo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0500moogooOol00002Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00D03goo
Oomoo`00009oo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool00`00Ool03`05Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol00goo
00<0000?Ool017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00
:7oo001MOol2000FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Moo`0300moogoo00=oo`0300003goo00Aoo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<0
3gooOol017oo00<03`00Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600mo
ogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300l007oo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Ool00003Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000X
Ool005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01goo00<03gooOol017oo00<03goo00000goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0400moogoo0002
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`03
00003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00@03gooOol0009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool01`0?Oomoogoo001oo`0?00Ao
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
ogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo0P005Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool01`0?
Oomoogoo001oo`0?00Aoo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo
00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0000moo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00Woo00<0000?
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0015Ool20007Ool5000:
Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`03001oogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoogoo00l002Qoo`00AGoo0P001Woo1`002Goo00<0000?Ool05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
04Eoo`8000Ioo`8000=oo`8000Uoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03`00Ool0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0015Ool20005Ool20005Ool2
0008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moo`00009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoogoo00l002Qoo`00AGoo0P001Goo0P001Goo0P0027oo00<0000?Ool05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Ool00002Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomo
o`0?000XOol003Aoo`/000Ioo`8000Eoo`8000Eoo`8000Qoo`0300003goo01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool00goo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qo
o`00AGoo0P001Goo0P001Goo0P0027oo0P00Q`0?00<0000?00l0WP0?00<007ooOol09Woo0015Ool2
0005Ool20005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0600moogooOol0000?
0goo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol004Eoo`8000Eoo`8000Eoo`80
00Qoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D007ooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo0015Ool20005Ool20005Ool20008Ool00`0000moo`0EOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`05001oogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo
00l002Qoo`00@Woo0P0000=oo`0000001Goo0P001Goo0P0027oo00<0000?Ool05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?001oogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
049oo`D000Eoo`8000Eoo`8000Qoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03goo001oo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo0014Ool30006Ool20003Ool2
0009Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moo`00Ool03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoogoo00l002Qoo`00AGoo0P001Woo1`002Goo00<0000?Ool05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000X
Ool004Eoo`8000Moo`D000Yoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOol0000?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol2000FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol00003Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00
GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0900moogooOol03goo001oo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eo
o`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo
00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D0000?Oomoo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eo
o`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?009oo`05
00003gooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01000Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?
Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03`00Ool0
3aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moo`0000lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol2000FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`005Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00
GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00D03gooOol03`0001Aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`004goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo
00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo000COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol047oo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qo
o`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`=oo`03001oogoo00moo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l4Ool00`00Oomo
o`0>Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?1Goo00<007ooOol03Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0
000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`Ioo`03001oogoo00aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOomoo`0?000XOol005eoo`8001Ioo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l7Ool00`00Oomoo`0;Ool00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo
001MOol00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?27oo00<007ooOol02Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`Uoo`03001oogoo
00Uoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00l:Ool00`00Oomoo`08Ool00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`00
00moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?2goo0P0027oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`eoo`03001oogoo00Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000XOol0
05eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00l>Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?3goo0P0017oo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo
00l002Qoo`00GGoo00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03a5oo`05001oogooOol03`0<Ool00`0?Oomoo`06Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001MOol00`0000moo`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?4Woo0P0000=oo`0?
Ool02goo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l0
02Qoo`00GGoo0P005Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aAoo`8000aoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00H03gooOomoo`0?000XOol005eoo`0300003goo01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0100?000000002Goo00<03gooOol01Woo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00GGoo00<0000?Ool05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`04
00moogooOol20007Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600mo
ogooOol03`00:7oo001>Ool5000:Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol00goo10000goo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l002Qoo`00CGoo1`002Goo
00<0000?Ool05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Moo`@000Qoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOomoo`0?000XOol004eoo`8000=oo`8000Uoo`0300003goo01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?0000
00020004Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogooOol03`00:7oo001<Ool2
0005Ool20008Ool00`0000moo`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol00Woo1P001Woo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoogoo00l002Qoo`00C7oo0P001Goo0P0027oo0P005Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo000EOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol001Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moo`0000T00003Ool03goo00=oo`0300moogoo009oo`0400moogoo00l3Ool0
0`00Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOomoo`8002Qoo`00C7oo0P001Goo0P0027oo
0P005Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`04001oogoo000EOol00`00Oomoo`0:Ool00`00Oomoo`07Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol0
01Eoo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Eoo`04001oogooOolJ000>Ool00`00
Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Oomoogoo00000goo00@007ooOomoo`8002Qoo`00C7oo0P001Goo0P0027ooo`00;000:7oo001<Ool2
0005Ool2003oOomLOol004aoo`8000Eoo`800?mooeaoo`00C7oo0P001Goo0P00ogooG7oo001<Ool2
0005Ool2003oOomLOol004aoo`8000Eoo`800?mooeaoo`00CGoo0P000goo0P00ogooGGoo001=Ool7
002@Ool50037Ool004ioo`D008moo`P00<Ioo`00hWoo0P0017oo0`00aGoo003YOol20035Ool00<Mo
o`8000=oo`<000=oo`8000Aoo`@0009oo`8000Aoo`@00003Ool00000009oo`8000Aoo`80009oo`80
00=oo`<000=oo`@00003Ool0000000Aoo`@00003Ool0000000Aoo`D009=oo`00agoo0P000goo0`00
0goo0P000goo200017oo20000Woo0P0017oo0P000Woo0P000Woo10000Woo20000goo20000goo1`00
TWoo0037Ool20003Ool30003Ool20003Ool20003Ool30004Ool20003Ool30002Ool20004Ool20002
Ool20002Ool20004Ool20003Ool30003Ool20003Ool30003Ool20004Ool2002AOol00<Moo`80009o
o`800003Ool00000009oo`8000=oo`8000Aoo`8000=oo`8000Eoo`80009oo`8000Aoo`80009oo`80
009oo`8000Aoo`8000Aoo`80009oo`8000Eoo`80009oo`8009Qoo`00agoo0P000Woo0P0000=oo`00
00000Woo0P000goo10000Woo0P000goo0P001Goo0P000Woo0P0017oo0P000Woo0P000Woo0P0017oo
0P0017oo0P000Woo0P001Goo0P000Woo0P00V7oo0037Ool20002Ool200000goo00000002Ool20004
Ool70003Ool20005Ool20002Ool20004Ool20002Ool20002Ool20004Ool20004Ool20002Ool20005
Ool20002Ool9002AOol00<Moo`80009oo`800003Ool00000009oo`8000Moo`@000=oo`8000Eoo`80
009oo`8000Aoo`80009oo`80009oo`8000Aoo`8000Aoo`80009oo`8000Eoo`80009oo`T0095oo`00
agoo0P0000=oo`0000000goo0P0000=oo`0000002Goo0P000goo0P001Goo0P000Woo0P0017oo0P00
0Woo0P000Woo0P0017oo0P0017oo0P000Woo0P001Goo0P000Woo0P001Goo0P00TGoo0037Ool20000
0goo00000003Ool200000goo00000003Ool20004Ool20004Ool20003Ool30002Ool30003Ool20002
Ool20002Ool20004Ool20004Ool20003Ool20003Ool30003Ool20003Ool2002BOol00<Moo`800003
Ool0000000=oo`800003Ool0000000=oo`P000Aoo`P0009oo`P0009oo`800003Ool0000000<0009o
o`8000Aoo`8000=oo`P000=oo`L0099oo`00agoo0P0000=oo`0000000goo0P0000=oo`0000001Goo
1@001Woo100000=oo`0000000Woo0P0000=oo`0000000P000goo0P0000=oo`0000000`000Woo0P00
17oo0P0017oo100000=oo`00000017oo1@00Tgoo0037Ool40005Ool4000WOol2000EOol2002LOol0
0<Moo`@000Eoo`@002Moo`8001Eoo`8009aoo`00agoo10001Goo10008goo0P000Woo0P005Goo0P00
W7oo0037Ool30007Ool3000SOol2000IOol2002LOol00?mook5oo`00ogoo/Goo003oOonaOol00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-3.2854, -51.7574, \
0.0203262, 0.327445}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.010828 0.00547577 [
[.00617 -0.0125 -14.5625 -16.375 ]
[.00617 -0.0125 14.5625 0 ]
[.25309 -0.0125 -10.9688 -16.375 ]
[.25309 -0.0125 10.9688 0 ]
[.5 -0.0125 -5.59375 -16.375 ]
[.5 -0.0125 5.59375 0 ]
[.74691 -0.0125 -9.1875 -16.375 ]
[.74691 -0.0125 9.1875 0 ]
[.99383 -0.0125 -12.7813 -16.375 ]
[.99383 -0.0125 12.7813 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.90625 -32.75 ]
[.5 -0.0125 9.90625 -16.375 ]
[-0.0125 .01083 -11.1875 -8.1875 ]
[-0.0125 .01083 0 8.1875 ]
[-0.0125 .12034 -18.375 -8.1875 ]
[-0.0125 .12034 0 8.1875 ]
[-0.0125 .22986 -18.375 -8.1875 ]
[-0.0125 .22986 0 8.1875 ]
[-0.0125 .33937 -18.375 -8.1875 ]
[-0.0125 .33937 0 8.1875 ]
[-0.0125 .44889 -18.375 -8.1875 ]
[-0.0125 .44889 0 8.1875 ]
[-0.0125 .55841 -25.5625 -8.1875 ]
[-0.0125 .55841 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -41.9375 -22.125 ]
[-0.01875 .30902 -25.5625 22.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -20.3125 0 ]
[.5 .63053 20.3125 16.375 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12034 m
1 .12034 L
s
0 .22986 m
1 .22986 L
s
0 .33937 m
1 .33937 L
s
0 .44889 m
1 .44889 L
s
0 .55841 m
1 .55841 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75.5625 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
88.125 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
77.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
84.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.9063 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
78.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01083 m
.00625 .01083 L
s
gsave
-0.0125 .01083 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12034 m
.00625 .12034 L
s
gsave
-0.0125 .12034 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .22986 m
.00625 .22986 L
s
gsave
-0.0125 .22986 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .33937 m
.00625 .33937 L
s
gsave
-0.0125 .33937 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .44889 m
.00625 .44889 L
s
gsave
-0.0125 .44889 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .55841 m
.00625 .55841 L
s
gsave
-0.0125 .55841 -86.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03821 m
.00375 .03821 L
s
0 .06559 m
.00375 .06559 L
s
0 .09296 m
.00375 .09296 L
s
0 .14772 m
.00375 .14772 L
s
0 .1751 m
.00375 .1751 L
s
0 .20248 m
.00375 .20248 L
s
0 .25724 m
.00375 .25724 L
s
0 .28462 m
.00375 .28462 L
s
0 .312 m
.00375 .312 L
s
0 .36675 m
.00375 .36675 L
s
0 .39413 m
.00375 .39413 L
s
0 .42151 m
.00375 .42151 L
s
0 .47627 m
.00375 .47627 L
s
0 .50365 m
.00375 .50365 L
s
0 .53103 m
.00375 .53103 L
s
0 .58578 m
.00375 .58578 L
s
0 .61316 m
.00375 .61316 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -116.875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
83.125 12.1875 translate
90 rotate
-83.125 -12.1875 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
103.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -81.3125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
99.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .06715 m
.03955 .08747 L
.06699 .10938 L
.08762 .12966 L
.1043 .14884 L
.11959 .16886 L
.1325 .18771 L
.14471 .20724 L
.15529 .22555 L
.16457 .24266 L
.17363 .2603 L
.18168 .27673 L
.1889 .29201 L
.19608 .3077 L
.20256 .32224 L
.20906 .33711 L
.21496 .35086 L
.22034 .36356 L
.22579 .37652 L
.23079 .38847 L
.23585 .40062 L
.24052 .4118 L
.24482 .42209 L
.24922 .43254 L
.25309 .44167 L
s
.25309 .44167 m
.28646 .51538 L
.31391 .56421 L
.32508 .57984 L
.33453 .5909 L
.34343 .59939 L
.35121 .60523 L
.35511 .6076 L
.35919 .60967 L
.36274 .61112 L
.36597 .61217 L
.36926 .61296 L
.37096 .61326 L
.37277 .6135 L
.37366 .61359 L
.37412 .61362 L
.37462 .61366 L
.37509 .61368 L
.37552 .6137 L
.37573 .61371 L
.37595 .61372 L
.37635 .61373 L
.37674 .61373 L
.37696 .61373 L
.37716 .61373 L
.37758 .61373 L
.37781 .61372 L
.37802 .61372 L
.37839 .61371 L
.3788 .61369 L
.37953 .61365 L
.38025 .6136 L
.38103 .61353 L
.38242 .61336 L
.38405 .6131 L
.38552 .61281 L
.38849 .61205 L
.39154 .61104 L
.3969 .60869 L
.40166 .60599 L
.41113 .59896 L
.42036 .59001 L
.42855 .58039 L
.43588 .5705 L
.44317 .55953 L
.44975 .5487 L
.45571 .53818 L
.46172 .52694 L
.4672 .51618 L
.47273 .50485 L
Mistroke
.47781 .49411 L
.48247 .48396 L
.48722 .47337 L
.4916 .46342 L
.49607 .45312 L
.5 .44395 L
Mfstroke
.5 .44395 m
.53337 .36437 L
.56082 .30144 L
.58144 .25828 L
.59812 .22671 L
.61342 .20054 L
.62633 .18052 L
.63854 .16329 L
.64912 .14964 L
.65839 .13858 L
.66745 .12858 L
.67551 .1203 L
.68272 .11336 L
.68991 .10686 L
.69639 .10133 L
.70288 .09611 L
.70878 .09161 L
.71417 .08771 L
.71962 .08395 L
.72461 .08066 L
.72968 .07747 L
.73435 .07466 L
.73865 .07217 L
.74305 .06973 L
.74691 .06766 L
s
.74691 .06766 m
.78029 .05253 L
.80773 .04314 L
.82836 .0375 L
.84504 .03366 L
.86033 .03063 L
.87324 .02838 L
.88545 .0265 L
.89603 .02502 L
.90531 .02385 L
.91437 .02279 L
.92242 .02193 L
.92964 .02121 L
.93682 .02053 L
.9433 .01996 L
.9498 .01943 L
.9557 .01897 L
.96108 .01857 L
.96653 .01819 L
.97153 .01785 L
.97659 .01753 L
.98126 .01724 L
.98556 .01699 L
.98996 .01674 L
.99383 .01653 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0P001goo0P0000=oo`0000001`00
]Goo003VOol20007Ool200000goo00000007002eOol00>Ioo`8000Moo`800004Ool00000002kOol0
0>Ioo`8000Moo`80009oo`<00;Yoo`00iWoo0P001goo0P000goo0`00^Goo003VOol20007Ool20004
Ool3002hOol00>Ioo`8000Moo`8000Eoo`<00;Moo`00iWoo2`001Woo0`00]Woo003VOol;0007Ool3
002eOol00>Ioo`8000Moo`80009oo`P00;Eoo`00iWoo0P001goo0P000Woo2000]Goo003VOol20007
Ool2002oOol00>Ioo`8000Moo`800;moo`00iWoo0P001goo0P00_goo003VOol20007Ool2002oOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00CGoo1@001Goo0P001Goo1@0027oo0P00;goo1@001Goo0P001goo
0P00?goo0P00@goo0P001goo1@00=Woo0P001goo1@001Woo1@007Woo001<Ool70004Ool20004Ool7
0007Ool2000^Ool70004Ool20007Ool2000oOol20013Ool20006Ool7000eOol20006Ool70004Ool7
000MOol004aoo`8000=oo`8000Yoo`8000=oo`8000Moo`8002ioo`8000=oo`8000eoo`8003moo`80
04=oo`8000Ioo`8000=oo`8003Eoo`8000Ioo`8000=oo`8000Aoo`8000=oo`8001eoo`00Bgoo0P00
1Goo0P0027oo0P001Goo0P001Woo0P00;Goo0P001Goo0P0037oo0P00?goo0P00@goo0P001Goo0P00
1Goo0P00=7oo0P001Goo0P001Goo0P000Woo0P001Goo0P0077oo001;Ool20005Ool20008Ool20005
Ool20006Ool2000]Ool20005Ool2000<Ool2000oOol20013Ool20005Ool20005Ool2000dOol20005
Ool20005Ool20002Ool20005Ool2000LOol004]oo`8000Eoo`8000Qoo`8000Eoo`8000Ioo`8002eo
o`8000Eoo`8000aoo`8003moo`8004=oo`8000Eoo`8000Eoo`8003Aoo`8000Eoo`8000Eoo`80009o
o`8000Eoo`8001aoo`00Bgoo0P001Goo0P0027oo0P001Goo0P001Woo0P00;Goo0P001Goo0P0037oo
0P00?goo0P00@goo0P001Goo0P001Goo0P00=7oo0P001Goo0P001Goo0P000Woo0P001Goo0P0077oo
001;Ool20005Ool20008Ool20005Ool20006Ool2000]Ool20005Ool2000<Ool2000oOol20013Ool2
0005Ool20005Ool2000dOol20005Ool20005Ool20002Ool20005Ool2000LOol004]oo`8000Eoo`80
00Qoo`8000Eoo`8000Ioo`8002eoo`8000Eoo`8000aoo`8003moo`8004=oo`8000Eoo`8000Eoo`80
03Aoo`8000Eoo`8000Eoo`80009oo`8000Eoo`8001aoo`00Bgoo0P001Goo0P0027oo0P001Goo0P00
1Woo0P00;Goo0P001Goo0P0037oo0P00?goo0P00@goo0P001Goo0P001Goo0P00=7oo0P001Goo0P00
1Goo0P000Woo0P001Goo0P0077oo001;Ool20005Ool20008Ool20005Ool20003Ool200000goo0000
000]Ool20005Ool20009Ool200000goo0000000lOol200000goo00000010Ool200000goo00000005
Ool20005Ool2000aOol200000goo00000005Ool20005Ool20002Ool20005Ool2000LOol004]oo`80
00Eoo`8000Qoo`8000Eoo`8000=oo`D002eoo`8000Eoo`8000Uoo`D003aoo`D0041oo`D000Eoo`80
00Eoo`80035oo`D000Eoo`8000Eoo`80009oo`8000Eoo`8001aoo`00C7oo0P000goo0P002Woo0P00
0goo0P001Woo0`00;Woo0P000goo0P0037oo0`00?Woo0`00@Woo0`001Woo0P000goo0P00=7oo0`00
1Woo0P000goo0P0017oo0P000goo0P007Goo001<Ool7000:Ool70007Ool2000^Ool7000=Ool2000o
Ool20013Ool20006Ool7000eOol20006Ool70004Ool7000MOol004eoo`D000aoo`D000Qoo`8002mo
o`D000ioo`8003moo`8004=oo`8000Moo`D003Ioo`8000Moo`D000Ioo`D001ioo`00ogoo/Goo003o
OonaOol00?mook5oo`00ogoo/Goo001=Ool5003oOomOOol004aoo`L00?mooeioo`00C7oo0P000goo
0P0027ooo`00;@00:Goo001;Ool20005Ool20007Ool00`00Ool0000EOol00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000goo00<007ooOol04goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0000EOol00`00Oomo
o`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000goo00@007ooOol001Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01P00Oomoo`00Ool002Uoo`00Bgoo
0P001Goo0P001goo00<007oo00005Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo01=o
o`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00003Ool01@00Oomoogoo00005Goo00<007ooOol02Woo00<007ooOol01Woo00<0
07ooOol017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo000F
Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool01@00Oomoogoo00000goo00H007ooOol007oo000YOol004]oo`8000Eoo`8000Moo`03001oo`0?
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogoo00moo`00:Goo001;Ool20005Ool20007Ool3000EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Bgoo0P001Goo
0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03goo000007oo000YOol004]oo`8000Eoo`8000Moo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03`000000300000Aoo`0?Ool002Uoo`00Bgoo0P001Goo
0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`02Ool90004Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol004]oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol00Woo2@000Woo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001;Ool20005Ool20007
Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300l00000008000Aoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00C7oo0P000goo0P0027oo00<007oo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`07Ool40008Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000Y
Ool004aoo`L000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Woo00<03gooOol00Woo1@000goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001=Ool50009Ool200000`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`D000Qoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
ogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lAOol500000`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?3Woo0`001Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0600moogoo00moo`00:Goo001KOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03`]oo`<000Qoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l9Ool2000;Ool00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?1goo0P003Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo
001KOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`Eoo`8000mo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00l3Ool2000AOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000YOol005]oo`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomo
o`0?Ool00P004goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool0000E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo00000P005Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogoo00moo`00:Goo001KOol00`00Ool03`02000COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03`00Ool03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l0
0Woo0P004Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04001oogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol005]oo`03001oo`0?00Aoo`03001oogoo00ioo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`06
00moogooOol03goo0P0000@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uo
o`00Fgoo00<007oo00l01Goo0P003Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00H03gooOomoo`0?0002Ool0100?Oomoo`0?
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`07Ool2000<Ool0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`020003Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00:Goo001KOol00`00Ool03`09Ool00`00Oomoo`09Ool00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Ool007oo00l0
0goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo0P0000<0
3gooOol027oo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo0P000Woo00D03gooOomoo`0?009oo`0300moogoo
01Aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l02goo0P0027oo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00P0000D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol005]oo`03001oo`0?00eoo`03001oogoo00Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moo`00009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0010Ool90004
Ool50009Ool00`00Ool03`0>Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?001oo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00@7oo2@000goo1`0027oo
00<007oo00l03goo0P0017oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00Woo0P0017oo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo000YOol0045oo`8000Uoo`8000=oo`8000Qoo`03001oo`0?015oo`05
001oogooOol03`0<Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool01`0?Oomoogoo001o
o`0?00Aoo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00:Goo0012Ool20007Ool20005Ool20007Ool00`00Ool03`0BOol01000Oomoo`0?37oo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00@03gooOol0009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0013
Ool20006Ool20005Ool20007Ool00`00Ool03`0COol00`00Ool03`0<Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Ool00003Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00A7oo0P001Goo0P001Goo
0P001goo0`00500?00<0000?00l0/00?00<0000?00l0GP0?00<007ooOol09goo0015Ool20004Ool2
0005Ool20007Ool00`00Ool03`0EOol00`00Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`00Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00AWoo0P000goo0P001Goo0P001goo00<0
07oo00l05Goo00<03`00Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<007oo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol004Moo`04001oogooOol20005Ool20007Ool00`00Ool03`0EOol0
0`0?Ool0000:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0000moo`04Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool002Uoo`00Agoo0P000Woo0P001Goo0P001goo00<007oo00l05Goo00@03gooOol000Uoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo009oo`03001oo`0?00Eoo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0017
Ool20002Ool20005Ool20007Ool00`00Ool03`0EOol01@0?Oomoogoo000027oo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<0
3gooOol01Woo00D03gooOomoo`00009oo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0010Ool20005
Ool20002Ool20005Ool20007Ool00`00Ool03`0EOol01@0?Oomoogoo000027oo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<0
3gooOol01Woo00@03gooOol000=oo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0011Ool20004Ool2
0003Ool20003Ool20008Ool00`00Ool03`0EOol00`0?Oomoo`02Ool00`00Oomoo`05Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Ool00004Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00@Goo1`00
17oo1`0027oo00<007oo00l05Goo00<03gooOol00goo00<007ooOol017oo00<03gooOol01Woo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03`00Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0049oo`D000Ioo`D000Uo
o`80000300moogoo01=oo`0300moogoo00Aoo`03001oogoo00=oo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`03001oogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`0EOol00`0?
Oomoo`05Ool00`00Oomoo`02Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0000moo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol01Woo00D007ooOomoo`0?
00Qoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Aoo`03001oo`0?00Ioo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00
Ool03`0EOol00`0?Oomoo`06Ool01@00Oomoogoo00l027oo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol017oo00<007oo00l01Woo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Moo`04001oogoo
00l8Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:
Ool00`0?Oomoo`03Ool01000Oomoo`0?1Woo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03
001oo`0?01Eoo`0300moogoo00Qoo`03001oo`0?00Qoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo009oo`05001oogooOol03`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Goo00<0000?
Ool01goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol0
2Woo00D03gooOomoo`0000Aoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001K
Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`00Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool01@0?Oomoogoo000017oo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`80000300moogoo01=oo`0300moogoo00Yo
o`03001oogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`03
00moogoo00Yoo`0400moogoo0005Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uo
o`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03`00Ool01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03goo00001Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moo`0000Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300mo
ogoo00Yoo`0300l007oo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001K
Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Ool00006Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?001oo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00@03goo
Ool000Eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo
00Yoo`03001oogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol0
0`00Ool03`0EOol00`0?Oomoo`0:Ool01@0?Oomoogoo000017oo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Goo00<0000?Ool01goo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0500mo
ogooOol00004Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?
Oomoo`09Ool00`0000moo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00
Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol00Woo00D007ooOomoo`0?00Moo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Qoo`03001oo`0?00Qoo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol200000`0?Oomoo`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`02Ool01@00Oomoogoo00l01goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5Goo00<03gooOol01goo00@007ooOol03`Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00mo
o`00:Goo001KOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`03Ool01000Oomoo`0?1goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol01goo00@007ooOol03`Qoo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`04Ool00`00Ool03`07Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0E
Ool00`0?Oomoo`06Ool01@00Oomoogoo00l027oo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000YOol004Eoo`8000Ioo`D000Uoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ao
o`03001oo`0?00Moo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Ioo`05
001oogooOol03`08Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`008Woo1@00
7Woo0P001Goo1`0027oo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Goo00<0000?Ool0
1Woo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol01Goo00<007ooOol00Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0021oo`T001ao
o`8000Eoo`8000=oo`8000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03001o
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Eoo`03001oogoo
009oo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol3
0005Ool3000EOol:0002Ool20005Ool20007Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`00Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`04
Ool00`00Oomoo`03Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
02Uoo`007goo0P001goo0P005Goo2P000Woo0P001Goo0P001goo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03`00Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo
00<03gooOol017oo00<007ooOol00goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo000YOol001moo`8000Moo`8001Eoo`8000Aoo`8000Aoo`8000Eoo`8000Moo`<002`0
3`0300003`0?08003`0300003`0?07H03`03001oogoo02Moo`007goo0P001goo0P005Woo0P000goo
0P0017oo0P001Goo0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
00001Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
ogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol00goo00<007ooOol0
17oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0021oo`80
00Eoo`8001Qoo`80009oo`8000Aoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moo`0000Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300mo
ogoo009oo`03001oogoo00Eoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00:Goo000KOol?000GOol20002Ool20004Ool20005Ool20007Ool00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool0100?Oomoo`0017oo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05Goo00<03gooOol00Woo00<007ooOol01Goo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol001]oo`l001Qoo`800003Ool0000000Aoo`8000Eoo`8000Moo`03
001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0400moogoo0004Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0500moogooOol03`0EOol01@0?Oomoogoo000027oo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo000YOol004=oo`@000Aoo`8000Eoo`8000Moo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0500moogooOol00003Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`05
00moogooOol03`0EOol01@0?Oomoogoo000027oo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol004Aoo`<000Aoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0500moogooOol00003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0EOol0100?Oomoo`002Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol0029oo`D001eoo`<000Eoo`8000=oo`8000Qoo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo009oo`04001oogoo00l4Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0E
Ool0100?Oomoo`002Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol0021oo`T001aoo`8000Eoo`L000Qoo`80000300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo009oo`04001oogoo00l4Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Ool0
000:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo
0`0000=oo`0000000Woo0`0077oo00<007ooOol017oo1@002Goo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol00goo00<007oo00l017oo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo
00<03goo00002Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000Y
Ool001moo`80009oo`8000=oo`80035oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00=oo`03001oo`0?00Aoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moo`0000Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol20002Ool2
0003Ool2000aOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0000moo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?001oo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo0P000Woo0P000goo0P00<Goo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0000?Ool00goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05Goo00<03`00Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol001moo`<00003Ool0000000=oo`80035oo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`03001oogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Eoo`03001oogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00:Goo000POol50002Ool2000bOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`00Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`00Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`008Woo0`000Woo
00<007ooOol0<Goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03`00Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l057oo00<0000?Ool02goo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lF
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300l007oo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Ao
o`0300003goo00]oo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00
:Goo001KOol200000`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Ool00002Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0500moogooOol03`0COol00`00Ool03`0<Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`008Woo1@0017oo0P00;Woo00<007oo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo00000Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l04goo00<007oo00l037oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo000YOol0021oo`T0009oo`8002ioo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Eoo`0600moogoo001oo`0?17oo00<03gooOol00Woo00@03gooOol03`=o
o`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l04Woo00@007ooOol03`aoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol30005Ool3
0002Ool2000]Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
1P0?Oomoo`00Ool03`Aoo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?019oo`04001oogoo00l<Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo0P001goo0P000Woo0P00;Goo00<007oo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00H03gooOomoo`0000l4Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0AOol01@00Oomoogoo00l037oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol001moo`8000Moo`80009oo`8002eoo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0600moogooOol0000?17oo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l04Goo00D007ooOomoo`0?
00aoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol2
0007Ool20002Ool2000]Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0AOol01@00Oomoogoo00l037oo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0021oo`8000Eoo`80009o
o`<002eoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`03001oogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?011oo`03001oogoo009oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol>000^Ool200000`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
001oo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0500moogooOol03`0@Ool00`00Oomoo`02Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo3@00;goo00<007oo00l05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03`00Ool00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
3goo00<007ooOol00goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00H03gooOol03goo000YOol004=oo`@000Ioo`D000Uoo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moo`00009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00moo`03001o
ogoo00=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00:Goo0011Ool70004Ool70008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Ool00002Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0>Ool00`00Oomoo`04Ool0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uo
o`007goo2`005goo0P000goo0P0017oo0P000goo0P0027oo00<007oo00l05Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo00000Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03Woo00<0
07ooOol017oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol001moo`/001Ioo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0600moogoo001oo`0?
17oo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03Goo
00<007ooOol01Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo000YOol0021oo`8001ioo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0600moogoo001o
o`0?17oo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
3Goo00<007ooOol01Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00H03gooOol03goo000YOol001moo`8001moo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0600moogoo
Ool0000?17oo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l03Goo00<007ooOol01Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol001moo`8001moo`8000Eoo`80009oo`8000Eoo`8000Moo`<003`0
3`0300003`0?06403`0300003`0?08D03`03001oogoo02Moo`007goo0P007goo0`000goo0`000Woo
0P001Goo0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00H03gooOomoo`0000l4Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0<Ool00`00Oomoo`06Ool00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00@7oo20000goo0P001Goo0P00
1goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<007ooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l02goo00<007ooOol01goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0029oo`D001Uoo`800003Ool00000
008000Aoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03001oogoo009oo`0400moogoo00l3Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00]oo`03001oogoo00Moo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000POol9
000GOol20009Ool20005Ool20007Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool0100?Oomoo`0?0goo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0:Ool00`00Oomoo`08Ool00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00
7goo0`0000=oo`0000000Woo0`005goo0P0017oo0P000Woo0P001Goo0P001goo00<007oo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00<03`00Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l02Woo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo000YOol001moo`80009oo`8000=oo`8001Moo`8000=oo`<000=oo`80
00=oo`8000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0300l007oo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?00Uoo`03001oogoo00Uoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol20002Ool20003
Ool2000HOol60004Ool70008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Ool00002Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`09Ool00`00Oomoo`09Ool00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo
0P000Woo0P000goo0P006Goo10001Woo1@002Goo0P0000<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo00000Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02Goo00<007oo
Ool02Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000YOol001moo`<00003Ool0000000=oo`80035oo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0600moogoo001oo`0?
0Woo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l027oo00<007ooOol0
2Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol0021oo`D0009oo`80039oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0600moogoo001oo`0?0Woo00D03gooOomo
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l027oo00<007ooOol02Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0029oo`<0
009oo`03001oogoo035oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol0000?0Woo00D03gooOomoo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l01goo00<007ooOol02goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0600moogooOol0000?0Woo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l01goo00<007ooOol02goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol0000?0Woo00D0
3gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l01Woo00<007ooOol037oo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0
029oo`D003Aoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0300moogoo009oo`04001oogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?00Ioo`03001oogoo00aoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000POol9000bOol00`00
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01000Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0500moogooOol03`06Ool00`00Oomoo`0<Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo0`0000=oo`0000000Woo0`00<Goo0P00
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03`00Ool03`=oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l01Goo00<007ooOol03Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lF
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol001moo`80009oo`8000=oo`80035oo`03
001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400l007oo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?00Eoo`03001oogoo00eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000OOol20002Ool20003Ool2000aOol00`00
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Ool0000?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0500moogooOol03`04Ool00`00Oomoo`0>Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`007goo0P000Woo0P000goo0P00<Goo00<007oo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03goo00003`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l017oo00<007ooOol03Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000YOol001moo`<00003Ool0000000=oo`80035oo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0300moogoo009oo`0400moo`0000l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?00Aoo`03001oogoo00ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000POol50002Ool2000bOol00`00Ool03`0EOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`000goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`03Ool00`00Oomoo`0?Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool002Uoo`008Woo0`000Woo00<007ooOol0<Goo00<007oo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol000=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l00goo00<007ooOol03goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo0003
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?009oo`03001oogoo011oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo
001KOol200000`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`0?00000Woo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0500moogooOol03`02Ool00`00Oomoo`0@Ool00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOol03`00009oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1`0?Oomoogoo00moo`0001=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoo`0?
Ool007oo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00@Woo1@001Woo
1@002Goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00P03gooOol03goo001oo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00004goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000YOol0045oo`L000Aoo`L000Qoo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l2Ool00`0000moo`0DOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOomo
o`0?000DOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool002Uoo`00@7oo0`000goo0`000goo0P000goo0P0027oo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`9oo`0300003goo01Aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoogoo00l001Ao
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00
:Goo0010Ool20005Ool20002Ool20005Ool20007Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<007ooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol0000EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00@7oo
0P001Goo0P000Woo0P001Goo0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`03001oogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00005Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0041oo`8000Eoo`80
009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?001o
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00D03gooOol0000?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0010Ool30003Ool30002Ool20005
Ool20007Ool3001:00l00`0000l03`1500l00`0000l03`2C00l00`00Oomoo`0WOol0045oo`L000=o
o`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00D03goo001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0011Ool70003Ool20005Ool20007Ool0
0`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00004goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0500moo`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool002Uoo`00@7oo0`000goo0`000Woo0P001Goo0P001goo00<007oo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0400moogoo000BOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D0
3`00Oomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogoo00moo`00:Goo0010Ool20005Ool20002Ool20005Ool20007Ool00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00@03gooOol0019oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?001oogoo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000YOol0041oo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool0100?Oomoo`004Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500l007ooOol03`0EOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uo
o`00@7oo0`000goo0`000goo0P000goo0P0027oo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0500moogooOol0000AOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D007ooOomoo`0?01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo0011
Ool70004Ool70008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00D03gooOomo
o`00015oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01@00Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0049oo`D000Ioo`D000Uoo`80
000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`02Ool00`00Oomoo`0>
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<0000?Ool00Woo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`02Ool00`00Oomoo`0>Ool00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<0000?Ool00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`03Ool00`00Oomoo`0=Ool00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool02@0?Oomoogoo00moo`00Ool03`03
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moogoo00=oo`03001oogoo00eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0900moogooOol03goo001oo`0?00=oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo
001KOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol017oo00<007oo
Ool037oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00H03gooOomoo`0?0002Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`04Ool00`00Oomoo`0<Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0
009oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moogoo00Aoo`03001oogoo00aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol00003Ool01@0?Oomoogoo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000Y
Ool005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`05Ool00`00
Oomoo`0;Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00000goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol200000`0?Oomoo`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol01Goo00<007ooOol02goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOol0
000?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo00Ioo`03001oogoo00Yoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo00003`03Ool01@0?Oomoogoo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`06Ool0
0`00Oomoo`0:Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Ool007oo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`0E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol01goo00<007ooOol02Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo001o
o`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo00Moo`03001oogoo00Uoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moo`00Ool03`03Ool01@0?Oomoogoo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`08Ool0
0`00Oomoo`08Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?001oogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`0E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol027oo00<007ooOol027oo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03`00Oomo
o`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo00Uoo`03001oogoo00Moo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05001oogooOol03`03Ool01@0?Oomoogoo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol005]oo`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`09
Ool00`00Oomoo`07Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool01P0?Oomoogoo00003`=oo`0500moogooOol03`03Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00Yoo`03001oogoo00Ioo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0600moogooOol0000?0goo
00D03gooOomoo`0?00=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00Ool03`0EOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03gooOol02Woo00<007ooOol01Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l00goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol003Uoo`8000Moo`D000Ioo`D000Uoo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0;Ool00`00Oomoo`05Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool01P0?Oomoo`00Ool03`=oo`0500moogooOol03`03Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool002Uoo`00>Goo0P001Woo1`0017oo1`0027oo00<007oo00l05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo00aoo`03001oogoo00Aoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moo`00009oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000YOol003Uoo`8000Ioo`8000=oo`8000Aoo`8000=oo`8000Qoo`03001oo`0?01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0<Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Ool00002Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0600moogoo00moo`00:Goo000iOol20005Ool20005Ool20002Ool20005Ool20007Ool00`00Ool0
3`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol03Goo00<007ooOol00goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03`00Ool00Woo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00>Goo0P001Goo0P001Goo0P000Woo0P001Goo0P00
1goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00eoo`03001oogoo
00=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300l007oo
009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol003Uoo`8000Eoo`8000Eoo`80009o
o`8000Eoo`8000Moo`<005X03`0300003`0?02D03`0300003`0?0:<03`03001oogoo02Moo`00>Goo
0P001Goo0P001Goo0P000Woo0P001Goo0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo00ioo`03001oogoo009oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`03001oogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol003Uoo`8000Eoo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0?Ool01@00Oomoogoo00l037oo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00Woo00<0000?Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool002Uoo`00>Goo0P001Goo0P001Goo0P000Woo0P001Goo0P001goo00<007oo00l05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo011oo`04001oogoo00l<Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool01`0?Oomoogoo001oo`0?00Aoo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000Y
Ool003Uoo`8000Eoo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0@Ool01000Oomoo`0?37oo00<03gooOol01Woo00<03gooOol0
17oo00@03gooOol0009oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000Y
Ool003Ioo`800003Ool0000000Eoo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0AOol00`00Ool03`0<Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Ool00003Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00:Goo000fOol50005Ool20005Ool20002Ool20005Ool20007Ool00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04Goo00<007oo00l037oo00<03gooOol01Woo00<0
3gooOol017oo00<03goo00000goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool002Uoo`00>7oo0`001Woo0P000goo0P0017oo0P000goo0P0027oo00<007oo00l05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moogoo019oo`0300003goo00]oo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300l007oo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000YOol003Uoo`8000Ioo`L000Aoo`L000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Oomoo`0COol00`00Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`00Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo000iOol20007
Ool50006Ool50009Ool200000`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool04goo00<03`00Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<007ooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moo`0000Yoo`0300moogoo00Ioo`03
00moogoo00=oo`0300003goo00Aoo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0C
Ool0100?Oomoo`002Goo00<03gooOol01Woo00@03gooOomoo`800003Ool03goo00Aoo`0300moogoo
009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol005]oo`03001oo`0?01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol01@0?Oomoogoo000027oo00<03gooOol01Woo
00@03gooOol000=oo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000YOol005]oo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0COol00`0?Oomoo`02Ool00`00Oomoo`05Ool00`0?Oomoo`06Ool00`0?Ool00004Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00:Goo001KOol00`00
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol00goo0P00
1Goo00<03gooOol01Woo00<03`00Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002Uoo`00Fgoo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo01=oo`0300moogoo00Eoo`03001oogoo009oo`0300moogoo00Eoo`8000Io
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000YOol0
05]oo`03001oo`0001Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`00Oomoo`0COol00`0?Oomo
o`06Ool400000`0?Oomoo`02Ool300000goo00moo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0001Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`005Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo001oo`00:Goo001KOol3000EOol00`00Oomoo`0:Ool00`00
Oomoo`06Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000
Oomoo`000goo00<007ooOol04goo00<007ooOol02Woo1@0017oo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000=oo`05001oogooOol0000EOol00`00Oomoo`0:Ool0
0`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0goo00@007ooOol001Ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo009oo`05001oogooOol00003Ool01P00Oomoo`00Ool002Uoo`00Fgooo`00;@00
:Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00=Moo`8000Yoo`8000Aoo`8000=oo`@0009oo`8000Aoo`@0
00Ioo`D00:Moo`00egoo0P002Woo0P0017oo0P000Woo200017oo1P0017oo1`00YWoo003GOol2000:
Ool20004Ool20002Ool20003Ool30003Ool20004Ool20003Ool20004Ool2002UOol00=Moo`8000Yo
o`8000Aoo`80009oo`8000Aoo`8000Uoo`80009oo`800:aoo`00egoo0P002Woo0P0017oo0P000Woo
10000Woo0P001goo10000Woo0P00[7oo003GOol2000:Ool20004Ool20003Ool70004Ool60003Ool9
002UOol00=Moo`P000Aoo`8000Aoo`8000Ioo`@000=oo`@000Ioo`T00:Eoo`00egoo2@000goo0P00
17oo0P0027oo0P000goo0P0027oo0P001Goo0P00YGoo003GOol20005Ool30002Ool30003Ool20002
Ool20004Ool20003Ool20004Ool20003Ool20003Ool2002VOol00=Moo`8000Ioo`80009oo`P0009o
o`P000=oo`L000Aoo`L00:Ioo`00egoo0P001Woo0P000Woo0P0000=oo`0000000P001Goo1@001Woo
10001Woo1@00Ygoo003GOol20006Ool20002Ool2003;Ool00=Moo`8000Eoo`<0009oo`800<]oo`00
egoo2@000goo0P00bgoo003GOol80004Ool2003;Ool00?mook5oo`00ogoo/Goo003oOonaOol00001
\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-3.26698, -34.2778, \
0.0203262, 0.916551}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dewhitening", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Vout/Vin /. sol\) /. {Z1 \[Rule] R, Z2 \[Rule] R, 
          Z3 \[Rule] ser[1\/\(s\ C\), R2], Z4 \[Rule] ser[1\/\(s\ C\), R2], 
          G \[Rule] 1} // Simplify\), "\[IndentingNewLine]", 
    \(\(% /. {R \[Rule] 1, C \[Rule] 1/\((2  \[Pi])\), 
          R2 \[Rule] 0.1};\)\), "\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.01, 100}];\)\)}], "Input"],

Cell[BoxData[
    \(\((1 + C\ R2\ s)\)\^2\/\((1 + C\ \((R + R2)\)\ s)\)\^2\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]1\[InvisibleSpace]" ("\
\[InvisibleSpace]1.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=0) = ", 1, " (", 1.0, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = \
"\[InvisibleSpace]0.008264462809917356`\[InvisibleSpace]" \
("\[InvisibleSpace]0.008264462809917356`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=\[Infinity]) = ", .0082644628099173556, " (", .0082644628099173556,
         ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Poles at = \
"\[InvisibleSpace]\(-0.9090909090909091`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(-0.9090909090909091`\)\[InvisibleSpace]" "\),
      SequenceForm[ 
      "Poles at = ", -.90909090909090906, " and ", -.90909090909090906, " "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]0.9090909090909091`\[InvisibleSpace]" \
("\[InvisibleSpace]0.9090909090909091`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Pole frequency = ", .90909090909090906, " (", .90909090909090906, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.5000000000000001`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.5000000000000001`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Pole Q = ", .50000000000000011, " (", .50000000000000011, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = "\[InvisibleSpace]10.`\
\[InvisibleSpace]" ("\[InvisibleSpace]10.`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero frequency = ", .1*^2, " (", .1*^2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.615522 0.0147709 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .02469 -18 -4.5 ]
[-0.0125 .02469 0 4.5 ]
[-0.0125 .17239 -18 -4.5 ]
[-0.0125 .17239 0 4.5 ]
[-0.0125 .3201 -18 -4.5 ]
[-0.0125 .3201 0 4.5 ]
[-0.0125 .46781 -18 -4.5 ]
[-0.0125 .46781 0 4.5 ]
[-0.0125 .61552 -6 -4.5 ]
[-0.0125 .61552 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -8 ]
[-0.01875 .30902 -18 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .17239 m
1 .17239 L
s
0 .3201 m
1 .3201 L
s
0 .46781 m
1 .46781 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .02469 m
.00625 .02469 L
s
[(-40)] -0.0125 .02469 1 0 Mshowa
0 .17239 m
.00625 .17239 L
s
[(-30)] -0.0125 .17239 1 0 Mshowa
0 .3201 m
.00625 .3201 L
s
[(-20)] -0.0125 .3201 1 0 Mshowa
0 .46781 m
.00625 .46781 L
s
[(-10)] -0.0125 .46781 1 0 Mshowa
0 .61552 m
.00625 .61552 L
s
[(0)] -0.0125 .61552 1 0 Mshowa
.125 Mabswid
0 .05423 m
.00375 .05423 L
s
0 .08377 m
.00375 .08377 L
s
0 .11331 m
.00375 .11331 L
s
0 .14285 m
.00375 .14285 L
s
0 .20194 m
.00375 .20194 L
s
0 .23148 m
.00375 .23148 L
s
0 .26102 m
.00375 .26102 L
s
0 .29056 m
.00375 .29056 L
s
0 .34965 m
.00375 .34965 L
s
0 .37919 m
.00375 .37919 L
s
0 .40873 m
.00375 .40873 L
s
0 .43827 m
.00375 .43827 L
s
0 .49736 m
.00375 .49736 L
s
0 .5269 m
.00375 .5269 L
s
0 .55644 m
.00375 .55644 L
s
0 .58598 m
.00375 .58598 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -93.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .61551 m
.02372 .6155 L
.03955 .61549 L
.05352 .61549 L
.06699 .61547 L
.07854 .61546 L
.08806 .61545 L
.10505 .61543 L
.12005 .61539 L
.13273 .61536 L
.14475 .61532 L
.15518 .61527 L
.16433 .61523 L
.17329 .61518 L
.18125 .61512 L
.18912 .61506 L
.19619 .61499 L
.20257 .61492 L
.20897 .61485 L
.2148 .61477 L
.22066 .61468 L
.22601 .6146 L
.23093 .61451 L
.23592 .61441 L
.24051 .61431 L
.24476 .61421 L
.24909 .6141 L
.25309 .61399 L
s
.25309 .61399 m
.27063 .6134 L
.28646 .61269 L
.30044 .61185 L
.31391 .61082 L
.33497 .60862 L
.35197 .60614 L
.36749 .60315 L
.38058 .59993 L
.39182 .59655 L
.40262 .59268 L
.41208 .58872 L
.42045 .5847 L
.42869 .58024 L
.43607 .57578 L
.4434 .57089 L
.45001 .56605 L
.45601 .5613 L
.46205 .55616 L
.46755 .55115 L
.47311 .54577 L
.4782 .54055 L
.48288 .53551 L
.48765 .53013 L
.49205 .52495 L
.49612 .51998 L
.5 .51506 L
s
.5 .51506 m
.53337 .46648 L
.56082 .41922 L
.58144 .38057 L
.59812 .34806 L
.61342 .3177 L
.62633 .29197 L
.63854 .26776 L
.64912 .24704 L
.65839 .22916 L
.66745 .21205 L
.67551 .1972 L
.68272 .18423 L
.68991 .17167 L
.69639 .16066 L
.70288 .14998 L
.70878 .14058 L
.71417 .13229 L
.71962 .12418 L
.72461 .117 L
.72968 .10997 L
.73435 .10374 L
.73865 .09819 L
.74305 .09273 L
.74691 .0881 L
s
.74691 .0881 m
.76446 .06912 L
.78029 .05478 L
.80773 .03567 L
.82764 .02571 L
.84542 .01902 L
.86013 .01476 L
.87383 .01163 L
.88555 .00947 L
.89574 .00792 L
.90561 .00666 L
.91432 .00571 L
.92208 .00499 L
.92977 .00436 L
.93668 .00387 L
.94357 .00344 L
.94982 .00309 L
.9555 .0028 L
.96123 .00254 L
.96647 .00233 L
.97178 .00213 L
.97665 .00197 L
.98114 .00183 L
.98572 .0017 L
.98995 .00159 L
.99383 .0015 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hWoo0`000Woo0`000Woo1P00_Woo003S
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000_Woo003SOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2oOol00>=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;ioo`00hgoo1P000goo00D007ooOomoo`000;moo`00hgoo00<007ooOol00Woo00@007ooOomoo`H0
0;ioo`00hgoo00<007ooOol00Woo00<007ooOol0aGoo003ROol30002Ool30036Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000iOol40006Ool20006Ool40004Ool7000dOol40006Ool20005Ool7
0010Ool70015Ool70003Ool4000nOol70003Ool40005Ool4000KOol003Qoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Ao
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Qoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03Aoo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol0
03Qoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Ioo`03
001oogoo009oo`03001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03aoo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0HOol003Uoo`@000io
o`@000Moo`03001oogoo03Eoo`@0011oo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0045oo`03001oogoo00Aoo`@000Eoo`@001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo0017Oooo0018000ROol004Moo`03001oo`0001Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0?0002Ool00`00Oomo
o`0POol004Moo`03001oo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0F
Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05
001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`02Ool<0002Ool00`00
Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00=oo`X0009oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo00000`001Goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol003Aoo`@000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`09Ool40009Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00=Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00Moo`80009oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000fOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol017oo0`0017oo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol0039oo`H000=oo`03001oogoo009oo`03001oogoo00Aoo`<001Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0100?Oomoogoo0`00
1goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol002Uoo`H000Aoo`04001oogoo0004Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00@03goo000000Yoo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo000cOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`8000aoo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo000dOol00`00Ool00004Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05Goo0P0000<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Ao
o`03001oo`0000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0COol20002Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo0P001Goo10001goo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?015oo`8000Aoo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l047oo00<007ooOol017oo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0>Ool20007Ool00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00eoo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02goo0P002Woo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0:Ool00`00Oomoo`0:Ool00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Uoo`03001oogoo00]oo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l027oo00<007ooOol037oo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`07Ool00`00Oomoo`0=
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Ioo`03001oogoo
00ioo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l01Goo00<007oo
Ool03goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`04Ool00`00
Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00=oo`03
001oogoo015oo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo
00<007ooOol04Woo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00005Goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogooOol03`005Woo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0000GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOol0000?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoo`0000l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500l00000Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029o
o`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D007oo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@00Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?009oo`0300003goo009oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`0000moo`02Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool02@0?Oomoogoo00moo`00Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01P0?Oomoogoo00l0009oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00000goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool00003Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Ool007oo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500l007ooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03`00Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@00Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300003goo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Ool00003Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol40005Ool40007Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moo`0000=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool003Moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l0
07oo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003Moo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`03001oogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol002Uoo`H000Ioo`8000Aoo`03001o
ogoo009oo`03001oogoo00Aoo`<00=d03`0300003`0?06<03`03001oogoo021oo`00=goo00D007oo
Oomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool03`05Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000gOol01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?
00Eoo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000cOol40005Ool4
0007Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300l007oo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0000moo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300003goo00Aoo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<0
07oo00l01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0100?
Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<007ooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`00Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Ioo`0300003goo00Ioo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Eoo`03001oo`0?00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
17oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol017oo00@007oo
Ool03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Mo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?00Moo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000KOol4000XOol00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0UOol2
00000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0400moogoo0006Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000JOol00`00Oomo
o`02Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`00
8Woo000JOol00`00Oomoo`02Ool00`00Oomoo`0UOol00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol001Moo`04001oogoo0003Ool00`00Oomoo`0VOol00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Moo`T002Moo`03001oo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00@03gooOol0029oo`007goo00<007ooOol09Goo00<007oo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000bOol60004Ool40007Ool00`00Ool03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0039oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool001Qoo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02Woo00<0000?Ool0
27oo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`0067oo2000
57oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo000HOol01000Oomoo`000goo00<007ooOol01goo1P001Woo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo0`00a00?00<0000?00l0O00?00<007oo
Ool087oo000HOol01000Oomoo`000goo00<007ooOol057oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`09Ool00`00
Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000H
Ool01000Oomoo`000goo00<007ooOol047oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol027oo00@007ooOol0
3`Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol001Qoo`04
001oogoo0003Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08Ool01000Oomoo`0?2Goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`006Goo0P0000Ao
o`00000001Aoo`@000Eoo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01goo
00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol01Woo00<007oo
Ool00Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`06Ool00`00
Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Eoo`03
001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
1Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`04Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00Aoo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol00goo00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo009oo`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00D03gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00D0
3gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00@03gooOol0
00Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo
000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00@03gooOol000Yoo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo00002goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03`00Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`00
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03001oogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol0
04Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol057oo00<0000?Ool037oo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`80000300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol04goo00<007oo00l03Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol0
1000Oomoo`0?3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol01000Oomoo`0?
3Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0AOol01@00Oomoogoo00l03Goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0AOol01@00Oomoogoo00l03Goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0@Ool00`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo011oo`03001oogoo009oo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol03goo00<007ooOol00goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo
0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`03001oogoo00Aoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000R
Ool004Moo`80000300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Goo00<007ooOol01Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0=Ool00`00Oomoo`05Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00aoo`03001oogoo00Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`04
00moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol037oo00<007ooOol01Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0;Ool00`00Oomoo`07
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Yoo`03001oogoo
00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol0039oo`L000=oo`@000Moo`03001oo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool02Woo00<007ooOol027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00=Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`09Ool00`00Oomoo`09Ool00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?
Oomoo`008Woo000eOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo00Uoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003Eoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol027oo
00<007ooOol02Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol0029oo`00:Goo1P001Woo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol017oo0`00ZP0?00<0000?00l0UP0?00<007ooOol087oo000eOol00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Moo`03001o
ogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol003Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Woo00<007ooOol037oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
<goo0`001Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`05Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool0100?Oomoo`008Woo000eOol00`00Oomoo`04Ool40007Ool00`00Ool0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo00eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol017oo00<007ooOol03Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`03Ool00`00Oomoo`0?Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool0
0`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo009oo`03001oogoo011oo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol00Woo00<007ooOol047oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00
Agoo0P0000<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool01@0?Oomoogoo00004goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo
00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300l007oo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03`00Ool05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`00Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300003goo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool02@0?
Oomoogoo00moo`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00H03gooOomoo`0?0002Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0000=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03goo
Ool0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogoo00003`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03goo001oo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
001oogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05001oogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00H03gooOomoo`0000l3Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@0
3gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0600moogoo001oo`0?0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool00002
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`8000=oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool200000`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00@03gooOol0029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`06
00moogoo001oo`0?17oo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Mo
o`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool00002Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo00<007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00Woo0P0017oo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool01`0?Oomo
ogoo001oo`0?00Aoo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03`0000000goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03001oo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool20005Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00Agoo0P0000<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo009oo`800003Ool03goo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool0100?Oomoo`008Woo0017Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo00000P00
0goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
27oo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0400moogoo000ROol004Moo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool20006Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00Agoo00<007oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Eoo`80000300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo0017
Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol00goo0P000Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol004Moo`03
001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Ool000030004Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0029oo`00?7oo10001goo00<0
07oo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Qo
o`D000Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Qoo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool0100?Oomoo`008Woo000kOol00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol00goo1@000goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol027oo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0400moogoo000ROol003]o
o`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0@Ool<0008Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`08Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00@03gooOol0
029oo`00>goo00<007ooOol00Woo00<007ooOol017oo00<007oo00005goo00<007ooOol02goo00<0
07ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00<007oo000070001Woo
00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol027oo00<007ooOol017oo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`04001oogoo000ROol003]oo`03
001oogoo009oo`03001oogoo00AoodP000=oo`05001oogooOol00002Ool00`00Oomoo`0FOol00`00
Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo
00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogoo
Ool0000GOol00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00@007ooOol0029oo`00>goo00<007oo
Ool00Woo00<007ooOol017ooo`00B0008Woo000kOol00`00Oomoo`02Ool00`00Oomoo`3oOom^Ool0
03]oo`03001oogoo009oo`03001oogoo0?moofioo`00?7oo1000ogooLGoo003oOonaOol00?mook5o
o`00ogoo/Goo003EOol4003GOol00=Uoo`03001oogoo0=Aoo`00fGoo00<007ooOol0e7oo0031Ool3
0003Ool30003Ool50003Ool300000goo001oo`02Ool30002Ool300000goo000000050005Ool40004
Ool300000goo00000002Ool300000goo00000004Ool4002POol00<9oo`03001oogoo00=oo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20004Ool00`00
Oomoo`02Ool00`00Oomoo`2MOol00<9oo`04001oogoo0002Ool01@00Oomoogoo00000goo00D007oo
Oomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2ROol0
0<9oo`07001oo`00Ool007oo000017oo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`H009moo`00`Woo00L007oo001oo`00Ool00003Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2MOol0
0<9oo`07001oo`00Ool007oo000017oo0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Ao
o`<000Eoo`L0009oo`8000=oo`8000=oo`<00003Ool007oo00Aoo`@00:1oo`00`Woo0P000goo0P00
:7oo00<007ooOol04Woo00<007ooOol0Ygoo0031Ool30003Ool3000WOol00`00Oomoo`0BOol00`00
Oomoo`2WOol00>Uoo`03001oogoo01Uoo`800:Uoo`00jGoo00<007ooOol0a7oo003oOonaOol00?mo
ok5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.91386, -50.355, \
0.0186604, 0.311932}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.246914 0.606824 0.00533625 [
[.00617 -0.0125 -14 -12.5625 ]
[.00617 -0.0125 14 0 ]
[.25309 -0.0125 -11 -12.5625 ]
[.25309 -0.0125 11 0 ]
[.5 -0.0125 -5 -12.5625 ]
[.5 -0.0125 5 0 ]
[.74691 -0.0125 -8 -12.5625 ]
[.74691 -0.0125 8 0 ]
[.99383 -0.0125 -11 -12.5625 ]
[.99383 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .0732 -24 -4.5 ]
[-0.0125 .0732 0 4.5 ]
[-0.0125 .17992 -18 -4.5 ]
[-0.0125 .17992 0 4.5 ]
[-0.0125 .28665 -18 -4.5 ]
[-0.0125 .28665 0 4.5 ]
[-0.0125 .39337 -18 -4.5 ]
[-0.0125 .39337 0 4.5 ]
[-0.0125 .5001 -18 -4.5 ]
[-0.0125 .5001 0 4.5 ]
[-0.0125 .60682 -6 -4.5 ]
[-0.0125 .60682 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -20 ]
[-0.01875 .30902 -24 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .0732 m
1 .0732 L
s
0 .17992 m
1 .17992 L
s
0 .28665 m
1 .28665 L
s
0 .39337 m
1 .39337 L
s
0 .5001 m
1 .5001 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0732 m
.00625 .0732 L
s
[(-100)] -0.0125 .0732 1 0 Mshowa
0 .17992 m
.00625 .17992 L
s
[(-80)] -0.0125 .17992 1 0 Mshowa
0 .28665 m
.00625 .28665 L
s
[(-60)] -0.0125 .28665 1 0 Mshowa
0 .39337 m
.00625 .39337 L
s
[(-40)] -0.0125 .39337 1 0 Mshowa
0 .5001 m
.00625 .5001 L
s
[(-20)] -0.0125 .5001 1 0 Mshowa
0 .60682 m
.00625 .60682 L
s
[(0)] -0.0125 .60682 1 0 Mshowa
.125 Mabswid
0 .09988 m
.00375 .09988 L
s
0 .12656 m
.00375 .12656 L
s
0 .15324 m
.00375 .15324 L
s
0 .2066 m
.00375 .2066 L
s
0 .23329 m
.00375 .23329 L
s
0 .25997 m
.00375 .25997 L
s
0 .31333 m
.00375 .31333 L
s
0 .34001 m
.00375 .34001 L
s
0 .36669 m
.00375 .36669 L
s
0 .42005 m
.00375 .42005 L
s
0 .44674 m
.00375 .44674 L
s
0 .47342 m
.00375 .47342 L
s
0 .52678 m
.00375 .52678 L
s
0 .55346 m
.00375 .55346 L
s
0 .58014 m
.00375 .58014 L
s
0 .04652 m
.00375 .04652 L
s
0 .01984 m
.00375 .01984 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -111.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .54442 m
1 .54442 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .60071 m
.03955 .59848 L
.06699 .59604 L
.08762 .59376 L
.1043 .59156 L
.11959 .58922 L
.1325 .58697 L
.14471 .58458 L
.15529 .58228 L
.16457 .58006 L
.17363 .57771 L
.18168 .57544 L
.1889 .57326 L
.19608 .57094 L
.20256 .56871 L
.20906 .56635 L
.21496 .56407 L
.22034 .56187 L
.22579 .55954 L
.23079 .5573 L
.23585 .55492 L
.24052 .55263 L
.24482 .55042 L
.24922 .54808 L
.25309 .54594 L
s
.25309 .54594 m
.28646 .52403 L
.31391 .50045 L
.33453 .4787 L
.35121 .45818 L
.3665 .43684 L
.37942 .41684 L
.39162 .3962 L
.4022 .37694 L
.41148 .35903 L
.42054 .34066 L
.4286 .32364 L
.43581 .3079 L
.44299 .29181 L
.44948 .27698 L
.45597 .2619 L
.46187 .24803 L
.46726 .23529 L
.4727 .22235 L
.4777 .21049 L
.48277 .19849 L
.48743 .1875 L
.49174 .17743 L
.49613 .16726 L
.5 .15841 L
s
.5 .15841 m
.53337 .08851 L
.54735 .06412 L
.56082 .04411 L
.57211 .03027 L
.58144 .02098 L
.59035 .014 L
.59499 .0111 L
.59911 .00896 L
.60272 .00743 L
.60655 .00614 L
.61027 .00524 L
.61225 .00489 L
.6132 .00476 L
.61408 .00466 L
.61498 .00458 L
.6158 .00452 L
.61623 .00449 L
.6167 .00447 L
.61695 .00446 L
.61719 .00446 L
.61741 .00445 L
.61765 .00444 L
.61805 .00444 L
.61842 .00444 L
.61886 .00444 L
.61926 .00445 L
.61967 .00446 L
.62012 .00448 L
.62093 .00452 L
.62166 .00457 L
.62245 .00465 L
.62404 .00484 L
.6255 .00507 L
.62684 .00532 L
.62985 .00606 L
.63293 .00704 L
.63823 .00927 L
.6436 .01222 L
.64837 .01542 L
.65786 .02338 L
.6671 .03311 L
.67531 .04335 L
.68265 .05372 L
.68994 .06509 L
.69653 .07623 L
.7025 .087 L
.70852 .09843 L
.714 .10934 L
.71954 .12078 L
Mistroke
.72462 .1316 L
.72929 .1418 L
.73404 .15241 L
.73843 .16237 L
.7429 .17266 L
.74691 .182 L
Mfstroke
.74691 .182 m
.78029 .26088 L
.80773 .32286 L
.82836 .36521 L
.84504 .39614 L
.86033 .42174 L
.87324 .44131 L
.88545 .45814 L
.89603 .47147 L
.90531 .48226 L
.91437 .49203 L
.92242 .5001 L
.92964 .50688 L
.93682 .51321 L
.9433 .5186 L
.9498 .5237 L
.9557 .52808 L
.96108 .53189 L
.96653 .53555 L
.97153 .53876 L
.97659 .54187 L
.98126 .54461 L
.98556 .54704 L
.98996 .54942 L
.99383 .55144 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00iWoo0`000Woo0`000Woo1P00^Woo003W
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000^Woo003WOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`2kOol00>Moo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0;Yoo`00igoo1P000goo00D007ooOomoo`000;]oo`00igoo00<007ooOol00Woo00@007ooOomoo`H0
0;Yoo`00igoo00<007ooOol00Woo00<007ooOol0`Goo003VOol30002Ool30032Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000nOol40006Ool20006Ool40004Ool7000cOol40006Ool20005Ool7
0011Ool70015Ool70003Ool4000mOol70003Ool40005Ool4000GOol003eoo`03001oogoo009oo`03
001oogoo00=oo`8000Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo
009oo`03001oogoo00=oo`8000Qoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo
00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eo
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=o
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Eoo`03
001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003eoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo03=oo`03001oogoo009oo`03001o
ogoo00eoo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo03eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol0
03eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo009oo`<003Eoo`03
001oogoo009oo`03001oogoo00]oo`<004Eoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo
03]oo`<000Eoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0DOol003ioo`@000io
o`@000Moo`03001oogoo03Aoo`@0011oo`03001oogoo04Eoo`03001oogoo04Uoo`03001oogoo00Ao
o`@0041oo`03001oogoo00Aoo`@000Eoo`@001Moo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo001;Oooo0018000NOol004]oo`03001oo`0001Qoo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07
Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007oo
Ool001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0goo00L007ooOomoo`00Ool0000NOol004]oo`03001oo`0001Qoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00@007ooOol001Moo`03001oogoo00Qo
o`T000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001o
ogooOol00003Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00L007ooOomoo`00Ool0000NOol0
04]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00Eoo`<000Aoo`0300moogoo009oo`8000=o
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00Aoo`03001oogoo00Eoo`0300moogoo00Aoo`800003
Ool03goo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00=oo`03001oogoo00Ioo`0300moogoo00Ioo`8000Ioo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3aMoo`0400moogooOol20009Ool00`0?Oomoo`07Ool00`0?001oo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0100?Oomoo`002goo00<0
3gooOol01goo00<03goo000017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo000037oo00<03gooOol01goo00@03gooOol0
00=oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300l007oo00aoo`0300moogoo00Moo`0500moogooOol00002Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`00
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool00`00Ool03`06Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lFOol00`0000moo`0=Ool00`0?Oomoo`07
Ool00`0?Oomoo`03Ool00`0000moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0400moogoo00lEOol00`00Ool03`0>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lE
Ool00`00Ool03`0>Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lDOol01000Oomoo`0?3Woo00<0
3gooOol01goo00<03gooOol017oo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?Oomoo`0?4goo00D007ooOomoo`0?00ioo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moo`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03a9oo`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
o`0000Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a9o
o`03001oogoo009oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0400moogoo0003
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lAOol00`00
Oomoo`03Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool01@0?Oomoogoo00000Woo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?47oo00<007oo
Ool017oo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00D03gooOomoo`00009oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03a1oo`03001oogoo
00Aoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo009oo`03001oo`0?
00Aoo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol002eoo`L000=oo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol0
3`moo`03001oogoo00Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
009oo`03001oo`0?00Aoo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l>Ool00`00Oomoo`06
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0000moo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo000`Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo0000
17oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?3Woo00<007ooOol01Woo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<007ooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00<7oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`<00:h03`0300003`0?02h03`0300003`0?06403`03001oogoo01aoo`0097oo1P001Woo00<007oo
Ool00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03`aoo`03001oogoo00Qoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300l007oo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo00=oo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l<Ool00`00Oomo
o`08Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?001o
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000`Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?2goo00<007ooOol02Goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo00000Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`00;Woo0`001Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03`]oo`03001oogoo00Uoo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0031oo`03001oogoo
00Aoo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Yoo`03001oogoo00Yoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0600moogoo001oo`0?17oo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?2Woo00<007ooOol02Woo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00l9Ool00`00Oomoo`0;Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Uoo`03
001oogoo00]oo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`03001oogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
001oogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Qoo`03001oogoo00aoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Moo`03001oogoo00eoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300l007oo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03`Moo`03001oogoo00eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00@03gooOol03`Ioo`03001oogoo00ioo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001o
o`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00@03gooOol03`Ioo`03001oogoo00ioo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0600moogoo001oo`0?0goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
1Goo00<007ooOol03goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00H03gooOol007oo00l3Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00l5Ool00`00Oomoo`0?
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool01P0?Oomoogoo00003`=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03`Aoo`03001oogoo011oo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0600moogooOol0
000?0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?17oo00<007ooOol047oo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?0goo00<007ooOol04Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?0goo00<007ooOol04Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D007ooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?0Woo
00<007ooOol04Woo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03`00Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?0Woo00<007oo
Ool04Woo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03`00Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool01P0?Oomoo`0?Ool001Eoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moo`00Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00H03gooOol03goo000EOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0500moogoo00l0000FOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo00l0000F
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`07
00moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00000goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0400moogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Ool0000?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00H03gooOomoo`0?0002Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol003Moo`@000Eoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo00003aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`06
00moogooOol03`000Woo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000fOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Ool0000?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000fOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`04Ool0100?001oo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000fOol00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?001oo`0?5goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300003goo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001io
o`00;Goo1P0017oo100017oo00<007ooOol00Woo00<007ooOol017oo0`00W@0?00<0000?00l0D00?
00<0000?00l0D00?00<007ooOol077oo000fOol00`00Oomoo`02Ool01@00Oomoogoo000017oo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool01000Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
001oogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00=Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0000?Oomoo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`00Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol003Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500003gooOol03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03`00Ool05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000gOol40005Ool40007Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009o
o`03001oo`0?009oo`0300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?001o
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo
00l00Woo00<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0001Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`00Ool03`02Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo00005Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00L03gooOomoo`0?Ool00002Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0001Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0700moogooOol03goo00000Woo00@03gooOol03aMoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0057oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00H03gooOomo
o`0?0003Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo000D
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l000=oo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0001=oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol00004Ool0100?Oomoo`0?5goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0500moogooOol0000COol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomo
o`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo000017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00004goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Ool0000?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
0Woo00<007ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00Woo00<0
07ooOol047oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOol0000?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol0
3goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol03goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool3000HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol00goo00<007ooOol03goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo001oo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol017oo00<0
07ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Oomoo`02
Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol017oo00<007ooOol03Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03`00Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Goo00<007ooOol03Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000COol01000Oomoo`000goo00<007ooOol0;Woo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo
00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`004goo2@00;goo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Eoo`03001oogoo
00eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`006goo00<007ooOol0;Goo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Ioo`03
001oogoo00aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300003goo009oo`0300mo
ogoo009oo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01Woo
00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00<0
3gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`07
Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`<001Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01`0?Oomoogoo001oo`0?00=oo`0300moogoo009o
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol01goo00<007oo
Ool02goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00L03gooOomoo`00Ool03`03Ool00`0?Oomo
o`02Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Moo`03
001oogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo0000
0Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700mo
ogooOol007oo00l00goo00<03gooOol00Woo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`08Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol001Ioo`03001oo`00009oo`03001oogoo02eoo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol027oo00<007ooOol02Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03gooOol0009oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Uoo`03
001oogoo00Uoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo0000
0Woo00<007ooOol06Woo100017oo10001goo00<007oo00l067oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moo`0000=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo00Uoo`03001oogoo00Uoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`005goo0P0000=oo`00Ool06goo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Ool0
0003Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0:Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool003Moo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03`00Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007ooOol027oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000gOol20003Ool01000Oomoo`0017oo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300l007oo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo00]oo`03001oogoo00Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
5goo10004Woo1P0017oo00<007oo00000P000goo00<007ooOol00Woo00<007ooOol017oo0`00SP0?
00<0000?00l0KP0?00<0000?00l0@@0?00<007ooOol077oo000FOol00`00Oomoo`02Ool01000Oomo
o`0067oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`03001oogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00]oo`03001oogoo00Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007ooOol00Woo00@007ooOol001Uo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0000moo`04Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0<Ool00`00Oomoo`06Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`04001oogoo000JOol00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00Woo00<0000?Ool017oo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol037oo00<007ooOol01Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000GOol01000Oomoo`000goo00<007ooOol06Goo0`000goo1000
1goo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0700moogooOol007oo00l01Goo00D03gooOomo
o`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Goo
00<007ooOol01Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol8000]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool03`05Ool01@0?Oomoogoo00l0
17oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0=Ool00`00
Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo039o
o`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
3Woo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00@03gooOol0009oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00ioo`03
001oogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0?Ool00`00Oomoo`03Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oogoo009oo`03001oogoo02eoo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0@Ool0
0`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`H002moo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?001oo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0@Ool0
0`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Moo`05001oogoo
Ool0000_Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03`00Ool00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol047oo00<007ooOol00Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000F
Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<007oo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol04Goo00D007ooOomoo`0?00eoo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00mo
o`0001ioo`005Woo00<007ooOol00Woo00<007ooOol0;Goo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`03001oogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo015oo`05001oogooOol03`0=Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L0
3gooOomoo`0?Ool0000NOol001Ioo`03001oogoo039oo`03001oo`0?01Qoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0000moo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0BOol01000Oomoo`0?3Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol017oo00<0000?Ool017oo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol04Woo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo
0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01=oo`03001o
o`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
009oo`04001oogoo00l5Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0COol00`00Ool03`0=Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol001Moo`@0031oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomo
o`0?1Goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol057oo00<0000?Ool037oo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo0000
7Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`00
00=oo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Aoo`0300003goo00aoo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`05
00moogooOol00003Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`00Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001oogoo02eoo`03001oo`0?
01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<007oo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo000FOol00`00Ool00002Ool00`00Oomoo`0]Ool0
0`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00@03gooOol000Aoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`005goo0P0000=oo`00Ool0;goo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moo`0000Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00l007oo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
o`0000Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moo`0000]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300l007oo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?001oo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000GOol4000`Ool00`00Ool03`0HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<007ooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00D03gooOomoo`00
00Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`005Woo00<007oo00000Woo00<007ooOol0;Goo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`05
00moogooOol00009Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001o
ogoo02eoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol001Io
o`03001oo`00009oo`03001oogoo01Yoo`@000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000mo
o`06Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool00`00Oomoo`05
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00L03gooOomoo`0?Ool0000NOol001Ioo`03001oo`00009oo`03001oogoo01aoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00L03gooOomoo`0?Ool0000NOol001Moo`800003Ool007oo01ioo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`04Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0
000NOol003Ioo`H000=oo`03001oogoo009oo`03001oogoo00Aoo`<007d03`0300003`0?09003`03
00003`0?03003`03001oogoo01aoo`00;Goo1P0017oo00@007ooOol000Aoo`03001oogoo009oo`03
001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo
000gOol01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00=oo`05
001oogooOol03`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`06Ool0
0`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Qoo`03001oo`0000Aoo`03001oogoo
009oo`03001oogoo00Aoo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol0
3goo00007Woo000hOol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool00Woo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00>Goo0P001Goo10001goo
00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00Moo`05001oogooOol03`09Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03
001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol0
0005Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`08
Ool01000Oomoo`0?2Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00@03gooOol000Ioo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00Uoo`03001oo`0?00Uoo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
o`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo
00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300l007oo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300l007oo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03001oogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moo`00
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00
Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00Uoo`03001oo`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0400moogoo0006Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`09Ool00`00Ool03`09
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03goo
Ool03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
1@0?Oomoogoo00001Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000HOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol027oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0500moogooOol00005Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?
Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol01Woo00<007ooOol00Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?
00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`00
01ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool017oo00<007ooOol017oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol00goo
00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol00Woo00<007oo
Ool01Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00D03gooOomoo`0000Uoo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?
Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo0`0067oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?001oo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol004]oo`03001oo`0?01Qo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?001oo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@0
3gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool0100?Oomoo`0017oo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D0
3gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?Oomo
ogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Aoo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0500moogooOol00003Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
03Ioo`H000Aoo`@000Moo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0DOol00`0000moo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool01000Oomo
o`0?1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000fOol0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01=oo`03001oo`0?00eoo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00=oo`03001oo`0?00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01`0?
Oomoogoo00moo`0001ioo`00=goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<0
07oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo019oo`04001oogoo00l=
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l017oo00@03gooOol03aMoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool20005Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Qoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Aoo`<006@03`0300003`0?0<<03`0300003`0?01H03`03001oogoo01aoo`00;Goo1P00
1Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo011oo`03001oogoo009oo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0
100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01`0?Oomoogoo00moo`0001ioo`00>Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l067oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00mo
o`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`04
00moogoo0002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000NOol0
03Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol03Woo00<007ooOol017oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool03`05Ool01@0?Oomo
ogoo00l00goo00L03gooOomoo`0?Ool0000NOol003Ioo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool037oo0P001goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00Woo00<0000?Ool017oo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000g
Ool40005Ool40007Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool02goo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo0P0017oo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Woo00<007oo
Ool027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03goo00000goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00
Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol02Goo00<007ooOol02Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@0
3gooOol0009oo`0500moogooOol03`03Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l0
67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo00Qoo`03001oogoo00Yoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`04Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700moogoo
Ool007oo00l00goo00D03gooOomoo`0?00=oo`0300moo`0001ioo`00Bgoo0`0067oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo00Ioo`8000eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomo
o`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`8000=oo`0500moogoo
Ool03`03Ool00`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`05Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@00Oomoogoo00l00goo00L03goo
Oomoo`0?Ool0000NOol004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`03Ool2000@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00@03gooOol03aMoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?001oogoo00l00goo00L03gooOomoo`0?Ool0000N
Ool004]oo`03001oo`0?01Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoogoo0P00
4Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03goo0000000?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol001Aoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04
Ool0100?Oomoo`0?5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0400mo
ogooOol20002Ool01`0?Oomoogoo00moo`0001ioo`00Bgoo00<007oo00l067oo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300l0000001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`04Ool0100?Oomoo`0?5goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0900moogooOol03goo001oo`0?00=o
o`0300moo`0001ioo`00Bgooo`00B0007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<0000?Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moo`000000
3goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoogoo0`0000=oo`0?Ool0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol007oo00007Woo001;Ool3000HOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Ool0000000l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?001o
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool000030003Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool20003
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`0200000`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;
Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool40002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`0200000goo00moo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`02Ool60003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool3000H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool000020003Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool0
0`0?Oomoo`06Ool30006Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`0;Ool00`0?0000000600000goo00moo`06Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool0
3`0HOol00`0?Oomoo`07Ool50009Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400mo
ogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0700moogooOol03goo00007Woo001;Ool00`00Ool03`0HOol00`0?Oomoo`02Ool50004Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogoo
Ool03goo00007Woo0010Ool40007Ool00`00Ool03`0?Ool>0009Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00007Woo000oOol0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`05Ool:0009Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool00005000COol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo00lGOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700mo
ogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool3000HOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0400moogoo
00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0700moogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0H
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`04
00moogoo00lGOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0700moogooOol03goo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Ool0000HOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007ooOol02goo
00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007ooOomoo`00
00Aoo`04001oogoo000GOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<0
07ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D0
07ooOomoo`0000=oo`07001oogooOol007oo00007Woo000oOol00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Ool0000HOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol05Goo00<007oo
Ool02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00D007oo
Oomoo`0000Aoo`04001oogoo000GOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol0
5Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
0goo00D007ooOomoo`0000=oo`07001oogooOol007oo00007Woo0010Ool40007Oooo0018000NOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00=Uoo`D000Aoo`<0009oo`<000=oo`D000=oo`D000Eoo`@00:eoo`00fWoo00<0
07ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`2ZOol00=Yoo`03001oogoo00Ioo`03001oogoo009oo`05
001oogooOol00003Ool00`00Oomoo`07Ool01@00Oomoogoo0000/Goo003JOol50004Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool40005Ool40004Ool6002/Ool00=Yoo`03001oogoo009oo`04001oogoo
Ool20003Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo0:Yoo`00fWoo00<007ooOol00Woo00H007ooOomoo`00Ool30005Ool30006Ool5
0004Ool4002]Ool00=Yoo`03001oogoo009oo`05001oogooOol0003<Ool00=Uoo`H000Aoo`03001o
ogoo0<Yoo`00hWoo0P00c7oo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.96984, -137.754, \
0.0186604, 0.863437}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ICS130 Whitening", "Section"],

Cell["Solve for specific pole frequency, zero frequency and gain.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tr = \(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C\), R2], 
            Z2 \[Rule] par[1\/\(s\ C\), R2], Z3 \[Rule] R3, Z4 \[Rule] R4} // 
        Simplify\), "\[IndentingNewLine]", 
    \(Numerator[tr]~Collect~s\), "\[IndentingNewLine]", 
    \(Denominator[tr]~Collect~s\), "\[IndentingNewLine]", 
    \(num = 
      Coefficient[Numerator[tr], s, {0, 1, 2}]\), "\[IndentingNewLine]", 
    \(den = 
      Coefficient[Denominator[tr], s, {0, 1, 2}]\), "\[IndentingNewLine]", 
    \(zeros = Solve[Numerator[tr] \[Equal] 0, s]\), "\[IndentingNewLine]", 
    \(poles = Solve[Denominator[tr] \[Equal] 0, s]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\((G\ R3\ R4\ \((1 + C\ R2\ s)\)\^2)\)/\((\(-R3\)\ R4 - 
            R2\^2\ \((1 + C\ \((R3 - G\ R3 + 2\ R4)\)\ s + 
                  C\^2\ R3\ R4\ s\^2)\) + 
            R2\ \((\(-2\)\ R4 + 
                  R3\ \((\(-1\) + G - 2\ C\ R4\ s)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-G\)\ R3\ R4 - 2\ C\ G\ R2\ R3\ R4\ s - 
      C\^2\ G\ R2\^2\ R3\ R4\ s\^2\)], "Output"],

Cell[BoxData[
    \(\(-R2\^2\) - R2\ R3 + G\ R2\ R3 - 2\ R2\ R4 - 
      R3\ R4 + \((\(-2\)\ C\ R2\ R3\ R4 - 
            C\ R2\^2\ \((R3 - G\ R3 + 2\ R4)\))\)\ s - 
      C\^2\ R2\^2\ R3\ R4\ s\^2\)], "Output"],

Cell[BoxData[
    \({\(-G\)\ R3\ R4, \(-2\)\ C\ G\ R2\ R3\ R4, \(-C\^2\)\ G\ R2\^2\ R3\ R4}\
\)], "Output"],

Cell[BoxData[
    \({\(-R2\^2\) - R2\ R3 + G\ R2\ R3 - 2\ R2\ R4 - 
        R3\ R4, \(-C\)\ R2\^2\ R3 + C\ G\ R2\^2\ R3 - 2\ C\ R2\^2\ R4 - 
        2\ C\ R2\ R3\ R4, \(-C\^2\)\ R2\^2\ R3\ R4}\)], "Output"],

Cell[BoxData[
    \({{s \[Rule] \(-\(1\/\(C\ R2\)\)\)}, {s \[Rule] \(-\(1\/\(C\ \
R2\)\)\)}}\)], "Output"],

Cell[BoxData[
    \({{s \[Rule] \(-\(\(1\/\(2\ C\^2\ R2\^2\ R3\ R4\)\)\((C\ R2\^2\ R3 - 
                C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 2\ C\ R2\ R3\ R4 - 
                C\ R2\^2\ \@\(R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ \
R4 + 4\ R4\^2\))\)\)\)}, {s \[Rule] \(-\(\(1\/\(2\ C\^2\ R2\^2\ R3\ \
R4\)\)\((C\ R2\^2\ R3 - C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 
                2\ C\ R2\ R3\ R4 + 
                C\ R2\^2\ \@\(R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ \
R4 + 4\ R4\^2\))\)\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eq1 = 
        1\/\(C\ R2\) \[Equal] 2  \[Pi]\ zerof;\)\), "\[IndentingNewLine]", 
    \(\(eq2 = 
        R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ R4 + 4\ R4\^2 \[Equal] 
          0\ ;\) (*\ real\ poles\ *) \), "\[IndentingNewLine]", 
    \(\(eq3 = \(1\/\(2\ C\^2\ R2\^2\ R3\ R4\)\) \((C\ R2\^2\ R3 - 
                C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 
                2\ C\ R2\ R3\ R4)\) \[Equal] 
          2\ \[Pi]\ polef;\)\), "\[IndentingNewLine]", 
    \(\(eq4 = G \[Equal] gain;\)\), "\[IndentingNewLine]", 
    \(\(eq5 = C \[Equal] C1;\)\ \  (*\ 
      assume\ a\ value*) \), "\[IndentingNewLine]", 
    \(\(assume = {polef \[Rule] 100, zerof \[Rule] 20, gain \[Rule] 25, 
          C1 \[Rule] 1*^-6};\)\), "\[IndentingNewLine]", 
    \(Rs = 
      Solve[{eq1, eq2, eq3, eq4, eq5} /. assume, {R2, R3, R4}] // 
        N\)}], "Input"],

Cell[BoxData[
    \({{R2 \[Rule] 7957.747154594767`, R4 \[Rule] \(-5968.310365946076`\), 
        R3 \[Rule] \(-663.1455962162306`\)}, {R2 \[Rule] 7957.747154594767`, 
        R4 \[Rule] 7957.747154594767`, 
        R3 \[Rule] 497.35919716217296`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rs = {{}, {R2 \[Rule] 7870. , R4 \[Rule] 7870. , 
          R3 \[Rule] 499. }}\)], "Input"],

Cell[BoxData[
    \({{}, {R2 \[Rule] 7870.`, R4 \[Rule] 7870.`, 
        R3 \[Rule] 499.`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C1\), R2], 
            Z2 \[Rule] par[1\/\(s\ C1\), R2], Z3 \[Rule] R3, Z4 \[Rule] R4, 
            G \[Rule] gain} // Together\) // 
      Simplify\), "\[IndentingNewLine]", 
    \(\(\(% /. assume\) /. 
        Rs\[LeftDoubleBracket]2\[RightDoubleBracket];\)\), "\
\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.1, 1000}];\)\)}], "Input"],

Cell[BoxData[
    \(\(-\(\((gain\ R3\ R4\ \((1 + C1\ R2\ s)\)\^2)\)/\((\(-R3\)\ R4 - 
            R2\^2\ \((1 + C1\ \((R3 - gain\ R3 + 2\ R4)\)\ s + 
                  C1\^2\ R3\ R4\ s\^2)\) + 
            R2\ \((\(-2\)\ R4 + 
                  R3\ \((\(-1\) + gain - 
                        2\ C1\ R4\ s)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]1.028187587571087`\
\[InvisibleSpace]" \
("\[InvisibleSpace]1.028187587571087`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=0) = ", 1.0281875875710871, " (", 1.0281875875710871, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = \
"\[InvisibleSpace]25.000000000000007`\[InvisibleSpace]" \
("\[InvisibleSpace]25.000000000000007`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=\[Infinity]) = ", 25.000000000000007, " (", 25.000000000000007, 
        ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Poles at = "\[InvisibleSpace]\(\(-96.49487526560183`\
\) - 25.153091763849414`\ \[ImaginaryI]\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(\(-96.49487526560183`\) + 
          25.153091763849414`\ \[ImaginaryI]\)\[InvisibleSpace]" "\),
      SequenceForm[ "Poles at = ", 
        Complex[ -96.494875265601834, -25.153091763849414], " and ", 
        Complex[ -96.494875265601834, 25.153091763849414], " "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]\(\(\(99.71930092918164`\)\(\[InvisibleSpace]\)\) + 
          0.`\ \[ImaginaryI]\)\[InvisibleSpace]" \
("\[InvisibleSpace]\(\(\(99.71930092918164`\)\(\[InvisibleSpace]\)\) + 
          0.`\ \[ImaginaryI]\)\[InvisibleSpace]")"\),
      SequenceForm[ "Pole frequency = ", 
        Complex[ 99.719300929181642, 0.0], " (", 
        Complex[ 99.719300929181642, 0.0], ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.5167077560062365`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.5167077560062365`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Pole Q = ", .51670775600623653, " (", .51670775600623653, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = \
"\[InvisibleSpace]20.22299149833486`\[InvisibleSpace]" \
("\[InvisibleSpace]20.22299149833486`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Zero frequency = ", 20.22299149833486, " (", 20.22299149833486, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253086 0.246914 0.0122332 0.0216554 [
[.00617 -0.0125 -11 -12.5625 ]
[.00617 -0.0125 11 0 ]
[.25309 -0.0125 -5 -12.5625 ]
[.25309 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.74691 -0.0125 -11 -12.5625 ]
[.74691 -0.0125 11 0 ]
[.99383 -0.0125 -14 -12.5625 ]
[.99383 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .01223 -6 -4.5 ]
[-0.0125 .01223 0 4.5 ]
[-0.0125 .12051 -6 -4.5 ]
[-0.0125 .12051 0 4.5 ]
[-0.0125 .22879 -12 -4.5 ]
[-0.0125 .22879 0 4.5 ]
[-0.0125 .33706 -12 -4.5 ]
[-0.0125 .33706 0 4.5 ]
[-0.0125 .44534 -12 -4.5 ]
[-0.0125 .44534 0 4.5 ]
[-0.0125 .55362 -12 -4.5 ]
[-0.0125 .55362 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -8 ]
[-0.01875 .30902 -12 8 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29 0 ]
[.5 .63053 29 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12051 m
1 .12051 L
s
0 .22879 m
1 .22879 L
s
0 .33706 m
1 .33706 L
s
0 .44534 m
1 .44534 L
s
0 .55362 m
1 .55362 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01223 m
.00625 .01223 L
s
[(0)] -0.0125 .01223 1 0 Mshowa
0 .12051 m
.00625 .12051 L
s
[(5)] -0.0125 .12051 1 0 Mshowa
0 .22879 m
.00625 .22879 L
s
[(10)] -0.0125 .22879 1 0 Mshowa
0 .33706 m
.00625 .33706 L
s
[(15)] -0.0125 .33706 1 0 Mshowa
0 .44534 m
.00625 .44534 L
s
[(20)] -0.0125 .44534 1 0 Mshowa
0 .55362 m
.00625 .55362 L
s
[(25)] -0.0125 .55362 1 0 Mshowa
.125 Mabswid
0 .03389 m
.00375 .03389 L
s
0 .05554 m
.00375 .05554 L
s
0 .0772 m
.00375 .0772 L
s
0 .09885 m
.00375 .09885 L
s
0 .14217 m
.00375 .14217 L
s
0 .16382 m
.00375 .16382 L
s
0 .18548 m
.00375 .18548 L
s
0 .20713 m
.00375 .20713 L
s
0 .25044 m
.00375 .25044 L
s
0 .2721 m
.00375 .2721 L
s
0 .29375 m
.00375 .29375 L
s
0 .31541 m
.00375 .31541 L
s
0 .35872 m
.00375 .35872 L
s
0 .38037 m
.00375 .38037 L
s
0 .40203 m
.00375 .40203 L
s
0 .42369 m
.00375 .42369 L
s
0 .467 m
.00375 .467 L
s
0 .48865 m
.00375 .48865 L
s
0 .51031 m
.00375 .51031 L
s
0 .53196 m
.00375 .53196 L
s
0 .57527 m
.00375 .57527 L
s
0 .59693 m
.00375 .59693 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -87.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
69 10.2813 translate
90 rotate
-69 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
117.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .01747 m
.02372 .01747 L
.03955 .01747 L
.05352 .01747 L
.06699 .01748 L
.07854 .01748 L
.08806 .01748 L
.10505 .01749 L
.12005 .0175 L
.13273 .01751 L
.14475 .01752 L
.15518 .01753 L
.16433 .01755 L
.17329 .01756 L
.18125 .01758 L
.18912 .0176 L
.19619 .01762 L
.20257 .01763 L
.20897 .01766 L
.2148 .01768 L
.22066 .0177 L
.22601 .01773 L
.23093 .01775 L
.23592 .01778 L
.24051 .01781 L
.24476 .01784 L
.24909 .01787 L
.25309 .0179 L
s
.25309 .0179 m
.27063 .01808 L
.28646 .01829 L
.30044 .01853 L
.31391 .01884 L
.33497 .01949 L
.35197 .02024 L
.36749 .02117 L
.38058 .02218 L
.39182 .02326 L
.40262 .02453 L
.41208 .02586 L
.42045 .02724 L
.42869 .02881 L
.43607 .03043 L
.4434 .03225 L
.45001 .0341 L
.45601 .03597 L
.46205 .03805 L
.46755 .04013 L
.47311 .04244 L
.4782 .04474 L
.48288 .04703 L
.48765 .04954 L
.49205 .05202 L
.49612 .05448 L
.5 .05696 L
s
.5 .05696 m
.51754 .07011 L
.53337 .08503 L
.56082 .11874 L
.58072 .14986 L
.5985 .18227 L
.61321 .21205 L
.62691 .24177 L
.63864 .26837 L
.64882 .29209 L
.65869 .31537 L
.66741 .33601 L
.67517 .3543 L
.68285 .37224 L
.68977 .38812 L
.69666 .40364 L
.7029 .41738 L
.70858 .42957 L
.71432 .44152 L
.71956 .45213 L
.72487 .46251 L
.72974 .47173 L
.73423 .47994 L
.73881 .48802 L
.74304 .49521 L
.74691 .50156 L
s
.74691 .50156 m
.76446 .5275 L
.78029 .54693 L
.80773 .57245 L
.82764 .5855 L
.84542 .59413 L
.86013 .59957 L
.87383 .60353 L
.88555 .60625 L
.89574 .60819 L
.90561 .60976 L
.91432 .61093 L
.92208 .61183 L
.92977 .61261 L
.93668 .61322 L
.94357 .61375 L
.94982 .61418 L
.9555 .61453 L
.96123 .61485 L
.96647 .61511 L
.97178 .61536 L
.97665 .61556 L
.98114 .61573 L
.98572 .61589 L
.98995 .61603 L
.99383 .61614 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00fgoo0`000Woo0`000Woo1P00aGoo003L
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000aGoo003LOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`36Ool00=aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0<Eoo`00g7oo1P000goo00D007ooOomoo`000<Ioo`00g7oo00<007ooOol00Woo00@007ooOomoo`H0
0<Eoo`00g7oo00<007ooOol00Woo00<007ooOol0c7oo003KOol30002Ool3003=Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000gOol40006Ool20005Ool70010Ool70015Ool70003Ool4000nOol7
0003Ool40005Ool4000eOol70003Ool40005Ool40005Ool4000MOol003Ioo`03001oogoo009oo`03
001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0A7oo00<0
07ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol00goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03Eoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol06Woo000fOol00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0=Goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol0A7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0?Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
03Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol06Woo000fOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomo
o`19Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03
001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo03aoo`<000Eoo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0cOol30005Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=goo100047oo00<007ooOol0
A7oo00<007ooOol0BGoo00<007ooOol017oo1000@Goo00<007ooOol017oo10001Goo1000>7oo00<0
07ooOol017oo10001Goo10001Goo10007Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol0041oool004P002Uoo`00=Goo10001goo00<007oo00005goo
00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Ool0000YOol003Aoo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomo
o`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo0000:Goo000dOol00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
=7oo00<007ooOol00Woo00<007ooOol017oo0`005goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol003Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo000dOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0001Q0007
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000dOol0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol03Woo5P002Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00=7oo00<007oo
Ool00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300l0000000T000Ioo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Eoo`@0
00Moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Ool0000500000`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo1@0000=oo`0?Ool017oo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo009oo`@000=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`0200000goo00moo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool30002Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Ool0000000l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00@03gooOomoo`80
009oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0900moogooOol03goo001oo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?009oo`<0009oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moo`0000003`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00005goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?008001Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`02Ool00`00Oomoo`0BOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l00goo0P004Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?00Eoo`03001oogoo00moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`06Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l01goo00<007ooOol03Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?00Qoo`03001oogoo00aoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`09Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l02Woo00<007ooOol02Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?00]oo`03001oogoo00Uoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0<Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l037oo00<007ooOol027oo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00eoo`03001oogoo00Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0>Ool00`00Oomoo`06Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03goo00<007ooOol01Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?011oo`03001oogoo00Aoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo000eOol40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0AOol00`00Oomoo`03Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00=7oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l04Goo00<007ooOol00goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Uoo`03001oogoo00Ao
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?019oo`03001oogoo009oo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000i
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0COol01@00Oomoogoo00l03Goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool003Uoo`03001oogoo00Aoo`<00;D03`0300003`0?08/03`03001oogoo02Moo`00=Goo10001goo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l057oo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000eOol00`00Oomoo`08
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0EOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00=Goo00<007ooOol0
27oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05Goo00<007oo00l03Goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Eoo`D000Ioo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Ioo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`00Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<007ooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300l007oo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?001oo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo00002goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00@03gooOol000Yoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
1@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0500moogoo
Ool00009Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00Woo
00<007ooOol01Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo009o
o`03001oogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`03
Ool00`00Oomoo`05Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
0goo00<007ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00Aoo`03001oogoo00Aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`04Ool00`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool01Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Qoo`04
001oogoo00l9Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol027oo00@007ooOol03`Uo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`09Ool00`00Ool03`09Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03goo
Ool05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0:Ool00`0000moo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00:goo1`000goo10001goo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<007ooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000^Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00;Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03`00Ool01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002ioo`03001oogoo00=oo`03001oogoo009o
o`03001oogoo00Aoo`<00<L03`0300003`0?07T03`03001oogoo02Moo`00;Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03goo00001goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Mo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool30005Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002ioo`03
001oogoo00Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0400moogoo
0006Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00@03gooOol000Ioo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool01@0?Oomoogoo00001Goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo
01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`03
00moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo
Oomoo`0?01Moo`0300moogoo00]oo`0300moogoo009oo`03001oogoo009oo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00=oo`05001oogooOol03`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol017oo00@007ooOol03`Moo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`04Ool01000Oomoo`0?1goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Aoo`04001oogoo00l7Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01Goo00<007oo
00l01goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Eoo`03001oo`0?00Moo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`06Ool00`0000moo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01Woo00<0000?Ool01Woo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol001eoo`@001moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`03001oogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo000LOol00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007ooOol00Woo00<007ooOol077oo0P0000<0
3gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<007ooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oogoo009oo`03
001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00l007oo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000IOol0
1000Oomoo`000goo00<007ooOol07Goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03`00Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol001Uoo`T001ioo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moo`0000Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo000QOol00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00@0
3gooOol000Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0100?Oomoo`0017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001Yoo`03001oogoo00Ao
o`03001oogoo01aoo`80000300moogoo01Eoo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0500moogooOol00003Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`006Woo20007Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00D03gooOomoo`0000=oo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo000JOol01000Oomoo`000goo00<007ooOol077oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol00Woo00@007ooOol03`Ioo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo000JOol01000Oomoo`000goo00<007ooOol077oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00Woo00@007ooOol03`Io
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000JOol01000Oomoo`000goo00<007ooOol0
1goo1`000goo10001goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol00Woo00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000JOol01000Oomoo`000goo00<007ooOol02Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool00Woo00@007ooOol03`Ioo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000KOol20000
17oo000000003Goo00<007ooOol027oo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l01Woo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol002ioo`03001oogoo00Qoo`03001oogoo00Aoo`<00=H03`030000
3`0?06X03`03001oogoo02Moo`00;Woo00<007ooOol027oo00<007ooOol017oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l01Woo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002ioo`03001oogoo00Aoo`@000Moo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`030000
3goo00Eoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000^Ool00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0000moo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;7oo0`00
1Woo00<007ooOol027oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<007ooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
02ioo`03001oogoo00Aoo`D000Ioo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`03001oogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?001oo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03`00Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moo`00
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Ool00004Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00@03gooOol000=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool0100?Oomoo`000goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0500moogooOol00002Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00D03gooOomoo`00009oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool20000
0`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`00Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00Woo
00<007oo00l017oo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300003goo00=o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<0000?Ool00goo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`00Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3`00Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300l007oo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?001oo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moo`00009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool01P0?Oomoo`00Ool03`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoo`00Ool03`Ao
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool01P0?Oomoogoo00003`Aoo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<007oo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol002]oo`H000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300l0
07oo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo000]Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3003V00l00`00
00l03`1J00l00`00Oomoo`0WOol002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000_Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?Oomoo`00
Ool03`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00H03gooOol007oo00l3Ool0100?Oomoo`0?67oo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00:goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0600moogooOol0000?0goo00@03gooOol03aQoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`@000Eoo`@000Moo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0600moogooOol0000?0goo00@03gooOol03aQoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`05001oogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?001oogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03`00Oomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0
041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moo`00Ool03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Ool007oo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOol0000?009oo`0300moogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogoo00003`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00000Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?
001oo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?001oo`0?67oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00P03gooOomoo`0?Ool0000?67oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00P03goo
Oomoo`0?Ool0000?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00P03gooOomoo`0?Ool0000?67oo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03goo
Ool037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo
00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03001oogoo01Ioo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?001oo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03`00Ool05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moo`0001Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0100?Oomo
o`005Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500moogooOol0000DOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0001Aoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`02Ool00`00Oomoo`0AOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol00goo00<007ooOol047oo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Aoo`03001oogoo00moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`05Ool00`00Oomoo`0>Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol01Goo00<007ooOol03Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Ioo`03001oogoo00eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002]oo`H000Aoo`@000Moo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`07
Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000[Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Qoo`03001oogoo00]oo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`09Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000]Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol02Woo00<007ooOol02Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00;Woo00<007ooOol027oo00<007ooOol017oo0`00oP0?
00<0000?00l0@P0?00<007ooOol09goo000_Ool00`00Oomoo`03Ool40007Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol037oo00<007ooOol0
1goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00:goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol027oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo00eoo`03001oogoo00Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol002]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qo
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0>Ool00`00Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/
Ool40005Ool50006Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol03goo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo011oo`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0AOol00`00Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol04Woo0P000Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Aoo`80000300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000Y
Ool0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol2000<Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
00002goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo008000Uoo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`02Ool20007Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol017oo0P001Goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Ioo`8000=oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`08Ool40009Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool05Woo00<03gooOol02goo00<03`0000000P001Goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo009oo`L000Ioo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Ool0000400000goo00moo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0000GOol00`00Oomoo`0<Ool00`00Oomoo`07
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo
00000goo00<007ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;
Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01@00Oomoogoo00000Woo00<007ooOol05Woo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool017oo3@0017oo00D007ooOomoo`0000=oo`03001oo`0002Uoo`00@7oo00<007oo00005goo00<0
07ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo00Mo
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomo
ogoo00005goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo00]o
o`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`h00003Ool007oo
02Qoo`00@7ooo`00B000:Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003>Ool4003NOol00=9oo`03001oogoo0=]oo`00dWoo00<007ooOol0fgoo002jOol30003
Ool30003Ool50003Ool300000goo001oo`02Ool30002Ool300000goo000000050005Ool40004Ool3
00000goo00000002Ool300000goo00000004Ool4002WOol00;]oo`03001oogoo00=oo`05001oogoo
Ool00003Ool01@00Oomoogoo00000goo0P0017oo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol00Woo00@007ooOol000=oo`80009oo`04001oogooOol20004Ool00`00Oomo
o`02Ool00`00Oomoo`2TOol00;]oo`04001oogoo0002Ool01@00Oomoogoo00000goo00D007ooOomo
o`0000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`2YOol00;]o
o`07001oo`00Ool007oo000017oo10000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo009oo`H00:Ioo`00^goo00L007oo001oo`00Ool00003Ool01@00Oomoogoo0000
0goo00@007ooOomoo`8000Aoo`8000=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo009oo`04001oogoo0003Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`2TOol00;]o
o`07001oo`00Ool007oo000017oo0`001Goo0`0000=oo`0000000Woo0P0000Aoo`00000000Aoo`<0
00Eoo`L0009oo`8000=oo`8000=oo`<00003Ool007oo00Aoo`@00:Moo`00^goo0P000goo0P00:7oo
00<007ooOol04Woo00<007ooOol0[Woo002jOol30003Ool3000WOol00`00Oomoo`0BOol00`00Oomo
o`2^Ool00>9oo`03001oogoo01Uoo`800;1oo`00hWoo00<007ooOol0bgoo003oOonaOol00?mook5o
o`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.82989, -6.488, 0.0186604, \
0.212765}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253086 0.246914 0.0119953 0.00716476 [
[.00617 -0.0125 -11 -12.5625 ]
[.00617 -0.0125 11 0 ]
[.25309 -0.0125 -5 -12.5625 ]
[.25309 -0.0125 5 0 ]
[.5 -0.0125 -8 -12.5625 ]
[.5 -0.0125 8 0 ]
[.74691 -0.0125 -11 -12.5625 ]
[.74691 -0.0125 11 0 ]
[.99383 -0.0125 -14 -12.5625 ]
[.99383 -0.0125 14 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -8 -25.125 ]
[.5 -0.0125 8 -12.5625 ]
[-0.0125 .012 -6 -4.5 ]
[-0.0125 .012 0 4.5 ]
[-0.0125 .15529 -12 -4.5 ]
[-0.0125 .15529 0 4.5 ]
[-0.0125 .29859 -12 -4.5 ]
[-0.0125 .29859 0 4.5 ]
[-0.0125 .44188 -12 -4.5 ]
[-0.0125 .44188 0 4.5 ]
[-0.0125 .58518 -12 -4.5 ]
[-0.0125 .58518 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24.5625 -20 ]
[-0.01875 .30902 -12 20 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12.5625 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .15529 m
1 .15529 L
s
0 .29859 m
1 .29859 L
s
0 .44188 m
1 .44188 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
81.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
87.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -69 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
75.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .012 m
.00625 .012 L
s
[(0)] -0.0125 .012 1 0 Mshowa
0 .15529 m
.00625 .15529 L
s
[(20)] -0.0125 .15529 1 0 Mshowa
0 .29859 m
.00625 .29859 L
s
[(40)] -0.0125 .29859 1 0 Mshowa
0 .44188 m
.00625 .44188 L
s
[(60)] -0.0125 .44188 1 0 Mshowa
0 .58518 m
.00625 .58518 L
s
[(80)] -0.0125 .58518 1 0 Mshowa
.125 Mabswid
0 .04782 m
.00375 .04782 L
s
0 .08364 m
.00375 .08364 L
s
0 .11947 m
.00375 .11947 L
s
0 .19111 m
.00375 .19111 L
s
0 .22694 m
.00375 .22694 L
s
0 .26276 m
.00375 .26276 L
s
0 .33441 m
.00375 .33441 L
s
0 .37023 m
.00375 .37023 L
s
0 .40606 m
.00375 .40606 L
s
0 .4777 m
.00375 .4777 L
s
0 .51353 m
.00375 .51353 L
s
0 .54935 m
.00375 .54935 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -99.2813 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
81 10.2813 translate
90 rotate
-81 -10.2813 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
99.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
93.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .01526 m
.03955 .01645 L
.06699 .01775 L
.08762 .01897 L
.1043 .02014 L
.11959 .02139 L
.1325 .02259 L
.14471 .02387 L
.15529 .0251 L
.16457 .02629 L
.17363 .02754 L
.18168 .02876 L
.1889 .02992 L
.19608 .03116 L
.20256 .03236 L
.20906 .03363 L
.21496 .03485 L
.22034 .03603 L
.22579 .03728 L
.23079 .03848 L
.23585 .03976 L
.24052 .04099 L
.24482 .04218 L
.24922 .04344 L
.25309 .04459 L
s
.25309 .04459 m
.28646 .05646 L
.31391 .06935 L
.33453 .08142 L
.35121 .09296 L
.3665 .10519 L
.37942 .11688 L
.39162 .12921 L
.4022 .141 L
.41148 .15224 L
.42054 .16408 L
.4286 .17537 L
.43581 .1861 L
.44299 .1974 L
.44948 .20814 L
.45597 .2194 L
.46187 .2301 L
.46726 .24025 L
.4727 .25088 L
.4777 .26096 L
.48277 .27149 L
.48743 .28146 L
.49174 .29088 L
.49613 .30073 L
.5 .30956 L
s
.5 .30956 m
.53337 .39124 L
.56082 .46134 L
.58144 .51115 L
.59812 .54685 L
.61342 .57421 L
.62633 .59231 L
.63236 .59898 L
.63854 .60457 L
.64417 .60852 L
.64675 .60996 L
.64912 .61107 L
.65155 .612 L
.65374 .61265 L
.65488 .61292 L
.65611 .61316 L
.65678 .61327 L
.6574 .61335 L
.65803 .61342 L
.65861 .61348 L
.65918 .61352 L
.65946 .61353 L
.65977 .61355 L
.66009 .61356 L
.66026 .61356 L
.66042 .61356 L
.66057 .61356 L
.66073 .61356 L
.66102 .61356 L
.66129 .61356 L
.66159 .61355 L
.66173 .61355 L
.66189 .61354 L
.66218 .61353 L
.66274 .6135 L
.66325 .61345 L
.6642 .61335 L
.66523 .6132 L
.66728 .61279 L
.66945 .61219 L
.67138 .6115 L
.67559 .60954 L
.67931 .60727 L
.68319 .60436 L
.69045 .59751 L
.69701 .58978 L
.70296 .58155 L
.70894 .57215 L
.71441 .56266 L
.71993 .55226 L
Mistroke
.72499 .54205 L
.72964 .53214 L
.73438 .52159 L
.73875 .51149 L
.74321 .50085 L
.74691 .49181 L
Mfstroke
.74691 .49181 m
.78029 .40526 L
.80773 .33481 L
.82836 .2863 L
.84504 .25088 L
.86033 .2216 L
.87324 .19927 L
.88545 .1801 L
.89603 .16494 L
.90531 .15269 L
.91437 .14161 L
.92242 .13245 L
.92964 .12478 L
.93682 .11761 L
.9433 .11151 L
.9498 .10575 L
.9557 .1008 L
.96108 .0965 L
.96653 .09235 L
.97153 .08873 L
.97659 .08522 L
.98126 .08213 L
.98556 .07939 L
.98996 .0767 L
.99383 .07442 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00fgoo0`000Woo0`000Woo1P00aGoo003L
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo0000aGoo003LOol00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`36Ool00=aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
0<Eoo`00g7oo1P000goo00D007ooOomoo`000<Ioo`00g7oo00<007ooOol00Woo00@007ooOomoo`H0
0<Eoo`00g7oo00<007ooOol00Woo00<007ooOol0c7oo003KOol30002Ool3003=Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo000gOol40006Ool20005Ool70010Ool70015Ool70003Ool4000nOol7
0003Ool40005Ool4000eOol70003Ool40005Ool40005Ool4000MOol003Ioo`03001oogoo009oo`03
001oogoo00=oo`8000Qoo`03001oogoo04Aoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo03ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0A7oo00<0
07ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol00goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo03Eoo`03001oogoo00=oo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol06Woo000fOol00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool0=Goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03001oogoo00eoo`03001oogoo04Aoo`03001o
ogoo04Uoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03ioo`03001oogoo00=oo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=Woo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol0A7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol0?Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo
03Eoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol06Woo000fOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`14Ool00`00Oomo
o`19Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol0=Goo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0JOol003Ioo`03001oogoo009oo`03
001oogoo00]oo`<004Aoo`<004Uoo`<000Eoo`03001oogoo009oo`03001oogoo03aoo`<000Eoo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`0cOol30005Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo01Yoo`00=goo100047oo00<007ooOol0
A7oo00<007ooOol0BGoo00<007ooOol017oo1000@Goo00<007ooOol017oo10001Goo1000>7oo00<0
07ooOol017oo10001Goo10001Goo10007Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol0041oool004P002Uoo`00=Goo10001goo00<007oo00005goo
00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Ool0000YOol003Aoo`03001oogoo009oo`03001oogoo00Ao
o`03001oo`0001Moo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`0EOol00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0001Moo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomo
o`0FOol00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo0000:Goo000dOol00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
=7oo00<007ooOol00Woo00<007ooOol017oo0`005goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol003Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0000D0019oo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo000dOol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`05
OolB00000`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00=7oo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo3`0000<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol003Aoo`03001oogoo009oo`03
001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`P0009oo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000eOol40007Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`05Ool900000`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo1@000Woo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo009oo`H00003Ool03goo00=oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool0100?Oomoogoo10000Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo00D00003Ool03goo009oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
00<0009oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0600moogooOol03goo10005Woo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P00
00<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moo`00000DOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOomoo`<0015oo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`04Ool2000?Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol01Woo0`0037oo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo00Uoo`8000Yoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0;Ool20008Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol03Goo0P001Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo00moo`8000Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0AOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol04goo
0P0000<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00H03gooOomoo`0?Ool300000goo001oo`0XOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol2000<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<0
3gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moo`0000]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomo
ogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol00003Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`020009Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Ool0000000l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol00Woo00<007ooOol01Woo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo0P00
0Woo00L03gooOomoo`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`03Ool20006Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`=oo`0700mo
ogooOol03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol01Goo00<007ooOol00goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00H03gooOol007oo00l3Ool01`0?Oomo
ogoo00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moo`00009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`07Ool20002Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool20003Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02Goo00<007oo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00H03gooOomoo`0000l4Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02Woo00<0000?
Ool027oo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00H03gooOol007oo00l4Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<007ooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03goo00000Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300l0000000Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<007ooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0500moogooOol00005Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0000moo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol00Woo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00
Ool03`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol00goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Io
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0400moogoo0002Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
17oo00@007ooOol03`Moo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moo`0000=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool0
3`07Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Ool00003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03`00Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Ioo`0300003goo00Ioo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`8000Eo
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`00Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool00`00Ool03`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000[Ool60004Ool40007Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03`00Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol00Woo00@007ooOol03`Eoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002]oo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03`00Ool01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00D0
3gooOomoo`0000=oo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol002aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Ool00005Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool01@0?Oomoogoo00000goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;Goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0400moogoo0004Ool00`0?
Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0100?
Oomoo`0017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00;Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo0`00Q00?
00<0000?00l0W00?00<0000?00l07@0?00<007ooOol09goo000_Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00D03gooOomoo`0000=oo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300l007oo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol002]oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol00Woo00@007ooOol03`Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300l007oo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002]oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol00goo00<007oo00l01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<007ooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`00;7oo10001Goo10001goo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Aoo`0300003goo00Ao
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Ioo`0300003goo00Io
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02
Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`00Ool03`07Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03`00Ool00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02goo00<03gooOol01Goo00<007oo00l01goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300l007oo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?
Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo
00]oo`0300moogoo00Aoo`04001oogoo00l7Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03goo00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool00goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Ool00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`02Ool0
0`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00@03gooOol0009oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo009o
o`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool0100?Oomoo`000Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00D03gooOomo
o`0000Eoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol0041oo`80000300moogoo01Eoo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
1`0?Oomoogoo001oo`0?00Eoo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0400moogoo0006Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00L03gooOomoo`00Ool0
3`05Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool0100?Oomoo`001Woo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo009oo`0300003goo00Aoo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300mo
ogoo01Ioo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`00Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`0;Ool00`0?001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03`00Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol0
3`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<0
3`00Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`03
00moogoo00=oo`0300moo`0000=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`03001oogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Ool00003Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00@03gooOol0009o
o`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00Yoo`0300003goo00Qoo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0100?Oomoo`000Woo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03gooOol02Woo00<0000?Ool027oo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo
00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0700moogooOol007oo00l00goo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`09Ool00`00Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`09Ool00`00Ool03`09Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<0000?Ool00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomo
o`08Ool01000Oomoo`0?2Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05001oogooOol03`03Ool01@0?Oomoogoo00l0
5goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Qoo`04001o
ogoo00l9Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo000MOol4000OOol00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D007ooOomoo`0?00=oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol01goo00D007ooOomo
o`0?00Uoo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oogoo009oo`03001oogoo01aoo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@00Oomoogoo00l00goo
00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?
Oomoo`07Ool01@00Oomoogoo00l02Goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007ooOol00Woo00<0
07ooOol077oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500l007ooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moogoo00Ioo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol001aoo`03001oogoo009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?001oogoo00l00goo00D03gooOomoo`0?01Moo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`06Ool00`00Oomoo`02
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000IOol01000Oomoo`000goo00<007ooOol07Goo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moo`00
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo
01Ioo`0300moogoo00Eoo`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001Uo
o`T001ioo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Ool007oo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`05Ool00`00Oomoo`03Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo000QOol00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOol0000?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol017oo00<007ooOol017oo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol00003Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00Aoo`03001oogoo00Aoo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00000goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`03Ool00`00Oomoo`05Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00H03gooOomoo`0?0002Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00=oo`03001oogoo00Eoo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol001eoo`@001moo`80000300moogoo01Eoo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l0009oo`0500moogooOol03`0GOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol00Woo00<007ooOol0
1Woo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007oo00000Woo00<007ooOol077oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0600moogoo
Ool03`000Woo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomo
o`0FOol00`0?Oomoo`02Ool00`00Oomoo`06Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000L
Ool00`00Ool00002Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00T03gooOomoo`0?Ool007oo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0500moogooOol00009Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00Oomoo`0LOol00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00T03gooOomoo`0?Ool007oo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0500mo
ogooOol00009Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00
Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?009oo`0300003goo009oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0FOol01@0?Oomoogoo00002Goo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`00
02Uoo`007Goo0P0000=oo`00Ool07Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`02Ool00`0000moo`02Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00@03gooOol000Yoo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D007ooOomoo`0?01Moo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0FOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo
01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
00=oo`0500moogooOol03`03Ool01@00Oomoogoo00l05goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
009oo`0300moogoo01Ioo`0300moo`0000]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001eo
o`@000aoo`@000Aoo`@000Moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03`00Oomoo`0?01Moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`02Ool00`0?Oomoo`0FOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo000LOol00`00Oomoo`02Ool01000Oomoo`002Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=o
o`0500moogooOol03`03Ool01@0?001oogoo00l05goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo01Ioo`0300moo`0000]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03
001oogoo009oo`04001oogoo000:Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moo`00Ool03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
5Woo00<03`00Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`0077oo00<007ooOol00Woo
00@007ooOol000Ioo`H000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03goo001o
o`0?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?001oo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03goo0000:Goo000MOol01000Oomoo`000goo00<007ooOol01Goo00@0
07ooOol000Aoo`03001oogoo009oo`03001oogoo00Aoo`<009l03`0300003`0?06L03`0300003`0?
03L03`03001oogoo02Moo`0077oo200027oo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo
00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00D03gooOol0000?01Moo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`00Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Oomo
o`0>Ool00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomo
o`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol0
000GOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol05Goo00<0000?Ool037oo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moo`0002Uoo`00;Goo00<007oo000017oo00<007ooOol00Woo00<007oo
Ool017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00005goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03
00moogoo01Eoo`0300003goo00aoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002ioo`8000Eo
o`@000Moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0001Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0DOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00
Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogooOol03`005Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ao
o`03001oo`0?00eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oogoo009oo`03
001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOomoo`0?000FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04goo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001ao
o`H001ioo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00L03gooOomoo`0?Ool0000EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04goo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001eo
o`05001oogooOol0000NOol00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo00005Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?009oo`0300moogoo019oo`05001oogooOol03`0=Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo000LOol00`00Oomoo`02Ool00`00Oomoo`0LOol00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0700moogooOol03goo
00005Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo019oo`05001oogooOol03`0=
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Oomoo`02Ool00`00Oomoo`0LOol0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`02Ool00`00Oomoo`0BOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04Goo00<007ooOol00Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`0077oo00<007ooOol08Goo0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l00Woo00<007ooOol0
4Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo015oo`03001oogoo009oo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
00=oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0AOol00`00
Oomoo`02Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`03Ool00`00Oomoo`0AOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol047oo00<007ooOol00goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l00goo00<007ooOol04Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?009oo`0300moogoo011oo`03001oogoo00=oo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol001eoo`@001moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Aoo`03001oogoo011o
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0?Ool00`00Oomoo`04Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00Oomoo`0L
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`04Ool00`00Oomoo`0@Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol03goo00<007ooOol017oo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`0077oo00<007oo00000Woo00<007ooOol077oo00<007oo00l05goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
1Goo00<007ooOol03goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00moo`03001o
ogoo00Aoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oo`00
009oo`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Eoo`03001oogoo00moo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0>Ool00`00Oomoo`05Ool00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00Oomoo`0LOol00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`06Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<0
3gooOol03Woo00<007ooOol01Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`007Goo0P0000=oo`00Ool07Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l01Woo00<007ooOol03Woo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00eoo`03001oogoo00Ioo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Ioo`03
001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0=Ool00`00Oomoo`06
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`07Ool00`00Oomoo`0=Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol0
3Goo00<007ooOol01Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
0P0000<03gooOol05Goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l01goo00<007ooOol03Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo00aoo`03001oogoo00Moo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol001eoo`@001moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Qoo`03001oogoo00aoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0<Ool00`00Oomoo`07Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00Oomoo`0LOol0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`08Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol037oo00<007ooOol01goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
o`0002Uoo`0077oo00<007oo00000Woo00<007ooOol077oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l027oo
00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00]oo`03001oogoo
00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol001aoo`03001oo`00009o
o`03001oogoo01aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomo
o`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Uoo`03001oogoo00]oo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0;Ool00`00Oomoo`08Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo000LOol00`00Ool00002Ool00`00Oomoo`0LOol00`00Ool03`0G
Ool00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`05
00moogooOol03`09Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
Ool02Woo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00
7Goo0P0000=oo`00Ool07Woo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l02Woo00<007ooOol02Woo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo00Yoo`03001oogoo00Uoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00Yoo`03001o
ogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0:Ool00`00Oomoo`09Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0:Ool00`00Oomoo`0:Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol02Goo
00<007ooOol02Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l02goo00<007ooOol02Goo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo00Uoo`03001oogoo00Yoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00]oo`03001oogoo00Uoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`08Ool00`00Oomoo`0;Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0<Ool00`00Oomoo`08Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol027oo00<007ooOol02goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo0P0000<03gooOol05Goo00<03gooOol0
37oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l0
37oo00<007ooOol027oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo00Qoo`03001o
ogoo00]oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?00aoo`03001oogoo00Qoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`07Ool00`00Oomoo`0<Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<0
3gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0500moogooOol03`0=Ool00`00Oomoo`07Ool00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol01goo00<007ooOol037oo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l03Goo00<007ooOol01goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOomoo`0?009oo`0300moogoo00Ioo`03001oogoo00eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00ioo`03001o
ogoo00Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`06Ool00`00Oomoo`0=Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0>Ool00`00Oomoo`06Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol01Woo
00<007ooOol03Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<0
07oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]o
o`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol0
3`03Ool01@0?Oomoogoo00l03Woo00<007ooOol01Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009o
o`0300moogoo00Eoo`03001oogoo00ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00moo`03001oogoo00Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`05Ool00`00Oomoo`0>Ool00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo000]Ool40004Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0?Ool0
0`00Oomoo`05Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03gooOol017oo00<007ooOol0
3goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00;7oo00<007ooOol00Woo
00@007ooOol000Aoo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?00moo`03001oogoo00Eo
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`04Ool00`00Oomoo`0?Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300mo
ogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l047oo00<007ooOol017oo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol0
0Woo00D03gooOomoo`0?009oo`0300moogoo00Aoo`03001oogoo00moo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500mo
ogooOol03`03Ool00`0?Ool0000YOol002aoo`8000=oo`04001oogoo0004Ool00`00Oomoo`04Ool3
002a00l00`0000l03`1200l00`0000l03`1:00l00`00Oomoo`0WOol002aoo`03001oo`00008000=o
o`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?015oo`03001oogoo00=o
o`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`03Ool00`00Oomoo`0@Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
Ool05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0AOol00`00Oomoo`03Ool00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol04Goo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0002Uoo`00;Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
17oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
17oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01@0?Oomoogoo00l04Goo00<007ooOol00goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?009oo`0300moogoo009oo`03001oogoo015oo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol002ioo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oo`0?
01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00D03gooOomoo`0?019oo`03001oogoo009oo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`02Ool00`00Oomoo`0AOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo
000_Ool30003Ool40007Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0BOol00`00Oomoo`02Ool00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01=oo`05001oogooOol03`0=
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01=oo`05001oogooOol03`0=Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00Woo00D03gooOomoo`0001Aoo`0300moogoo00]oo`0300moogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?
Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01=oo`05001oogooOol03`0=Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00@03gooOol001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0
000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0E
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Aoo`04001oogoo00l=Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00@03gooOol001Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041o
o`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00D03gooOomoo`0?01Aoo`04001oogoo00l=Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo
00005Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l0
5goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol0
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300mo
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1@0?Oomoogoo00l057oo00@007ooOol03`eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Ool0000FOol00`0?
Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0EOol00`00Ool03`0=Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00<03goo00005Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05Goo00<0
07oo00l03Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03gooOomoo`0?009oo`0300l007oo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Ioo`0300003goo00aoo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?001oo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0FOol00`0000moo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<007ooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05Woo00<0000?Ool037oo00<03gooOol01goo00<03gooOol01Goo
00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`03001oogoo
01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Mo
o`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOomoo`0?01Moo`03001oogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Ao
o`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`00Oomoo`0FOol00`0?Oomo
o`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0G
Ool00`00Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`00Oomoo`0;Ool00`0?
Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?
Oomoogoo00moo`0000lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010
Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03goo
Ool02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0500moogooOol03`0GOol00`0?001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00moo`0000lHOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?
Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogoo
Ool03`0GOol00`0?001oo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo00lHOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Ool0000;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0200?Oomoogoo00l007oo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000
:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo
00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Ool0000;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoogoo00l007oo
00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomo
o`0EOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol0100?Oomoo`002Woo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`00009oo`0300moogoo01Ioo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300mo
ogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomo
o`0?01Moo`0400moogoo000:Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00000Woo00<03gooOol05Woo00<03gooOol02goo
00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eo
o`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00D0
3gooOomoo`0000Uoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`0500moogoo00003`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol01@0?Oomoogoo
00002Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOol0000?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`03
00moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool0
0`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo009oo`03001o
ogoo00Ioo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300mo
ogoo009oo`0500moo`00Ool03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`02Ool00`00
Oomoo`06Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01@0?Ool007oo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo
00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=o
o`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol00goo00<0
07ooOol01Goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00<0
3gooOol00Woo00D03goo001oo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo00Mo
o`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03
Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00=oo`03
001oogoo00Eoo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03
00moogoo009oo`0500l007ooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`04Ool0
0`00Oomoo`04Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?001oogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol017oo
00<007ooOol017oo00<03gooOol01goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo
00<03gooOol00Woo00D007ooOomoo`0?009oo`0300moogoo01Ioo`0300moogoo00]oo`0300moogoo
00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0500moogoo
Ool03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol0
3`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Eo
o`03001oogoo00=oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009o
o`0300moogoo009oo`05001oogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomo
o`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03goo0000:Goo0010Ool200000`0?Oomoo`0EOol00`0?Oomoo`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomo
o`06Ool00`00Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool01P0?Oomoogoo00003`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`06Ool00`00
Oomoo`02Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool01P0?
Oomoogoo00003`=oo`0400moogoo00lHOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo
0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol0
5Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`07Ool01@00Oomoogoo00l0
2Goo00<03gooOol01Goo00<03gooOol017oo00<03gooOol00Woo00H03gooOol007oo00l3Ool0100?
Oomoo`0?67oo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol01goo00D007ooOomoo`0?00Uoo`0300moogoo00Eoo`03
00moogoo00Aoo`0300moogoo009oo`0600moogoo001oo`0?0goo00@03gooOol03aQoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo00ao
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo009o
o`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?01Mo
o`0300moogoo00Qoo`04001oogoo00l9Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02
Ool00`0?Ool00002Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03goo
Ool01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0300moo`0002Uoo`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300mo
ogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol0
27oo00@007ooOol03`Uoo`0300moogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`0300moo`00
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`09Ool00`00Ool0
3`09Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?001oo`02Ool01@0?Oomo
ogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uo
o`00@7oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`03
00moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`05
00moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02Goo00<007oo00l02Goo00<03goo
Ool01Goo00<03gooOol017oo00<03gooOol00Woo00<03`00Ool00Woo00D03gooOomoo`0?009oo`03
00moogoo01Ioo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002aoo`@000Eo
o`@000Moo`03001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00Aoo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00D03gooOomoo`0?01Moo`0300moogoo00Yoo`0300003goo00Qoo`0300mo
ogoo00Eoo`0300moogoo00Aoo`0300moogoo009oo`03001oogoo009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000[Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo
00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo
00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo
00<03gooOol02goo00<007ooOol01goo00<03gooOol01Goo00<03gooOol017oo00H03gooOomoo`00
00l4Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<0
3gooOol01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0300moo`0002Uoo`00:goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03
001oo`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`03
00moogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;
Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`03001oogoo00Moo`0300moogoo00Eoo`03
00moogoo00Aoo`0600moogooOol0000?17oo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol002]oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`04Ool00`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?
001oo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool01P0?Oomoo`00Ool03`Aoo`0500moogooOol0
3`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/
Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool3000GOol00`0?Oomoo`0<Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;
Ool00`0?Ool00007Ool00`0?Oomoo`05Ool00`0?Oomoo`04Ool00`0?Ool00002Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03goo
Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`03
00moo`0002Uoo`00:goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001o
o`0?01Moo`0300moogoo00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300mo
ogoo009oo`0300moogoo009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool0
0`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00D03gooOomoo`0?01Moo`0300moogoo00]oo`0300moo`0000Moo`0300moogoo00Eoo`0300mo
ogoo00Aoo`0300l007oo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol0
0`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000[Ool00`00Oomoo`02Ool01@00
Oomoogoo000017oo00<007ooOol017oo00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo
00<03gooOol017oo00<03gooOol017oo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0300moogoo01Eoo`0300moogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo
00=oo`0300moogoo00=oo`0500moogooOol03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo
00@03gooOol000Ioo`0300moogoo00Eoo`0300moogoo00Aoo`03001oogoo009oo`0300moogoo009o
o`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<0
3goo0000:Goo000[Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007oo
00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo00<03goo
Ool00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo00]oo`03
00moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogooOol03`03
Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00D03gooOomoo`0000Eoo`0300moogoo00Eoo`03
00moogoo00Aoo`03001oogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo000/Ool40005Ool40007Ool0
0`00Ool03`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol0
2goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0000moo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0Woo00<03gooOol05Woo00<03gooOol02goo00<03gooOol01goo00<03gooOol01Goo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moo`0002Uoo`00@7oo
00<007oo00l05goo00<03gooOol037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol017oo
00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0300moogoo01Eoo`0300moogoo
00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01@0?Oomoogoo00l05goo00<03gooOol02goo00<03gooOol00goo00D007ooOomoo`0?
00Moo`0300moogoo009oo`03001oo`0?00Aoo`0300moogoo009oo`0500moogooOol03`02Ool00`0?
Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool0
3`0GOol00`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<0
3gooOol01goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0500moogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`04Ool01000Oomoo`0?1goo00D03goo
Oomoo`00009oo`0300moogoo009oo`0300moogoo009oo`0500moogooOol03`02Ool00`0?Oomoo`0F
Ool00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03goo0000:Goo0010Ool00`00Ool03`0GOol0
0`0?Oomoo`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00<03gooOol05Goo00<03gooOol02goo00<03gooOol0
1goo00<03gooOol01Goo00<03gooOol00goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0500mo
ogooOol03`0GOol00`0?Oomoo`0;Ool00`0?Oomoo`05Ool200000`0?Oomoo`05Ool0100?Ool00000
0goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOomoo`0?009oo`0300moogoo01Ioo`0300mo
ogoo00]oo`0300moogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0500moogooOol03`03Ool00`0?Ool0000YOol0041oo`03001oo`0?01Moo`0300moogoo
00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00Aoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`03Ool00`0?Oomoo`0EOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D03gooOomoo`0?
01Moo`0300moogoo00]oo`0300moogoo00Moo`8000Ioo`8000Eoo`0300moogoo009oo`0300moogoo
009oo`0500moogooOol03`02Ool00`0?Oomoo`0FOol00`0?Oomoo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00<03goo0000:Goo0010Ool00`00Ool0000GOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<0
07ooOol05Goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0000GOol00`00Oomoo`0;Ool00`00Oomo
o`07Ool90006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol0
5Woo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol0
0Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oo`0002Uoo`00@7oo00<007oo00005goo
00<007ooOol037oo00<007ooOol01goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo
00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00
Oomoogoo00005goo00<007ooOol02goo00<007ooOol01goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo01Ioo`03001oogoo
00]oo`03001oogoo00Moo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00003Ool00`00Ool0000YOol0041oool004P002Uoo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
cGoo1@0017oo0`000Woo0`000goo1@000goo1@001Goo1000^Goo003>Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo0;Ioo`00cWoo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000=o
o`03001oogoo00Moo`05001oogooOol0002mOol00<ioo`D000Aoo`03001oogoo009oo`03001oogoo
009oo`@000Eoo`@000Aoo`H00;Qoo`00cWoo00<007ooOol00Woo00@007ooOomoo`8000=oo`05001o
ogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
]Woo003>Ool00`00Oomoo`02Ool01P00Oomoogoo001oo`<000Eoo`<000Ioo`D000Aoo`@00;Uoo`00
cWoo00<007ooOol00Woo00D007ooOomoo`000=Qoo`00cGoo1P0017oo00<007ooOol0eWoo003FOol2
003HOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-1.82989, -19.5767, \
0.0186604, 0.64308}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCF Whitening", "Section"],

Cell["Solve for specific pole frequency, zero frequency and gain.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(tr = \(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C\), R2], 
            Z2 \[Rule] par[1\/\(s\ C\), R2], Z3 \[Rule] R3, Z4 \[Rule] R4} // 
        Simplify\), "\[IndentingNewLine]", 
    \(Numerator[tr]~Collect~s\), "\[IndentingNewLine]", 
    \(Denominator[tr]~Collect~s\), "\[IndentingNewLine]", 
    \(num = 
      Coefficient[Numerator[tr], s, {0, 1, 2}]\), "\[IndentingNewLine]", 
    \(den = 
      Coefficient[Denominator[tr], s, {0, 1, 2}]\), "\[IndentingNewLine]", 
    \(zeros = Solve[Numerator[tr] \[Equal] 0, s]\), "\[IndentingNewLine]", 
    \(poles = Solve[Denominator[tr] \[Equal] 0, s]\)}], "Input"],

Cell[BoxData[
    \(\(-\(\((G\ R3\ R4\ \((1 + C\ R2\ s)\)\^2)\)/\((\(-R3\)\ R4 - 
            R2\^2\ \((1 + C\ \((R3 - G\ R3 + 2\ R4)\)\ s + 
                  C\^2\ R3\ R4\ s\^2)\) + 
            R2\ \((\(-2\)\ R4 + 
                  R3\ \((\(-1\) + G - 2\ C\ R4\ s)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    \(\(-G\)\ R3\ R4 - 2\ C\ G\ R2\ R3\ R4\ s - 
      C\^2\ G\ R2\^2\ R3\ R4\ s\^2\)], "Output"],

Cell[BoxData[
    \(\(-R2\^2\) - R2\ R3 + G\ R2\ R3 - 2\ R2\ R4 - 
      R3\ R4 + \((\(-2\)\ C\ R2\ R3\ R4 - 
            C\ R2\^2\ \((R3 - G\ R3 + 2\ R4)\))\)\ s - 
      C\^2\ R2\^2\ R3\ R4\ s\^2\)], "Output"],

Cell[BoxData[
    \({\(-G\)\ R3\ R4, \(-2\)\ C\ G\ R2\ R3\ R4, \(-C\^2\)\ G\ R2\^2\ R3\ R4}\
\)], "Output"],

Cell[BoxData[
    \({\(-R2\^2\) - R2\ R3 + G\ R2\ R3 - 2\ R2\ R4 - 
        R3\ R4, \(-C\)\ R2\^2\ R3 + C\ G\ R2\^2\ R3 - 2\ C\ R2\^2\ R4 - 
        2\ C\ R2\ R3\ R4, \(-C\^2\)\ R2\^2\ R3\ R4}\)], "Output"],

Cell[BoxData[
    \({{s \[Rule] \(-\(1\/\(C\ R2\)\)\)}, {s \[Rule] \(-\(1\/\(C\ \
R2\)\)\)}}\)], "Output"],

Cell[BoxData[
    \({{s \[Rule] \(-\(\(1\/\(2\ C\^2\ R2\^2\ R3\ R4\)\)\((C\ R2\^2\ R3 - 
                C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 2\ C\ R2\ R3\ R4 - 
                C\ R2\^2\ \@\(R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ \
R4 + 4\ R4\^2\))\)\)\)}, {s \[Rule] \(-\(\(1\/\(2\ C\^2\ R2\^2\ R3\ \
R4\)\)\((C\ R2\^2\ R3 - C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 
                2\ C\ R2\ R3\ R4 + 
                C\ R2\^2\ \@\(R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ \
R4 + 4\ R4\^2\))\)\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(eq1 = 
        1\/\(C\ R2\) \[Equal] 2  \[Pi]\ zerof;\)\), "\[IndentingNewLine]", 
    \(\(eq2 = 
        R3\^2 - 2\ G\ R3\^2 + G\^2\ R3\^2 - 4\ G\ R3\ R4 + 4\ R4\^2 \[Equal] 
          0\ ;\) (*\ real\ poles\ *) \), "\[IndentingNewLine]", 
    \(\(eq3 = \(1\/\(2\ C\^2\ R2\^2\ R3\ R4\)\) \((C\ R2\^2\ R3 - 
                C\ G\ R2\^2\ R3 + 2\ C\ R2\^2\ R4 + 
                2\ C\ R2\ R3\ R4)\) \[Equal] 
          2\ \[Pi]\ polef;\)\), "\[IndentingNewLine]", 
    \(\(eq4 = G \[Equal] gain;\)\), "\[IndentingNewLine]", 
    \(\(eq5 = C \[Equal] C1;\)\ \  (*\ 
      assume\ a\ value*) \), "\[IndentingNewLine]", 
    \(\(assume = {polef \[Rule] 100, zerof \[Rule] 10, gain \[Rule] 10, 
          C1 \[Rule] 0.33*^-6};\)\), "\[IndentingNewLine]", 
    \(Rs = 
      Solve[{eq1, eq2, eq3, eq4, eq5} /. assume, {R2, R3, R4}] // 
        N\)}], "Input"],

Cell[BoxData[
    \({{R2 \[Rule] 48228.77063390767`, R4 \[Rule] 14358.505999906296`, 
        R3 \[Rule] 1999.9452682777526`}, {R2 \[Rule] 48228.77063390768`, 
        R4 \[Rule] \(-8999.753707249889`\), 
        R3 \[Rule] \(-3190.779111090288`\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Vout/Vin /. sol\) /. {Z1 \[Rule] par[1\/\(s\ C1\), R2], 
            Z2 \[Rule] par[1\/\(s\ C1\), R2], Z3 \[Rule] R3, Z4 \[Rule] R4, 
            G \[Rule] gain} // Together\) // 
      Simplify\), "\[IndentingNewLine]", 
    \(\(\(% /. assume\) /. 
        Rs\[LeftDoubleBracket]1\[RightDoubleBracket];\)\), "\
\[IndentingNewLine]", 
    \(getZPK[%]\), "\[IndentingNewLine]", 
    \(\(%% /. {s \[Rule] 
            2\ \[Pi]\ \[ImaginaryI]\ f};\)\), "\[IndentingNewLine]", 
    \(\(BodePlot[%, {f, 0.1, 1000}];\)\)}], "Input"],

Cell[BoxData[
    \(\(-\(\((gain\ R3\ R4\ \((1 + C1\ R2\ s)\)\^2)\)/\((\(-R3\)\ R4 - 
            R2\^2\ \((1 + C1\ \((R3 - gain\ R3 + 2\ R4)\)\ s + 
                  C1\^2\ R3\ R4\ s\^2)\) + 
            R2\ \((\(-2\)\ R4 + 
                  R3\ \((\(-1\) + gain - 
                        2\ C1\ R4\ s)\))\))\)\)\)\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("K(f=0) = "\[InvisibleSpace]0.10000000000000003`\
\[InvisibleSpace]" \
("\[InvisibleSpace]0.10000000000000003`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "K(f=0) = ", .10000000000000003, " (", .10000000000000003, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("K(f=\[Infinity]) = "\[InvisibleSpace]10.`\
\[InvisibleSpace]" ("\[InvisibleSpace]10.`\[InvisibleSpace]")"\),
      SequenceForm[ "K(f=\[Infinity]) = ", .1*^2, " (", .1*^2, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Poles at = \
"\[InvisibleSpace]\(-100.00000000000033`\)\[InvisibleSpace]" and "\
\[InvisibleSpace]\(-99.99999999999972`\)\[InvisibleSpace]" "\),
      SequenceForm[ 
      "Poles at = ", -100.00000000000033, " and ", -99.999999999999716, " "],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole frequency = \
"\[InvisibleSpace]100.00000000000003`\[InvisibleSpace]" \
("\[InvisibleSpace]100.00000000000003`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Pole frequency = ", 100.00000000000003, " (", 100.00000000000003, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Pole Q = "\[InvisibleSpace]0.4999999999999999`\
\[InvisibleSpace]" ("\[InvisibleSpace]0.4999999999999999`\[InvisibleSpace]")"\
\),
      SequenceForm[ 
      "Pole Q = ", .49999999999999989, " (", .49999999999999989, ")"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero frequency = \
"\[InvisibleSpace]10.000000000000002`\[InvisibleSpace]" \
("\[InvisibleSpace]10.000000000000002`\[InvisibleSpace]")"\),
      SequenceForm[ 
      "Zero frequency = ", 10.000000000000002, " (", 10.000000000000002, ")"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Zero Q = "\[InvisibleSpace]0.5`\[InvisibleSpace]" ("\
\[InvisibleSpace]0.5`\[InvisibleSpace]")"\),
      SequenceForm[ "Zero Q = ", .5, " (", .5, ")"],
      Editable->False]], "Print"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253086 0.246914 0.309365 0.0154215 [
[.00617 -0.0125 -10.9688 -16.375 ]
[.00617 -0.0125 10.9688 0 ]
[.25309 -0.0125 -5.59375 -16.375 ]
[.25309 -0.0125 5.59375 0 ]
[.5 -0.0125 -9.1875 -16.375 ]
[.5 -0.0125 9.1875 0 ]
[.74691 -0.0125 -12.7813 -16.375 ]
[.74691 -0.0125 12.7813 0 ]
[.99383 -0.0125 -16.375 -16.375 ]
[.99383 -0.0125 16.375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.90625 -32.75 ]
[.5 -0.0125 9.90625 -16.375 ]
[-0.0125 .00094 -27.375 -8.1875 ]
[-0.0125 .00094 0 8.1875 ]
[-0.0125 .15515 -27.375 -8.1875 ]
[-0.0125 .15515 0 8.1875 ]
[-0.0125 .30937 -11.1875 -8.1875 ]
[-0.0125 .30937 0 8.1875 ]
[-0.0125 .46358 -18.375 -8.1875 ]
[-0.0125 .46358 0 8.1875 ]
[-0.0125 .6178 -18.375 -8.1875 ]
[-0.0125 .6178 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -43.75 -9.90625 ]
[-0.01875 .30902 -27.375 9.90625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -32.125 0 ]
[.5 .63053 32.125 16.375 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .15515 m
1 .15515 L
s
0 .30937 m
1 .30937 L
s
0 .46358 m
1 .46358 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
77.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
84.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -77.375 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
91.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.9063 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
78.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .00094 m
.00625 .00094 L
s
gsave
-0.0125 .00094 -88.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .15515 m
.00625 .15515 L
s
gsave
-0.0125 .15515 -88.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
72.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .30937 m
.00625 .30937 L
s
gsave
-0.0125 .30937 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .46358 m
.00625 .46358 L
s
gsave
-0.0125 .46358 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .6178 m
.00625 .6178 L
s
gsave
-0.0125 .6178 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03178 m
.00375 .03178 L
s
0 .06262 m
.00375 .06262 L
s
0 .09346 m
.00375 .09346 L
s
0 .12431 m
.00375 .12431 L
s
0 .18599 m
.00375 .18599 L
s
0 .21684 m
.00375 .21684 L
s
0 .24768 m
.00375 .24768 L
s
0 .27852 m
.00375 .27852 L
s
0 .34021 m
.00375 .34021 L
s
0 .37105 m
.00375 .37105 L
s
0 .40189 m
.00375 .40189 L
s
0 .43274 m
.00375 .43274 L
s
0 .49442 m
.00375 .49442 L
s
0 .52527 m
.00375 .52527 L
s
0 .55611 m
.00375 .55611 L
s
0 .58695 m
.00375 .58695 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -106.469 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
70.9063 12.1875 translate
90 rotate
-70.9063 -12.1875 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dB) show
78.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -93.125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Magnitude) show
123.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .00095 m
.02372 .00095 L
.03955 .00096 L
.05352 .00097 L
.06699 .00098 L
.07854 .00099 L
.08806 .001 L
.10505 .00102 L
.12005 .00105 L
.13273 .00108 L
.14475 .00111 L
.15518 .00115 L
.16433 .00119 L
.17329 .00123 L
.18125 .00128 L
.18912 .00134 L
.19619 .00139 L
.20257 .00145 L
.20897 .00152 L
.2148 .00158 L
.22066 .00166 L
.22601 .00173 L
.23093 .00181 L
.23592 .00189 L
.24051 .00198 L
.24476 .00207 L
.24909 .00216 L
.25309 .00225 L
s
.25309 .00225 m
.27063 .00276 L
.28646 .00338 L
.30044 .0041 L
.31391 .005 L
.33497 .00691 L
.35197 .00906 L
.36749 .01168 L
.38058 .01451 L
.39182 .01748 L
.40262 .0209 L
.41208 .02443 L
.42045 .02801 L
.42869 .03202 L
.43607 .03604 L
.4434 .04047 L
.45001 .04487 L
.45601 .04921 L
.46205 .05393 L
.46755 .05856 L
.47311 .06355 L
.4782 .06841 L
.48288 .07313 L
.48765 .07818 L
.49205 .08307 L
.49612 .08778 L
.5 .09245 L
s
.5 .09245 m
.53337 .13938 L
.56082 .18613 L
.58144 .22494 L
.59812 .2579 L
.61342 .28887 L
.62633 .31524 L
.63854 .34013 L
.64912 .36148 L
.65839 .37994 L
.66745 .39763 L
.67551 .413 L
.68272 .42644 L
.68991 .43946 L
.69639 .45089 L
.70288 .46197 L
.70878 .47172 L
.71417 .48034 L
.71962 .48877 L
.72461 .49623 L
.72968 .50353 L
.73435 .51001 L
.73865 .51578 L
.74305 .52146 L
.74691 .52628 L
s
.74691 .52628 m
.76446 .54604 L
.78029 .56097 L
.80773 .58087 L
.82764 .59125 L
.84542 .59821 L
.86013 .60265 L
.87383 .60592 L
.88555 .60817 L
.89574 .60978 L
.90561 .6111 L
.91432 .61208 L
.92208 .61284 L
.92977 .61349 L
.93668 .614 L
.94357 .61445 L
.94982 .61482 L
.9555 .61511 L
.96123 .61538 L
.96647 .6156 L
.97178 .61581 L
.97665 .61598 L
.98114 .61613 L
.98572 .61626 L
.98995 .61638 L
.99383 .61648 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00i7oo0P001goo0P0000=oo`0000001`00
]goo003TOol20007Ool200000goo00000007002gOol00>Aoo`8000Moo`800004Ool00000002mOol0
0>Aoo`8000Moo`80009oo`<00;aoo`00i7oo0P001goo0P000goo0`00^goo003TOol20007Ool20004
Ool3002jOol00>Aoo`8000Moo`8000Eoo`<00;Uoo`00i7oo2`001Woo0`00^7oo003TOol;0007Ool3
002gOol00>Aoo`8000Moo`80009oo`P00;Moo`00i7oo0P001goo0P000Woo2000]goo003TOol20007
Ool20031Ool00>Aoo`8000Moo`800<5oo`00i7oo0P001goo0P00`Goo003TOol20007Ool20031Ool0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00DGoo1@001Goo0P001goo0P00?goo0P00@Woo0P001goo1@00=goo
0P001goo1@001Woo1@00:goo0P001goo1@001Woo1@001Woo1@006Woo001@Ool70004Ool20007Ool2
000oOol20012Ool20006Ool7000fOol20006Ool70004Ool7000ZOol20006Ool70004Ool70004Ool7
000IOol0051oo`8000=oo`8000eoo`8003moo`80049oo`8000Ioo`8000=oo`8003Ioo`8000Ioo`80
00=oo`8000Aoo`8000=oo`8002Yoo`8000Ioo`8000=oo`8000Aoo`8000=oo`8000Aoo`8000=oo`80
01Uoo`00Cgoo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=Goo0P001Goo0P00
1Goo0P000Woo0P001Goo0P00:Goo0P001Goo0P001Goo0P000Woo0P001Goo0P000Woo0P001Goo0P00
67oo001?Ool20005Ool2000<Ool2000oOol20012Ool20005Ool20005Ool2000eOol20005Ool20005
Ool20002Ool20005Ool2000YOol20005Ool20005Ool20002Ool20005Ool20002Ool20005Ool2000H
Ool004moo`8000Eoo`8000aoo`8003moo`80049oo`8000Eoo`8000Eoo`8003Eoo`8000Eoo`8000Eo
o`80009oo`8000Eoo`8002Uoo`8000Eoo`8000Eoo`80009oo`8000Eoo`80009oo`8000Eoo`8001Qo
o`00Cgoo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=Goo0P001Goo0P001Goo
0P000Woo0P001Goo0P00:Goo0P001Goo0P001Goo0P000Woo0P001Goo0P000Woo0P001Goo0P0067oo
001?Ool20005Ool2000<Ool2000oOol20012Ool20005Ool20005Ool2000eOol20005Ool20005Ool2
0002Ool20005Ool2000YOol20005Ool20005Ool20002Ool20005Ool20002Ool20005Ool2000HOol0
04moo`8000Eoo`8000aoo`8003moo`80049oo`8000Eoo`8000Eoo`8003Eoo`8000Eoo`8000Eoo`80
009oo`8000Eoo`8002Uoo`8000Eoo`8000Eoo`80009oo`8000Eoo`80009oo`8000Eoo`8001Qoo`00
Cgoo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=Goo0P001Goo0P001Goo0P00
0Woo0P001Goo0P00:Goo0P001Goo0P001Goo0P000Woo0P001Goo0P000Woo0P001Goo0P0067oo001?
Ool20005Ool20009Ool200000goo0000000lOol200000goo0000000oOol200000goo00000005Ool2
0005Ool2000bOol200000goo00000005Ool20005Ool20002Ool20005Ool2000VOol200000goo0000
0005Ool20005Ool20002Ool20005Ool20002Ool20005Ool2000HOol004moo`8000Eoo`8000Uoo`D0
03aoo`D003moo`D000Eoo`8000Eoo`80039oo`D000Eoo`8000Eoo`80009oo`8000Eoo`8002Ioo`D0
00Eoo`8000Eoo`80009oo`8000Eoo`80009oo`8000Eoo`8001Qoo`00D7oo0P000goo0P0037oo0`00
?Woo0`00@Goo0`001Woo0P000goo0P00=Goo0`001Woo0P000goo0P0017oo0P000goo0P00:Goo0`00
1Woo0P000goo0P0017oo0P000goo0P0017oo0P000goo0P006Goo001@Ool7000=Ool2000oOol20012
Ool20006Ool7000fOol20006Ool70004Ool7000ZOol20006Ool70004Ool70004Ool7000IOol0055o
o`D000ioo`8003moo`80049oo`8000Moo`D003Moo`8000Moo`D000Ioo`D002]oo`8000Moo`D000Io
o`D000Ioo`D001Yoo`00ogoo/Goo000oOol90004Ool5003oOomPOol003moo`T000=oo`L00?mooemo
o`00@7oo0P002Goo0P000goo0P00ogooGgoo0011Ool20007Ool20005Ool2003oOomNOol0049oo`80
00Ioo`8000Eoo`800?mooeioo`00<Goo2`001goo0P001Goo0P001Goo0P001gooo`00;@00:Woo0014
Ool20004Ool20005Ool20007OomH000:Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol001Eoo`03001o
ogoo00Yoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`05001o
ogooOol00003Ool01000Oomoo`005Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oo`0002Yo
o`00AGoo0P000goo0P001Goo0P001goo00<007oo00005Goo00<007ooOol02Woo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo
000<Ool900000goo001oo`0;Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol001Eoo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomo
o`005Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oo`0002Yoo`00AWoo00@007ooOomoo`80
00Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo2`000goo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Ool0000ZOol004Ioo`80009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol01goo100027oo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004Ioo`80
009oo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03`0000000P0017oo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol003moo`8000Eoo`80009oo`8000Eoo`80
00Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<0
3gooOol00Woo0`0000=oo`0?Ool01Goo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Ool0000ZOol0041oo`8000Aoo`8000=oo`8000=oo`8000Qoo`03001oo`0?
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Goo0`00
1Goo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000Z
Ool0041oo`L000Aoo`L000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00@03goo000000=oo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo0011Ool50006Ool50009Ool00`00Ool0
3`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`04
00moogooOol300000`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moo`0002Yoo`00FWoo0P0000<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool20004Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0100?Ool00000
0Woo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00L03gooOomoo`00Ool03`04Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
o`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0000moo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool20003Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool01P0?Ool00000Ool03`=oo`0500moogooOol03`02Ool00`0?Oomoo`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00H03gooOomoo`0000l3Ool0
1@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`05001oogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol0
0`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500l00000Ool03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03goo0000:Woo001JOol200000`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogoo00003`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol00003Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo
001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0600moogooOol03`00
0Woo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool02@0?Oomoogoo00moo`00Ool03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?009oo`0500003goo
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`04001oogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400l007oo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yo
o`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00l007oo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moo`0000lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`80000300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo000EOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000Z
Ool005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0500moogoo00l0000DOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0500moogoo00l0000DOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`004goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol047oo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool0
3`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
0goo00<007ooOol03goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?0goo00<007ooOol03goo00<03gooOol02Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol0
0`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?17oo00<007ooOol03Woo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?1Goo00<007ooOol03Goo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo
001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?1Goo00<007ooOol03Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol200000`0?Oomoo`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?1Woo00<007ooOol0
37oo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?1goo00<007ooOol02goo00<03gooOol02Woo00<03gooOol01goo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?27oo00<0
07ooOol02Woo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03goo0000:Woo0013Ool20007Ool50009Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?27oo00<007ooOol02Woo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo
0013Ool20006Ool70008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?2Goo00<007ooOol02Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo0013Ool20006Ool20003
Ool20008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?2Woo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo0013Ool20005Ool20005Ool20007Ool0
0`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?2Woo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0goo00<03goo0000:Woo0013Ool20005Ool20005Ool20007Ool00`00Ool03`0E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?2goo
00<007ooOol01goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo0000:Woo000aOol;0007Ool20005Ool20005Ool20007Ool00`00Ool03`0EOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?2goo00<0
07ooOol01goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03goo0000:Woo0013Ool20005Ool20005Ool20007Ool3002O00l00`0000l03`2600l00`00
Oomoo`0XOol004=oo`8000Eoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l<Ool00`00Oomoo`06Ool00`0?Oomo
o`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol0
04=oo`8000Eoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00l=Ool00`00Oomoo`05Ool00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Eo
o`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00l>Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol0041oo`800003Ool0000000Eo
o`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00l>Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol0041oo`D000Eoo`8000Eoo`80
00Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00l?Ool00`00Oomoo`03Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol0049oo`<000Ioo`8000=oo`8000Qoo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00l?Ool00`00Oomoo`03Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Ioo`L000Qoo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l@Ool00`00Oomoo`02
Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool0000ZOol004=oo`8000Moo`D000Uoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00l@Ool00`00Oomoo`02Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`80
000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lAOol01@00Oomoogoo00l037oo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?4Woo00@007ooOol03`aoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03a9oo`04
001oogoo00l<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lCOol00`00Ool03`0<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lCOol00`00Ool03`0<Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lD
Ool00`0000moo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lDOol00`0000moo`0;Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`00Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?001oo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool0000ZOol005Yoo`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?001oo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Ool0000:
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yo
o`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Ool0000:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0100?Oomoo`002Goo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00@03goo
Ool000Uoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yo
o`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0500moogooOol00008Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol01@0?Oomoogoo000027oo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol00Woo00<007ooOol01Goo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol00Woo00<007ooOol0
1Goo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001J
Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol00goo00<007ooOol017oo00<03gooOol01goo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol200000`0?Oomoo`0COol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol00goo
00<007ooOol017oo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol017oo00<007ooOol00goo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool017oo00<007ooOol00goo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol01Goo00<007ooOol00Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol01Goo00<007ooOol00Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol01Woo00D007ooOomoo`0?00Uo
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Ioo`05001oogooOol03`09Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`07Ool01000Oomoo`0?2Goo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo000NOol5000gOol00`00Ool03`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
1goo00@007ooOol03`Uoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00
77oo2@00=Goo0P0000<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Qoo`03001oo`0?00Uoo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0002Yoo`006goo0`001Goo0`00=7oo00<007oo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Qoo`03001oo`0?00Uoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yo
o`006goo0P001goo0P00=7oo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Uoo`0300003goo00Qoo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`006goo0P001goo0P009Goo1@002Woo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Uoo`0300003goo00Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moo`0002Yoo`006goo0P001goo0P0097oo1`002Goo00<007oo00l05Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Uoo`03
00003goo00Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`0077oo0P00
1Goo0P009Goo0P000goo0P002Goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lF
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03001oogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`005goo3`008goo0P001Goo0P0027oo
00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`03001oogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`=oo`0300moo`0002Yoo`005goo3`008goo0P001Goo0P0027oo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300l007oo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00BGoo
0P001Goo0P0027oo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300l007oo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0002Yoo`00BGoo0P001Goo0P0027oo0`00]`0?00<0000?00l0
KP0?00<007ooOol0:7oo0019Ool20005Ool20008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
00001goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo000GOol?000SOol2
0005Ool20008Ool00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00@03gooOol000Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0002Yoo`005goo3`008goo0P001Goo0P0027oo00<007oo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0500moogooOol00005Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool0000ZOol001Moo`8000Aoo`8000Eoo`8002=oo`8000Eoo`8000Qoo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool01@0?Oomoogoo00001Goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
0000:Woo000GOol20004Ool20005Ool2000SOol20005Ool20008Ool00`00Ool03`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo0000:Woo000GOol20004Ool20005Ool2000TOol20003Ool20009Ool00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol00Woo00<007ooOol00Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03goo0000:Woo000GOol20004Ool20005Ool2000TOol70009Ool00`00Ool03`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol00goo00D007ooOomoo`0?00Ioo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yo
o`005goo0`000Woo0`001Goo0P009Goo1@002Woo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00=oo`05001oogooOol03`06Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol001Qoo`P000=o
o`<003Aoo`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`04Ool01000Oomoo`0?1Woo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0goo00<03goo0000:Woo000IOol40002Ool6000eOol00`00Ool03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol017oo00@007ooOol03`Ioo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yo
o`0087oo1000=Woo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Eoo`03001oo`0?00Ioo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Eoo`03001oo`0?00Ioo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300003goo00Eoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300003goo00Eo
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Moo`03001oogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0300moogoo00Moo`03001oogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300l007oo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo0P0000<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300l007oo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00
FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moo`0000Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`03
00moo`0000Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Moo`0400moogoo0003Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000Z
Ool005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0100?Oomoo`000goo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00D03gooOomoo`00009oo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo
00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Moo`0500moogooOol00002Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`02Ool00`00Ool03`05Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`07Ool00`0?Oomoo`02Ool00`00Ool03`05Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yo
o`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`03Ool00`0000moo`04Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool0000ZOol005Yoo`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`03Ool00`0000moo`04Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000Z
Ool005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`00Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?001oo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?001oo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Ool00003Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Ool00003Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?
01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lE
Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0100?Oomoo`000Woo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo
00@03gooOol0009oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo0P0000<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0700moogooOol007oo00l017oo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00
Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00L03gooOomoo`00Ool03`04
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`02Ool00`0000moo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Moo`D000Uoo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`00Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000Z
Ool004=oo`8000Ioo`L000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`00Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Ioo`8000=oo`8000Qoo`03
001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
001oo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Ool0000ZOol004=oo`8000Eoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?001oo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`80
00Eoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Ool00002Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Eoo`8000Eoo`8000Moo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Ool0
0002Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool0000ZOol004=oo`8000Eoo`8000Eoo`8000Moo`<00<l03`0300003`0?05H03`03001oogoo
02Qoo`00@goo0P001Goo0P001Goo0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0600moogooOol0000?0goo00D03gooOomoo`0?009oo`03
00moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Eoo`80
00Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@00Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Eoo`8000Eoo`8000Moo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@00Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
000ZOol0041oo`800003Ool0000000Eoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?001oogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol0041oo`D0
00Eoo`8000Eoo`8000Moo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?001oogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol0049oo`<000Ioo`8000=oo`8000Qoo`03001o
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Ool007oo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool0000ZOol004=oo`8000Ioo`L000Qoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Ool007oo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol004=oo`8000Moo`D000Uo
o`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool0000ZOol005Yoo`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoo`0000l00goo00@03gooOol0
3aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00000goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000Z
Ool005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00T03gooOomoo`0?Ool007oo00l0
0Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0900moogooOol03goo001oo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo00D0000?Oomo
o`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@007ooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03`00Ool03aEoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3goo00003aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`80000300mo
ogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03goo00003aEoo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol001Eoo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00D03gooOol03`0001Aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yo
o`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`004goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l0
5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00<007ooOol047oo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
0goo00<007ooOol03goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?17oo00<007ooOol03Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo
00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?1Goo00<007ooOol03Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00
FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?1Woo0P003Goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo0P0000<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?27oo00<007ooOol02Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yo
o`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?2Goo00<007ooOol02Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?2Woo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
o`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?2goo0P0027oo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?3Goo00<007ooOol01Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
o`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?3Woo00<007ooOol0
17oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00FWoo00<007oo00l05Goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?3goo0P0017oo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
o`0002Yoo`00FWoo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?4Goo00D007ooOomo
o`0?00aoo`0300moogoo00Ioo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03a9oo`800003Ool03goo00]oo`0300moogoo00Ioo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0000ZOol005Yo
o`80000300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aAoo`8000aoo`0300moogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Ool0000ZOol005Yoo`03001oo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`04
00l000000009Ool00`0?Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo0000:Woo001JOol00`00Ool03`0EOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00@03gooOol03aIoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol0100?Oomoogoo0P001goo00<03gooOol01Woo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yo
o`00?goo2@0017oo1@002Goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol00goo0`0017oo00<03gooOol01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00?goo2@000goo1`0027oo00<0
07oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol01Woo0P000Woo00<03goo
Ool01Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0002Yoo`00@7oo0P002Goo0P000goo0P0027oo00<007oo00l05Goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lFOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol027oo0`0027oo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00@Goo0P00
1goo0P001Goo0P001goo00<007oo00l05Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lFOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03`0000001@0000=oo`0?Ool01Woo00<03gooOol00Woo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moo`0002Yoo`00@Woo0P001Woo0P001Goo0P001goo00<007oo
00005Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo000FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
01Eoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`005Goo00<03gooOol02Woo00<03gooOol01Goo2000
00=oo`0?Ool00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03001oo`0002Yo
o`00@goo0P001Goo0P001Goo0P001goo00<007oo00005Goo00<007ooOol02Woo00<007ooOol01Woo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000=oo`04001oogoo
000FOol00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00@007ooOol001Eoo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003Ool01000Oomoo`00
5Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol017oo4@000Woo00L007ooOomoo`00Ool0
000ZOol004Aoo`8000Aoo`8000Eoo`8000Moool002d002Yoo`00AGoo0P000goo0P001Goo0P00ogoo
GWoo0016Ool01000Oomoogoo0P001Goo0P00ogooGWoo0016Ool20002Ool20005Ool2003oOomNOol0
04Ioo`80009oo`8000Eoo`800?mooeioo`00?goo0P001Goo0P000Woo0P001Goo0P00ogooGWoo0010
Ool20004Ool20003Ool20003Ool2003oOomOOol0041oo`L000Aoo`L008moo`D00<Yoo`00@Goo1@00
1Woo1@00SWoo2000bGoo003OOol20004Ool30038Ool00>Ioo`800<Qoo`00a7oo0P000goo0`000goo
0P0017oo10000Woo0P0017oo100000=oo`0000000Woo0P0017oo0P000Woo0P000goo0`000goo1000
00=oo`00000017oo100000=oo`00000017oo1@00UWoo0034Ool20003Ool30003Ool20003Ool80004
Ool80002Ool20004Ool20002Ool20002Ool40002Ool80003Ool80003Ool7002EOol00<Aoo`8000=o
o`<000=oo`8000=oo`8000=oo`<000Aoo`8000=oo`<0009oo`8000Aoo`80009oo`80009oo`8000Ao
o`8000=oo`<000=oo`8000=oo`<000=oo`8000Aoo`8009Aoo`00a7oo0P000Woo0P0000=oo`000000
0Woo0P000goo0P0017oo0P000goo0P001Goo0P000Woo0P0017oo0P000Woo0P000Woo0P0017oo0P00
17oo0P000Woo0P001Goo0P000Woo0P00Vgoo0034Ool20002Ool200000goo00000002Ool20003Ool4
0002Ool20003Ool20005Ool20002Ool20004Ool20002Ool20002Ool20004Ool20004Ool20002Ool2
0005Ool20002Ool2002KOol00<Aoo`80009oo`800003Ool00000009oo`8000Aoo`L000=oo`8000Eo
o`80009oo`8000Aoo`80009oo`80009oo`8000Aoo`8000Aoo`80009oo`8000Eoo`80009oo`T009Ao
o`00a7oo0P000Woo0P0000=oo`0000000Woo0P001goo10000goo0P001Goo0P000Woo0P0017oo0P00
0Woo0P000Woo0P0017oo0P0017oo0P000Woo0P001Goo0P000Woo2@00U7oo0034Ool200000goo0000
0003Ool200000goo00000009Ool20003Ool20005Ool20002Ool20004Ool20002Ool20002Ool20004
Ool20004Ool20002Ool20005Ool20002Ool20005Ool2002DOol00<Aoo`800003Ool0000000=oo`80
0003Ool0000000=oo`8000Aoo`8000Aoo`8000=oo`<0009oo`<000=oo`80009oo`80009oo`8000Ao
o`8000Aoo`8000=oo`8000=oo`<000=oo`8000=oo`8009Eoo`00a7oo0P0000=oo`0000000goo0P00
00=oo`0000000goo200017oo20000Woo20000Woo0P0000=oo`0000000`000Woo0P0017oo0P000goo
20000goo1`00UGoo0034Ool200000goo00000003Ool200000goo00000005Ool50006Ool400000goo
00000002Ool200000goo000000020003Ool200000goo000000030002Ool20004Ool20004Ool40000
0goo00000004Ool5002FOol00<Aoo`@000Eoo`@002Moo`8001Eoo`8009moo`00a7oo10001Goo1000
9goo0P005Goo0P00Wgoo0034Ool40005Ool4000SOol20002Ool2000EOol2002OOol00<Aoo`<000Mo
o`<002=oo`8001Uoo`8009moo`00ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.24887, -31.5297, \
0.0203262, 0.325443}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.253086 0.246914 0.0107871 0.00549112 [
[.00617 -0.0125 -10.9688 -16.375 ]
[.00617 -0.0125 10.9688 0 ]
[.25309 -0.0125 -5.59375 -16.375 ]
[.25309 -0.0125 5.59375 0 ]
[.5 -0.0125 -9.1875 -16.375 ]
[.5 -0.0125 9.1875 0 ]
[.74691 -0.0125 -12.7813 -16.375 ]
[.74691 -0.0125 12.7813 0 ]
[.99383 -0.0125 -16.375 -16.375 ]
[.99383 -0.0125 16.375 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -9.90625 -32.75 ]
[.5 -0.0125 9.90625 -16.375 ]
[-0.0125 .01079 -11.1875 -8.1875 ]
[-0.0125 .01079 0 8.1875 ]
[-0.0125 .12061 -18.375 -8.1875 ]
[-0.0125 .12061 0 8.1875 ]
[-0.0125 .23043 -18.375 -8.1875 ]
[-0.0125 .23043 0 8.1875 ]
[-0.0125 .34025 -18.375 -8.1875 ]
[-0.0125 .34025 0 8.1875 ]
[-0.0125 .45008 -18.375 -8.1875 ]
[-0.0125 .45008 0 8.1875 ]
[-0.0125 .5599 -25.5625 -8.1875 ]
[-0.0125 .5599 0 8.1875 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -41.9375 -22.125 ]
[-0.01875 .30902 -25.5625 22.125 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -20.3125 0 ]
[.5 .63053 20.3125 16.375 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
[ ] 0 setdash
.00617 0 m
.00617 .61803 L
s
.25309 0 m
.25309 .61803 L
s
.5 0 m
.5 .61803 L
s
.74691 0 m
.74691 .61803 L
s
.99383 0 m
.99383 .61803 L
s
.0805 0 m
.0805 .61803 L
s
.12398 0 m
.12398 .61803 L
s
.15483 0 m
.15483 .61803 L
s
.17876 0 m
.17876 .61803 L
s
.19831 0 m
.19831 .61803 L
s
.21484 0 m
.21484 .61803 L
s
.22916 0 m
.22916 .61803 L
s
.24179 0 m
.24179 .61803 L
s
.32741 0 m
.32741 .61803 L
s
.37089 0 m
.37089 .61803 L
s
.40174 0 m
.40174 .61803 L
s
.42567 0 m
.42567 .61803 L
s
.44522 0 m
.44522 .61803 L
s
.46175 0 m
.46175 .61803 L
s
.47607 0 m
.47607 .61803 L
s
.4887 0 m
.4887 .61803 L
s
.57433 0 m
.57433 .61803 L
s
.61781 0 m
.61781 .61803 L
s
.64866 0 m
.64866 .61803 L
s
.67259 0 m
.67259 .61803 L
s
.69214 0 m
.69214 .61803 L
s
.70867 0 m
.70867 .61803 L
s
.72299 0 m
.72299 .61803 L
s
.73562 0 m
.73562 .61803 L
s
.82124 0 m
.82124 .61803 L
s
.86472 0 m
.86472 .61803 L
s
.89557 0 m
.89557 .61803 L
s
.9195 0 m
.9195 .61803 L
s
.93905 0 m
.93905 .61803 L
s
.95558 0 m
.95558 .61803 L
s
.9699 0 m
.9699 .61803 L
s
.98253 0 m
.98253 .61803 L
s
0 .12061 m
1 .12061 L
s
0 .23043 m
1 .23043 L
s
0 .34025 m
1 .34025 L
s
0 .45008 m
1 .45008 L
s
0 .5599 m
1 .5599 L
s
0 g
.00617 0 m
.00617 .00625 L
s
gsave
.00617 -0.0125 -71.9688 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
80.938 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25309 0 m
.25309 .00625 L
s
gsave
.25309 -0.0125 -66.5938 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
70.188 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -70.1875 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
77.375 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.74691 0 m
.74691 .00625 L
s
gsave
.74691 -0.0125 -73.7813 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
84.563 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.99383 0 m
.99383 .00625 L
s
gsave
.99383 -0.0125 -77.375 -20.375 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
91.750 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.0805 0 m
.0805 .00375 L
s
.12398 0 m
.12398 .00375 L
s
.15483 0 m
.15483 .00375 L
s
.17876 0 m
.17876 .00375 L
s
.19831 0 m
.19831 .00375 L
s
.21484 0 m
.21484 .00375 L
s
.22916 0 m
.22916 .00375 L
s
.24179 0 m
.24179 .00375 L
s
.32741 0 m
.32741 .00375 L
s
.37089 0 m
.37089 .00375 L
s
.40174 0 m
.40174 .00375 L
s
.42567 0 m
.42567 .00375 L
s
.44522 0 m
.44522 .00375 L
s
.46175 0 m
.46175 .00375 L
s
.47607 0 m
.47607 .00375 L
s
.4887 0 m
.4887 .00375 L
s
.57433 0 m
.57433 .00375 L
s
.61781 0 m
.61781 .00375 L
s
.64866 0 m
.64866 .00375 L
s
.67259 0 m
.67259 .00375 L
s
.69214 0 m
.69214 .00375 L
s
.70867 0 m
.70867 .00375 L
s
.72299 0 m
.72299 .00375 L
s
.73562 0 m
.73562 .00375 L
s
.82124 0 m
.82124 .00375 L
s
.86472 0 m
.86472 .00375 L
s
.89557 0 m
.89557 .00375 L
s
.9195 0 m
.9195 .00375 L
s
.93905 0 m
.93905 .00375 L
s
.95558 0 m
.95558 .00375 L
s
.9699 0 m
.9699 .00375 L
s
.98253 0 m
.98253 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -70.9063 -36.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Hz) show
78.813 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01079 m
.00625 .01079 L
s
gsave
-0.0125 .01079 -72.1875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12061 m
.00625 .12061 L
s
gsave
-0.0125 .12061 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .23043 m
.00625 .23043 L
s
gsave
-0.0125 .23043 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .34025 m
.00625 .34025 L
s
gsave
-0.0125 .34025 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .45008 m
.00625 .45008 L
s
gsave
-0.0125 .45008 -79.375 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .5599 m
.00625 .5599 L
s
gsave
-0.0125 .5599 -86.5625 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03824 m
.00375 .03824 L
s
0 .0657 m
.00375 .0657 L
s
0 .09315 m
.00375 .09315 L
s
0 .14807 m
.00375 .14807 L
s
0 .17552 m
.00375 .17552 L
s
0 .20298 m
.00375 .20298 L
s
0 .25789 m
.00375 .25789 L
s
0 .28534 m
.00375 .28534 L
s
0 .3128 m
.00375 .3128 L
s
0 .36771 m
.00375 .36771 L
s
0 .39517 m
.00375 .39517 L
s
0 .42262 m
.00375 .42262 L
s
0 .47753 m
.00375 .47753 L
s
0 .50499 m
.00375 .50499 L
s
0 .53244 m
.00375 .53244 L
s
0 .58736 m
.00375 .58736 L
s
0 .61481 m
.00375 .61481 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -116.875 -12.1875 Mabsadd m
1 1 Mabs scale
currentpoint translate
83.125 12.1875 translate
90 rotate
-83.125 -12.1875 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(degree) show
103.250 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.00617 .61178 m
.00617 .61803 L
s
.25309 .61178 m
.25309 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.74691 .61178 m
.74691 .61803 L
s
.99383 .61178 m
.99383 .61803 L
s
.001 w
.0805 .61428 m
.0805 .61803 L
s
.12398 .61428 m
.12398 .61803 L
s
.15483 .61428 m
.15483 .61803 L
s
.17876 .61428 m
.17876 .61803 L
s
.19831 .61428 m
.19831 .61803 L
s
.21484 .61428 m
.21484 .61803 L
s
.22916 .61428 m
.22916 .61803 L
s
.24179 .61428 m
.24179 .61803 L
s
.32741 .61428 m
.32741 .61803 L
s
.37089 .61428 m
.37089 .61803 L
s
.40174 .61428 m
.40174 .61803 L
s
.42567 .61428 m
.42567 .61803 L
s
.44522 .61428 m
.44522 .61803 L
s
.46175 .61428 m
.46175 .61803 L
s
.47607 .61428 m
.47607 .61803 L
s
.4887 .61428 m
.4887 .61803 L
s
.57433 .61428 m
.57433 .61803 L
s
.61781 .61428 m
.61781 .61803 L
s
.64866 .61428 m
.64866 .61803 L
s
.67259 .61428 m
.67259 .61803 L
s
.69214 .61428 m
.69214 .61803 L
s
.70867 .61428 m
.70867 .61803 L
s
.72299 .61428 m
.72299 .61803 L
s
.73562 .61428 m
.73562 .61803 L
s
.82124 .61428 m
.82124 .61803 L
s
.86472 .61428 m
.86472 .61803 L
s
.89557 .61428 m
.89557 .61803 L
s
.9195 .61428 m
.9195 .61803 L
s
.93905 .61428 m
.93905 .61803 L
s
.95558 .61428 m
.95558 .61803 L
s
.9699 .61428 m
.9699 .61803 L
s
.98253 .61428 m
.98253 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
gsave
.5 .63053 -81.3125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 24.375 translate 1 -1 scale
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Phase) show
99.625 16.625 moveto
%%IncludeResource: font Helvetica
%%IncludeFont: Helvetica
/Helvetica findfont 13.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.00617 .01645 m
.03955 .01852 L
.06699 .02077 L
.08762 .02289 L
.1043 .02492 L
.11959 .02709 L
.1325 .02917 L
.14471 .03139 L
.15529 .03352 L
.16457 .03558 L
.17363 .03776 L
.18168 .03986 L
.1889 .04188 L
.19608 .04402 L
.20256 .04609 L
.20906 .04829 L
.21496 .0504 L
.22034 .05243 L
.22579 .05459 L
.23079 .05667 L
.23585 .05888 L
.24052 .06101 L
.24482 .06305 L
.24922 .06523 L
.25309 .06721 L
s
.25309 .06721 m
.28646 .08757 L
.31391 .10952 L
.33453 .12983 L
.35121 .14904 L
.3665 .1691 L
.37942 .18798 L
.39162 .20755 L
.4022 .22588 L
.41148 .24302 L
.42054 .26069 L
.4286 .27715 L
.43581 .29244 L
.44299 .30816 L
.44948 .32272 L
.45597 .33761 L
.46187 .35138 L
.46726 .36409 L
.4727 .37707 L
.4777 .38903 L
.48277 .40119 L
.48743 .41238 L
.49174 .42268 L
.49613 .43314 L
.5 .44227 L
s
.5 .44227 m
.53337 .51599 L
.56082 .56475 L
.57199 .58033 L
.58144 .59132 L
.59034 .59975 L
.59812 .60552 L
.60202 .60785 L
.6061 .60988 L
.60966 .6113 L
.61288 .61231 L
.61617 .61306 L
.61788 .61335 L
.61968 .61356 L
.62057 .61364 L
.62104 .61367 L
.62153 .6137 L
.62201 .61372 L
.62243 .61373 L
.62264 .61374 L
.62286 .61374 L
.62326 .61375 L
.62365 .61375 L
.62387 .61375 L
.62408 .61374 L
.62449 .61373 L
.62472 .61373 L
.62493 .61372 L
.62571 .61368 L
.62644 .61363 L
.62786 .6135 L
.62941 .61329 L
.631 .61302 L
.63247 .6127 L
.63777 .61112 L
.64049 .61002 L
.64328 .6087 L
.6481 .60596 L
.65739 .59905 L
.66647 .59026 L
.67454 .58082 L
.68249 .57006 L
.68964 .55925 L
.69609 .5486 L
.70255 .53714 L
.70843 .52608 L
.71379 .5155 L
.71921 .50435 L
.72419 .49378 L
.72924 .48275 L
Mistroke
.73389 .47236 L
.73818 .46259 L
.74256 .45246 L
.74662 .44297 L
.74691 .44227 L
Mfstroke
.74691 .44227 m
.78029 .3626 L
.80773 .29976 L
.82836 .25674 L
.84504 .2253 L
.86033 .19926 L
.87324 .17935 L
.88545 .16222 L
.89603 .14864 L
.90531 .13766 L
.91437 .12772 L
.92242 .11949 L
.92964 .11259 L
.93682 .10614 L
.9433 .10065 L
.9498 .09546 L
.9557 .091 L
.96108 .08712 L
.96653 .08339 L
.97153 .08012 L
.97659 .07695 L
.98126 .07416 L
.98556 .07169 L
.98996 .06927 L
.99383 .06721 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00hgoo0P001goo0P0000=oo`0000001`00
^7oo003SOol20007Ool200000goo00000007002hOol00>=oo`8000Moo`800004Ool00000002nOol0
0>=oo`8000Moo`80009oo`<00;eoo`00hgoo0P001goo0P000goo0`00_7oo003SOol20007Ool20004
Ool3002kOol00>=oo`8000Moo`8000Eoo`<00;Yoo`00hgoo2`001Woo0`00^Goo003SOol;0007Ool3
002hOol00>=oo`8000Moo`80009oo`P00;Qoo`00hgoo0P001goo0P000Woo2000^7oo003SOol20007
Ool20032Ool00>=oo`8000Moo`800<9oo`00hgoo0P001goo0P00`Woo003SOol20007Ool20032Ool0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00D7oo1@001Goo0P001goo0P00?goo0P00@Woo0P001goo1@00=goo
0P001goo1@001Woo1@00:goo0P001goo1@001Woo1@001Woo1@006goo001?Ool70004Ool20007Ool2
000oOol20012Ool20006Ool7000fOol20006Ool70004Ool7000ZOol20006Ool70004Ool70004Ool7
000JOol004moo`8000=oo`8000eoo`8003moo`80049oo`8000Ioo`8000=oo`8003Ioo`8000Ioo`80
00=oo`8000Aoo`8000=oo`8002Yoo`8000Ioo`8000=oo`8000Aoo`8000=oo`8000Aoo`8000=oo`80
01Yoo`00CWoo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=Goo0P001Goo0P00
1Goo0P000Woo0P001Goo0P00:Goo0P001Goo0P001Goo0P000Woo0P001Goo0P000Woo0P001Goo0P00
6Goo001>Ool20005Ool2000<Ool2000oOol20012Ool20005Ool20005Ool2000eOol20005Ool20005
Ool20002Ool20005Ool2000YOol20005Ool20005Ool20002Ool20005Ool20002Ool20005Ool2000I
Ool004ioo`8000Eoo`8000aoo`8003moo`80049oo`8000Eoo`8000Eoo`8003Eoo`8000Eoo`8000Eo
o`80009oo`8000Eoo`8002Uoo`8000Eoo`8000Eoo`80009oo`8000Eoo`80009oo`8000Eoo`8001Uo
o`00CWoo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=Goo0P001Goo0P001Goo
0P000Woo0P001Goo0P00:Goo0P001Goo0P001Goo0P000Woo0P001Goo0P000Woo0P001Goo0P006Goo
001>Ool20005Ool2000<Ool2000oOol20012Ool20005Ool20005Ool2000eOol20005Ool20005Ool2
0002Ool20005Ool2000YOol20005Ool20005Ool20002Ool20005Ool20002Ool20005Ool2000IOol0
04ioo`8000Eoo`8000aoo`8003moo`80049oo`8000Eoo`8000Eoo`8003Eoo`8000Eoo`8000Eoo`80
009oo`8000Eoo`8002Uoo`8000Eoo`8000Eoo`80009oo`8000Eoo`80009oo`8000Eoo`8001Uoo`00
CWoo0P001Goo0P0037oo0P00?goo0P00@Woo0P001Goo0P001Goo0P00=Goo0P001Goo0P001Goo0P00
0Woo0P001Goo0P00:Goo0P001Goo0P001Goo0P000Woo0P001Goo0P000Woo0P001Goo0P006Goo001>
Ool20005Ool20009Ool200000goo0000000lOol200000goo0000000oOol200000goo00000005Ool2
0005Ool2000bOol200000goo00000005Ool20005Ool20002Ool20005Ool2000VOol200000goo0000
0005Ool20005Ool20002Ool20005Ool20002Ool20005Ool2000IOol004ioo`8000Eoo`8000Uoo`D0
03aoo`D003moo`D000Eoo`8000Eoo`80039oo`D000Eoo`8000Eoo`80009oo`8000Eoo`8002Ioo`D0
00Eoo`8000Eoo`80009oo`8000Eoo`80009oo`8000Eoo`8001Uoo`00Cgoo0P000goo0P0037oo0`00
?Woo0`00@Goo0`001Woo0P000goo0P00=Goo0`001Woo0P000goo0P0017oo0P000goo0P00:Goo0`00
1Woo0P000goo0P0017oo0P000goo0P0017oo0P000goo0P006Woo001?Ool7000=Ool2000oOol20012
Ool20006Ool7000fOol20006Ool70004Ool7000ZOol20006Ool70004Ool70004Ool7000JOol0051o
o`D000ioo`8003moo`80049oo`8000Moo`D003Moo`8000Moo`D000Ioo`D002]oo`8000Moo`D000Io
o`D000Ioo`D001]oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo001:Ool5003oOomROol0
04Uoo`L00?moof5oo`00BGoo0P000goo0P0027ooo`00;@00;7oo0018Ool20005Ool20007Ool00`00
Ool0000FOol00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol001Eoo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol00004Ool01@00Oomoogoo00000Woo00<0
07ooOol04goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo01=oo`03001oogoo00Yoo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00003
Ool01P00Oomoo`00Ool002aoo`00B7oo0P001Goo0P001goo00<007oo00005Woo00<007ooOol02Woo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
00=oo`04001oogoo000EOol00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool01@00Oomoogoo000017oo00D007ooOomoo`00009oo`03001oogoo01=oo`03001oogoo00Yo
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0003Ool00`00Oomoo`0COol00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00H007ooOol007oo000/Ool0
04Qoo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo0018Ool20005Ool20007Ool3000F
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300mo
ogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`00B7oo0P001Goo0P001goo00<007oo000010004Woo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool004Qo
o`8000Eoo`8000Moo`03001oo`0?00Aoo`T000Uoo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo0018Ool20005Ool20007Ool0
0`00Ool03`0=Ool>0008Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1P0?Oomoo`0?Ool002aoo`00B7oo0P001Goo0P001goo00<007oo00l05Woo00<03gooOol00Woo1000
17oo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/
Ool004Qoo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Ioo`P000Eoo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`05
00moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo0019Ool20003Ool20008Ool00`00Ool0
3`0FOol00`0?Oomoo`0:Ool0100?Oomoogoo100000=oo`0?Ool01Goo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300mo
ogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00H03gooOol03goo000/Ool004Uoo`L000Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo
00Eoo`D000=oo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001:Ool50009Ool3000F
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0100?Oomoogoo1@0017oo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`04
00moo`000002Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?
Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00@03gooOomoo`@000=oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol0
0`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
1P0?Ool00000Ool03`=oo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?
009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0400moogooOol30002Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001H
Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Ool000020003Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00P0000Eo
o`0?Oomoo`0?01Eoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=o
o`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo
00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?009oo`<00003Ool03goo01Aoo`0300moogoo00Yoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo0`005Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moo`00
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?
01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`005Goo00<03gooOol02Woo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moo`00001oo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`80
01=oo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogoo
Ool03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?001oo`0?Ool002aoo`00F7oo00<007oo00l0
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool2000AOol00`0?Oomoo`0:Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`03
00moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00mo
o`<0009oo`0300moo`0002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo
00l4Ool00`00Oomoo`0>Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00l0009oo`0600moogoo00moo`00;7oo
001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`Eoo`8000ioo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?
Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0300moogoo008000=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03`Moo`8000aoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moo`00Ool03`03Ool01P0?Oomoo`0?
Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00l9Ool00`00Oomo
o`09Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Ool007oo00l00goo00H03gooOol03goo000/Ool005Qoo`<001Ioo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?2Woo00<007ooOol027oo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo0P000Woo00D03goo
Oomoo`0?009oo`0300moo`0002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00l;Ool20008Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`0200001@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qo
o`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?3Goo00<007ooOol01Goo00<03goo
Ool02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`05
00moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo0000
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000mOol90004Ool50009Ool00`00Ool0
3`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03`ioo`03001oogoo00Aoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo
00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300l007oo009oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00?Goo2@000goo1`0027oo00<007oo00l05Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00l?Ool20004Ool00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool20004Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000/Ool003ioo`8000Uoo`8000=oo`8000Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?4Goo00D007ooOomoo`0?00aoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0700moogooOol007oo00l017oo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000oOol2
0007Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03a9oo`04
001oogoo00l<Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0100?Oomoo`000Woo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo0010Ool20006Ool20005Ool2
0007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03a=oo`03001oo`0?00aoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo
00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moo`0000=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00@Goo0P001Goo0P001Goo0P001goo00<007oo00l0
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lDOol00`0000moo`0;Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?001oo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo000/Ool0049oo`8000Aoo`8000Eoo`8000Moo`<005l03`0300003`0?0:h03`030000
3`0?01D03`03001oogoo02Yoo`00@goo0P000goo0P001Goo0P001goo00<007oo00l05Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?001oo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`00Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000/Ool004Aoo`04001oogooOol20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moo`0000Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=o
o`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00=oo`03
00003goo00Aoo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00A7oo
0P000Woo0P001Goo0P001goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
100?Oomoo`002Goo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol00Woo00<007oo00l01Goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo0014Ool20002Ool20005Ool2
0007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0500moogooOol00008
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03goo
Oomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool01@0?Oomoogoo00000Woo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000mOol20005Ool20002Ool20005Ool2
0007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0500moogooOol00008
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03goo
Oomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool0100?Oomoo`000goo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000nOol20004Ool20003Ool20003Ool20008
Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo009oo`03001o
ogoo00Eoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool0
1@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moo`0000Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00?Woo1`0017oo1`0027oo00<007oo
00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`03Ool00`00Oomoo`04Ool0
0`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomo
o`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?001oo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000/Ool003moo`D000Ioo`D000Uoo`<001Ioo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol017oo00<007ooOol00goo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<007ooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Eoo`03001oogoo009oo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=o
o`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Eoo`0300003goo00Eoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo
00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`06Ool01@00Oomo
ogoo00l02Goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol0
3`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol017oo00<007oo00l01Woo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Ioo`05001oogooOol03`09Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`04Ool00`00Ool03`06
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool0
05Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol01goo00@0
07ooOol03`Uoo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo
00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00=oo`04001oogoo00l6Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol027oo00<007oo00l02Goo00<03gooOol017oo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol00Woo00D007ooOomoo`0?
00Ioo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002ao
o`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`09Ool0
0`0000moo`08Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomo
o`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?
Oomoo`0:Ool01@0?Oomoogoo000017oo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03001oogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0500moogooOol00004Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000/Ool005Qoo`<001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
07ooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol0
3`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00@03gooOol000Eoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?001oo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Ool00006Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qo
o`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
00001goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03`00Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moo`0000Moo`0300moogoo00Aoo`0300moogoo00=oo`05
00moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300l007oo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<0
07oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool0100?Oomoo`00
1Woo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo
00<007ooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03goo
Ool03aEoo`0300moogoo00Yoo`0500moogooOol00005Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`00Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03
001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00D03gooOomo
o`0000Eoo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l0
0Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo
00Uoo`0300003goo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`09Ool00`0000moo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000/Ool005Qoo`<001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol00goo00D007ooOomoo`0?00Ioo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomo
ogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`03
00moogoo00Qoo`03001oo`0?00Qoo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`03Ool01@00Oomoogoo00l01Woo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol027oo00<007oo00l027oo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00
;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Aoo`04001oogoo00l6Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03goo
Oomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`07Ool01000Oomoo`0?27oo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo0012Ool20006Ool50009Ool00`00Ool03`0F
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Eoo`03001o
o`0?00Ioo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Ioo`05001oogoo
Ool03`08Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00H03gooOol03goo000/Ool001moo`D001ioo`8000Eoo`L000Qoo`03001oo`0?01Ioo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Goo00<007oo00l01Woo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol01Woo00D007ooOomoo`0?00Qoo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool002aoo`007Goo2@0077oo0P001Goo0P000goo0P0027oo00<007oo00l05Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0000moo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`05Ool00`00Oomoo`02Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000/Ool001aoo`<000Eoo`<001Eoo`X0009oo`8000Eoo`8000Moo`03001oo`0?01Ioo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<0000?Ool0
1Goo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol01Goo00<007ooOol00Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0600moogoo00moo`00;7oo000LOol20007Ool2000EOol:0002Ool20005Ool20007Ool00`00
Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Mo
o`03001oogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Aoo`03
001oogoo00=oo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo0P001goo0P005Goo0P0017oo0P0017oo
0P001Goo0P001goo0`00MP0?00<0000?00l0P00?00<0000?00l0;00?00<007ooOol0:Woo000LOol2
0007Ool2000FOol20003Ool20004Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300l007oo00Aoo`0300moogoo
00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00=oo`03001oogoo00Aoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool002aoo`007Goo0P001Goo0P0067oo0P000Woo0P0017oo0P001Goo0P001goo00<007oo00l0
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
001oo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo
01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`02Ool00`00Oomo
o`05Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo000/Ool001Qoo`l001Moo`80009oo`8000Aoo`8000Eoo`8000Mo
o`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03goo000017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
0Woo00<007ooOol01Goo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000HOol?000HOol200000goo00000004
Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300mo
ogoo00Yoo`0300moogoo00Moo`0300moo`0000Aoo`0300moogoo00=oo`0500moogooOol03`04Ool0
1@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo
01=oo`0500moogooOol00008Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool0041oo`@000Aoo`8000Eoo`80
00Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01goo00@03gooOol000=oo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo
00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0500mo
ogooOol00008Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool0045oo`<000Aoo`8000Eoo`8000Moo`03001o
o`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo
00@03gooOol000=oo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<0
3gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0400moogoo0009Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000/Ool001moo`D001eoo`<000Eoo`8000=oo`8000Qoo`03001oo`0?01Io
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00D03goo
Oomoo`00009oo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03goo
Ool04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0400moogoo0009Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00H03gooOol03goo000/Ool001eoo`T001aoo`8000Eoo`L000Qoo`03001oo`0?01Ioo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00D03gooOomoo`00009o
o`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moo`0000Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool002aoo`0077oo0`0000=oo`0000000Woo0`0077oo00<007ooOol017oo1@002Goo0`005Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`02
Ool00`00Ool03`05Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Ool0000:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo000/Ool001aoo`80009oo`8000=oo`80035oo`03001oo`0?01Ioo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol00goo00<0000?Ool017oo
00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol04goo00<03`00Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000LOol2
0002Ool20003Ool2000aOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Moo`0300moogoo00=oo`0300003goo00Aoo`0500moogooOol03`04
Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
ogoo01=oo`0300l007oo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo0P000Woo0P000goo0P00
<Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`00Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?
009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`00Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo000/Ool001aoo`<00003Ool0000000=oo`80035oo`03001oo`0?
01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<0
3gooOol017oo00<007ooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<007ooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogoo00moo`00;7oo000MOol50002Ool2000bOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300l007oo00=o
o`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moogoo019oo`0300003goo00]oo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`007goo
0`000Woo00<007ooOol0<Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?001oo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Oomoo`0BOol00`0000moo`0;Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol0
17oo00<03goo00000goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04Goo00<007oo00l037oo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00;7oo001HOol3000FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0300moo`0000=oo`0500moogooOol03`04Ool01@0?Oomo
ogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo015oo`03
001oo`0?00aoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`007goo1@0017oo0P00;Woo00<007oo00l05Woo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomo
o`04Ool0100?Oomoo`000Woo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol047oo00@007ooOol03`aoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`007Goo2@000Woo0P00;Woo00<007oo00l05Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0100?Oomoo`000Woo
00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol047oo00@007ooOol03`aoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo
0`001Goo0`000Woo0P00;Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0100?Oomoo`000Woo00D03gooOomoo`0?
00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3gooOol03goo00D007ooOomoo`0?00aoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo0P001goo0P00
0Woo0P00;Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool01`0?Oomoogoo001oo`0?00=oo`0300moogoo009oo`05
00moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol0
3goo00D007ooOomoo`0?00aoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo0P001goo0P000Woo0P00
;Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool01`0?Oomoogoo001oo`0?00=oo`0300moogoo009oo`0500moogoo
Ool03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol03goo00D0
07ooOomoo`0?00aoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo0P001goo0P000Woo0P00;Goo00<0
07oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0000moo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00ioo`03001o
ogoo009oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`007Goo0P001Goo0P000Woo0`00
;Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol0
0goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?
Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`02Ool00`0000moo`02Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00io
o`03001oogoo009oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo3P00;Woo0`00
5Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?
Oomoo`04Ool00`0?Oomoo`02Ool00`0000moo`02Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00Woo
00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00eoo`03001oogoo00=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo3@00;goo00<007oo00l05Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool01@00Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0=Ool00`00Oomoo`03Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D007oo
Oomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol037oo00<007ooOol017oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo
0010Ool40006Ool50009Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`03
00moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500l007ooOol03`04
Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
ogoo00aoo`03001oogoo00Aoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo2`00
5goo1`0017oo1`0027oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?001oogoo00l017oo
00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomo
o`0<Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool001aoo`/001Mo
o`8000=oo`8000Aoo`8000=oo`8000Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomo
o`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03goo
001oo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03gooOol02goo00<007ooOol01Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo
000MOol2000NOol20005Ool20002Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0500moo`00Ool03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moogoo00]oo`03001oogoo00Eoo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool002aoo`0077oo0P007goo0P001Goo0P000Woo0P001Goo0P001goo00<007oo00l05Woo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool01@0?Oomoo`0000l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0:Ool00`00Oomoo`06Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000/Ool001aoo`8001moo`8000Eoo`80009oo`8000Eoo`8000Moo`<008H0
3`0300003`0?06403`0300003`0?03/03`03001oogoo02Yoo`0077oo0P007goo0P001Goo0P000Woo
0P001Goo0P001goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomo
o`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo000017oo00D0
3gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Ao
o`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0:
Ool00`00Oomoo`06Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003eoo`<000=oo`<0
009oo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0000Ao
o`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
Ool02Goo00<007ooOol01goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000OOol5000I
Ool80003Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0600moogooOol0
3`000goo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`09Ool00`00Oomoo`07Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool001eo
o`T001Moo`800003Ool00000008000Aoo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Yo
o`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol0
3`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03goo
Ool00goo00H03gooOomoo`0?0003Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo00Qoo`03001oogoo00Qoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`0077oo0`0000=oo`0000000Woo0`005Woo0P002Goo0P001Goo0P001goo00<0
07oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<0
3gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01P0?Oomoogoo00l000=oo`0500moogooOol03`02Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol027oo00<007ooOol027oo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000LOol20002Ool20003Ool2000GOol20004
Ool20002Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0700moogooOol0
3goo00000Woo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Oomoo`07Ool00`00Oomoo`09Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04
Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool0
01aoo`80009oo`8000=oo`8001Moo`8000=oo`<000=oo`8000=oo`8000Qoo`03001oo`0?01Ioo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol0
17oo00<03gooOol00goo00L03gooOomoo`0?Ool00002Ool01@0?Oomoogoo00l00Woo00<03gooOol0
4goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00Moo`03001oogoo00Uoo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool002aoo`0077oo0P000Woo0P000goo0P0067oo1P0017oo1`0027oo
0`005Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03goo
Ool00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool01`0?Oomoogoo00moo`00009oo`0500moogooOol03`02Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol01goo00<007ooOol02Goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000LOol300000goo00000003Ool2000IOol4
0006Ool50009Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`02Ool00`00
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo00Ioo`03
001oogoo00Yoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`007Goo1@000Woo0P00<Woo
00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo00<007oo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`06Ool00`00Oomoo`0:Ool0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool001moo`<0009oo`03001oogoo035oo`03001o
o`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300mo
ogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo
00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300003goo009oo`0400moogoo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol01Goo00<007ooOol02goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo
00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=o
o`0500moogooOol03`03Ool00`0000moo`02Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo00Eoo`03001oogoo00]oo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
02aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00<0000?
Ool00Woo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`04Ool00`00
Oomoo`0<Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool001moo`D003Aoo`03001oo`0?
01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<0
3gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`05001oogooOol03`02Ool00`0?Oomo
o`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol017oo00<007ooOol037oo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`00;7oo000MOol9000bOol00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01@00Oomoogoo00l00Woo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moogoo00Aoo`03001oogoo00aoo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`0077oo0`0000=oo`0000000Woo0`00<Goo00<007oo00l05Woo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l017oo00D03`00Oomoo`0?009oo`0300moogoo01=oo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Oomoo`03Ool00`00Oomoo`0=Ool00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo000/Ool001aoo`80009oo`8000=oo`80035oo`<001Ioo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo
00D03gooOomoo`0?00Aoo`0500l007ooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?
Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03gooOol00goo00<007ooOol03Goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00mo
o`00;7oo000LOol20002Ool20003Ool2000aOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`05
00moogooOol03`04Ool01@0?Ool007oo00l00Woo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moogoo009oo`03001oogoo00ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
02aoo`0077oo0P000Woo0P000goo0P00<Goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol0
1Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400mo
ogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l017oo00D03goo001oo`0?009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Oomoo`02Ool00`00Oomoo`0>Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/
Ool001aoo`<00003Ool0000000=oo`80035oo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0500moo`00Ool03`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03gooOol00Woo00<007ooOol03Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00
;7oo000MOol50002Ool2000bOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol0
3`04Ool01@0?Oomoo`0000l00Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`05
00moogooOol0000AOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool001moo`<0009oo`03
001oogoo035oo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol0
2Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500mo
ogoo00003`02Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00D03gooOomoo`00
015oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo
009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03gooOol0000?009oo`0300moogoo01=oo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool0100?Oomoo`004Woo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00mo
o`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?
Oomoogoo00000Woo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0400moogoo000B
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`<001Ioo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0500moogooOol00002Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03goo00004goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo
00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001H
Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool0200?Oomoogoo00l0
07oo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00004goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0600moogoo00moo`00;7oo000oOol50006Ool50009Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo
00=oo`0500moogooOol03`04Ool0200?Oomoogoo00l007oo00lEOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo00004goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000nOol70004
Ool70008Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool0200?Oomo
ogoo00moo`0000lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03`00Ool04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogoo00moo`00;7oo000mOol30003Ool30003Ool20003Ool20008Ool00`00Ool0
3`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool0200?Oomoogoo00moo`0000lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03`00Ool04goo00<03gooOol02Woo00<03gooOol01Woo
00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo
00moo`00;7oo000mOol20005Ool20002Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`03001oogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002ao
o`00?Goo0P001Goo0P000Woo0P001Goo0P001goo00<007oo00l05Woo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`04
00moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`03001oogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`00Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003eoo`80
00Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?
5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomo
o`0?00Aoo`0500moogooOol03`02Ool00`00Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00<0000?Ool057oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo
00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000mOol30003Ool30002
Ool20005Ool20007Ool3002D00l00`0000l03`1500l00`0000l03`1900l00`00Oomoo`0ZOol003io
o`L000=oo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300mo
ogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo
00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?
00Aoo`0500moogooOol03`02Ool00`0?001oo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoo`0?Ool007oo
00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003ioo`L000=oo`8000Eoo`8000Mo
o`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02
Ool00`0?Ool0000COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0200?Oomoo`0?Ool007oo00lEOol00`0?Oomoo`0:Ool0
0`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo000/Ool003eoo`<000=oo`<0009oo`8000Eoo`8000Moo`03001oo`0?01Io
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Ool0000C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool01@0?Oomoo`0?00000Woo00<03gooOol04goo00<03gooOol02Woo00<03goo
Ool01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`06
00moogoo00moo`00;7oo000mOol20005Ool20002Ool20005Ool20007Ool00`00Ool03`0FOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Ao
o`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00@03gooOol0019oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`03
00moogoo009oo`0500moogoo00l00002Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000/Ool003eoo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0100?Oomoo`004Woo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00<03goo
Ool00Woo00D03gooOol03`00009oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`03
00moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool002aoo`00?Goo0`000goo0`000goo0P000goo0P0027oo00<007oo00l05Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0500moogooOol0000AOol00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`000goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00
;7oo000nOol70004Ool70008Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEo
o`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol0
3`04Ool01@0?Oomoogoo00l00Woo00D03gooOomoo`00015oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo0003
Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003moo`D000Ioo`D0
00Uoo`<001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`02Ool00`00Oomoo`0>Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Ool0000?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol00Woo00<007ooOol0
3Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00@03goo00003`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOomoo`0?009oo`0300moogoo009oo`03001oogoo00ioo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400l0
07oo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03
001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`03Ool00`00Oomoo`0=Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?001oo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol00goo00<007ooOol0
3Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol0
0Woo00<03gooOol00Woo00@007ooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOomoo`0?009oo`0300moogoo00Aoo`03001oogoo00aoo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`04001o
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03
001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`04Ool00`00Oomoo`0<Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`9oo`0500moogooOol03`0EOol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`05Ool00`00Oomoo`0;Ool0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1P0?Oomoogoo00003`9oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
000/Ool005Qoo`<001Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo
00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<0
3gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol0
3`02Ool00`0?Oomoo`05Ool00`00Oomoo`0;Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomo
o`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool03`9oo`0500moogooOol03`0E
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo
00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<0
3gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`06Ool00`00Oomo
o`0:Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01P0?Oomoo`00Ool03`9oo`0500moogooOol03`0EOol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0500moogooOol03`02Ool00`0?Oomoo`06Ool00`00Oomoo`0:Ool00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?Ool00002Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00
Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<0
3gooOol01goo00<007ooOol02Goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00<03goo00000Woo00@03gooOol03`=oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo00Moo`03001oogoo00Uo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0300moo`00009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0500moogooOol03`02Ool00`0?Oomoo`08Ool00`00Oomoo`08Ool00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool00`0?001oo`02Ool0100?Oomo
o`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03goo
Ool00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00
Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Mo
o`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<0
3gooOol027oo00<007ooOol027oo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00<03`00Ool00Woo00@03gooOol03`=oo`0300moogoo01=oo`03
00moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo
00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?
00=oo`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo00Uoo`03001oogoo00Mo
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`03001oogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0500moogooOol03`02Ool00`0?Oomoo`09Ool00`00Oomoo`07Ool00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01P0?Oomoogoo00003`Aoo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`<001Ioo`0300mo
ogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo
00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0:Ool00`00
Oomoo`06Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01P0?
Oomoogoo00003`Aoo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06
Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo
00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<0
3gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Ao
o`0500moogooOol03`02Ool00`0?Oomoo`0:Ool00`00Oomoo`06Ool00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01P0?Oomoo`00Ool03`Aoo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003Ioo`8000Moo`D000Io
o`D000Uoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo
Ool03`02Ool00`0?Oomoo`0;Ool00`00Oomoo`05Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?
Oomoo`04Ool00`0?Oomoo`03Ool01P0?Oomoo`00Ool03`Aoo`0400moogoo00l3Ool00`0?Oomoo`0C
Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003Ioo`8000Ioo`L000Aoo`L000Qoo`03
001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`0<Ool00`00Oomoo`04Ool00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Ool00002Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo
00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo
00D03gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000fOol20006Ool20003Ool20004Ool20003
Ool20008Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yo
o`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomo
ogoo00l00Woo00<03gooOol037oo00<007ooOol017oo00<03gooOol02Woo00<03gooOol01Woo00<0
3gooOol017oo00<03gooOol00goo00<03goo00000Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00=Woo0P001Goo0P001Goo
0P000Woo0P001Goo0P001goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol0
0`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
17oo00D03gooOomoo`0?009oo`0300moogoo00eoo`03001oogoo00=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300l007oo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003Ioo`80
00Eoo`8000Eoo`80009oo`8000Eoo`8000Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?
Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D0
3gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0=Ool00`00Oomoo`03Ool00`0?Oomo
o`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?001oo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<03gooOol01Woo00<03goo
Ool017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0600moogoo00moo`00
;7oo000fOol20005Ool20005Ool20002Ool20005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:
Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo
00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300mo
ogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol03Woo00<007ooOol0
0Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<007ooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo
00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool002aoo`00=Woo0P001Goo0P001Goo0P000Woo0P001Goo0P001goo0`00Y00?00<0000?
00l09@0?00<0000?00l0F@0?00<007ooOol0:Woo000fOol20005Ool20005Ool20002Ool20005Ool2
0007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomo
o`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`03
00moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo
00l00Woo00<03gooOol03goo00D007ooOomoo`0?00aoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moogoo009oo`0300003goo00=oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003Ioo`8000Eoo`8000Eoo`80009oo`8000Eo
o`8000Moo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo
Ool03`02Ool00`0?Oomoo`0@Ool01000Oomoo`0?37oo00<03gooOol01Woo00<03gooOol017oo00L0
3gooOomoo`00Ool03`04Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`00;7oo000fOol20005Ool20005Ool20002Ool20005Ool20007
Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300mo
ogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l0
0Woo00<03gooOol047oo00@007ooOol03`aoo`0300moogoo00Ioo`0300moogoo00Aoo`0400moogoo
0002Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03goo
Ool02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`00;7oo000cOol200000goo00000005Ool20005Ool20002Ool2
0005Ool20007Ool00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo
00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?
Oomoogoo00l00Woo00<03gooOol04Goo00<007oo00l037oo00<03gooOol01Woo00<03gooOol017oo
00<03goo00000goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=o
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool002aoo`00<goo1@001Goo0P001Goo0P000Woo0P00
1Goo0P001goo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<0
3gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?Oomoo`0:
Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo00D03goo
Oomoo`0?009oo`0300moogoo015oo`03001oo`0?00aoo`0300moogoo00Ioo`0300moogoo00Aoo`03
00moo`0000=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol0
0`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool003Eoo`<000Ioo`8000=oo`8000Aoo`8000=o
o`8000Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo
00<03gooOol01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogoo
Ool03`02Ool00`0?Oomoo`0BOol00`0000moo`0;Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
001oo`03Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<0
3gooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`00;7oo000fOol20006Ool70004Ool70008Ool00`00Ool0
3`0FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomo
o`02Ool01@0?Oomoogoo00l00goo00@03gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`03
00moogoo00Aoo`0300moogoo00=oo`0500moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03goo
Ool04goo00<007ooOol02Woo00<03gooOol01Woo00<03gooOol017oo00<007ooOol00goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300mo
ogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool0
1P0?Oomoo`0?Ool002aoo`00=Woo0P001goo1@001Woo1@002Goo0`005Woo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0400moogoo00lEOol00`0?Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l017oo00D03gooOomoo`0?009oo`0300moogoo01=oo`0300l007oo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`03001oogoo00=oo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool0
0`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qo
o`03001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=o
o`0300moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03goo
Ool01goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02
Ool00`0?Oomoo`0COol00`0?Ool0000:Ool00`0?Oomoo`06Ool00`0?Oomoo`03Ool00`0000moo`04
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol0
2Woo00<03gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomo
o`0?00=oo`0600moogoo00moo`00;7oo001HOol00`00Ool03`0FOol00`0?Oomoo`0:Ool00`0?Oomo
o`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@0
3gooOol03aEoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`05
00moogooOol03`04Ool01@0?Oomoogoo00l00Woo00<03gooOol04goo00@03gooOol000Uoo`0300mo
ogoo00Ioo`0300moogoo009oo`03001oo`0?00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?
Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03
001oo`0?01Ioo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`03
00moogoo009oo`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol0
1goo00<03gooOol017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool0
0`0?Oomoo`0COol01@0?Oomoogoo000027oo00<03gooOol01Woo00D03gooOomoo`00009oo`0300mo
ogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Oomoo`0COol00`0?
Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Ioo`0300moogoo00Yoo`03
00moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03
Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03gooOol017oo00<03gooOol0
0goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0COol00`0?Oomoo`02Ool0
0`00Oomoo`05Ool00`0?Oomoo`06Ool0100?Oomoo`000goo00<03gooOol00goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moogoo01=oo`0300moogoo00Yoo`0300moogoo00Io
o`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool002aoo`00F7oo00<007oo00l05Woo00<03gooOol02Woo00<03gooOol01Woo00<03gooOol0
17oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=oo`0400moogoo00lEOol00`0?
Oomoo`0:Ool00`0?Oomoo`07Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l017oo
00D03gooOomoo`0?009oo`0300moogoo01=oo`0300moogoo00=oo`8000Eoo`0300moogoo00Ioo`03
00l0000000Aoo`0300moogoo00=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Oomoo`0COol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool00`0?Oomoo`04Ool00`0?Oomoo`03Ool0
0`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00H03gooOol03goo000/Ool005Qoo`03001oo`0?01Io
o`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300moogoo00=oo`0300moogoo009o
o`0500moogooOol03`03Ool0100?Oomoo`0?5Goo00<03gooOol02Woo00<03gooOol01goo00<03goo
Ool017oo00<03gooOol00goo00D03gooOomoo`0?00Aoo`0500moogooOol03`02Ool00`0?Oomoo`0C
Ool00`0?Oomoo`05Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool20006Ool00`0?Oomoo`03Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03gooOol04goo00<03gooOol02Woo00<0
3gooOol01Woo00<03gooOol017oo00<03gooOol00goo00<03gooOol00Woo00D03gooOomoo`0?00=o
o`0600moogoo00moo`00;7oo001HOol00`00Ool0000FOol00`0?Oomoo`0:Ool00`0?Oomoo`06Ool0
0`0?Oomoo`04Ool00`0?Oomoo`03Ool00`0?Oomoo`02Ool01@0?Oomoogoo00l00goo00@03gooOol0
01Eoo`0300moogoo00Yoo`0300moogoo00Moo`0300moogoo00Aoo`0300moogoo00=oo`0500moogoo
Ool03`04Ool01@0?Oomoogoo00l00Woo00<007ooOol04goo00<03gooOol01Woo100000<03gooOol0
0goo0P0000=oo`0?Ool01Goo00<03gooOol00goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`03001oogoo01=oo`0300moogoo00Yoo`0300moogoo00Ioo`0300moogoo00Aoo`0300mo
ogoo00=oo`0300moogoo009oo`0500moogooOol03`03Ool01P0?Oomoo`00Ool002aoo`00F7oo0`00
5Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol0
0Woo00D007ooOomoo`0000=oo`04001oogoo000EOol00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00D007ooOomoo`00009oo`03001oogoo
01=oo`03001oogoo00Yoo`H000=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03
001oogoo009oo`04001oogoo0003Ool00`00Oomoo`0COol00`00Oomoo`0:Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00H007ooOol0
07oo000/Ool005Qoool002d002aoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003DOol2000:Ool20004Ool2
0003Ool40002Ool20004Ool40006Ool5002ZOol00=Aoo`8000Yoo`8000Aoo`80009oo`P000Aoo`H0
00Aoo`L00:Uoo`00e7oo0P002Woo0P0017oo0P000Woo0P000goo0`000goo0P0017oo0P000goo0P00
17oo0P00Z7oo003DOol2000:Ool20004Ool20002Ool20004Ool20009Ool20002Ool2002_Ool00=Ao
o`8000Yoo`8000Aoo`80009oo`@0009oo`8000Moo`@0009oo`800:moo`00e7oo0P002Woo0P0017oo
0P000goo1`0017oo1P000goo2@00Z7oo003DOol80004Ool20004Ool20006Ool40003Ool40006Ool9
002XOol00=Aoo`T000=oo`8000Aoo`8000Qoo`8000=oo`8000Qoo`8000Eoo`800:Qoo`00e7oo0P00
1Goo0`000Woo0`000goo0P000Woo0P0017oo0P000goo0P0017oo0P000goo0P000goo0P00ZGoo003D
Ool20006Ool20002Ool80002Ool80003Ool70004Ool7002YOol00=Aoo`8000Ioo`80009oo`800003
Ool00000008000Eoo`D000Ioo`@000Ioo`D00:Yoo`00e7oo0P001Woo0P000Woo0P00cWoo003DOol2
0005Ool30002Ool2003>Ool00=Aoo`T000=oo`800<ioo`00e7oo200017oo0P00cWoo003oOonaOol0
0?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2.23045, -34.1746, \
0.0203262, 0.913989}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1600}, {0, 1082}},
WindowSize->{780, 1029},
WindowMargins->{{354, Automatic}, {Automatic, -13}},
Magnification->1.5
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 69, 1, 42, "Input"],
Cell[1789, 52, 130, 2, 111, "Input"],

Cell[CellGroupData[{
Cell[1944, 58, 294, 6, 177, "Input"],
Cell[2241, 66, 158, 2, 58, "Output"]
}, Open  ]],
Cell[2414, 71, 2549, 44, 667, "Input"],

Cell[CellGroupData[{
Cell[4988, 119, 28, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[5041, 123, 427, 7, 180, "Input"],
Cell[5471, 132, 137, 2, 74, "Output"],
Cell[5611, 136, 220, 4, 35, "Print"],
Cell[5834, 142, 378, 9, 38, "Print"],
Cell[6215, 153, 490, 13, 51, "Print"],
Cell[6708, 168, 302, 6, 58, "Print"],
Cell[7013, 176, 264, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[7302, 184, 132379, 2405, 279, 15479, 957, "GraphicsData", "PostScript", \
"Graphics"],
Cell[139684, 2591, 130407, 2427, 279, 15982, 1010, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[270152, 5025, 27, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[270204, 5029, 427, 7, 180, "Input"],
Cell[270634, 5038, 86, 1, 71, "Output"],
Cell[270723, 5041, 358, 9, 38, "Print"],
Cell[271084, 5052, 240, 4, 35, "Print"],
Cell[271327, 5058, 490, 13, 51, "Print"],
Cell[271820, 5073, 302, 6, 58, "Print"],
Cell[272125, 5081, 1107, 29, 89, "Print"],
Cell[273235, 5112, 264, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[273524, 5120, 132275, 2404, 279, 15488, 958, "GraphicsData", \
"PostScript", "Graphics"],
Cell[405802, 7526, 130638, 2432, 279, 16079, 1013, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[536501, 9965, 28, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[536554, 9969, 517, 9, 201, "Input"],
Cell[537074, 9980, 89, 1, 65, "Output"],
Cell[537166, 9983, 303, 6, 35, "Print"],
Cell[537472, 9991, 244, 4, 35, "Print"],
Cell[537719, 9997, 313, 6, 35, "Print"],
Cell[538035, 10005, 307, 6, 35, "Print"],
Cell[538345, 10013, 295, 6, 35, "Print"],
Cell[538643, 10021, 286, 6, 35, "Print"],
Cell[538932, 10029, 224, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[539181, 10037, 121135, 2386, 279, 19321, 1124, "GraphicsData", \
"PostScript", "Graphics"],
Cell[660319, 12425, 122607, 2439, 279, 19820, 1165, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[782987, 14871, 30, 0, 79, "Section"],

Cell[CellGroupData[{
Cell[783042, 14875, 516, 9, 226, "Input"],
Cell[783561, 14886, 88, 1, 65, "Output"],
Cell[783652, 14889, 220, 4, 35, "Print"],
Cell[783875, 14895, 332, 7, 35, "Print"],
Cell[784210, 14904, 317, 6, 35, "Print"],
Cell[784530, 14912, 318, 7, 35, "Print"],
Cell[784851, 14921, 295, 6, 35, "Print"],
Cell[785149, 14929, 246, 4, 35, "Print"],
Cell[785398, 14935, 224, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[785647, 14943, 132463, 2406, 279, 15401, 956, "GraphicsData", \
"PostScript", "Graphics"],
Cell[918113, 17351, 130853, 2422, 279, 16006, 1000, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1049027, 19780, 35, 0, 79, "Section"],
Cell[1049065, 19782, 75, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[1049165, 19786, 639, 11, 282, "Input"],
Cell[1049807, 19799, 294, 5, 94, "Output"],
Cell[1050104, 19806, 111, 2, 43, "Output"],
Cell[1050218, 19810, 211, 4, 69, "Output"],
Cell[1050432, 19816, 107, 2, 43, "Output"],
Cell[1050542, 19820, 206, 3, 69, "Output"],
Cell[1050751, 19825, 106, 2, 57, "Output"],
Cell[1050860, 19829, 522, 8, 198, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1051419, 19842, 872, 17, 357, "Input"],
Cell[1052294, 19861, 262, 4, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1052593, 19870, 111, 2, 42, "Input"],
Cell[1052707, 19874, 105, 2, 41, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1052849, 19881, 551, 11, 201, "Input"],
Cell[1053403, 19894, 332, 6, 94, "Output"],
Cell[1053738, 19902, 293, 6, 35, "Print"],
Cell[1054034, 19910, 324, 7, 35, "Print"],
Cell[1054361, 19919, 480, 8, 35, "Print"],
Cell[1054844, 19929, 480, 9, 35, "Print"],
Cell[1055327, 19940, 295, 6, 35, "Print"],
Cell[1055625, 19948, 307, 6, 35, "Print"],
Cell[1055935, 19956, 224, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[1056184, 19964, 131437, 2420, 279, 15757, 987, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1187624, 22386, 133675, 2431, 279, 15690, 970, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1321360, 24824, 32, 0, 79, "Section"],
Cell[1321395, 24826, 75, 0, 47, "Text"],

Cell[CellGroupData[{
Cell[1321495, 24830, 639, 11, 282, "Input"],
Cell[1322137, 24843, 294, 5, 94, "Output"],
Cell[1322434, 24850, 111, 2, 43, "Output"],
Cell[1322548, 24854, 211, 4, 69, "Output"],
Cell[1322762, 24860, 107, 2, 43, "Output"],
Cell[1322872, 24864, 206, 3, 69, "Output"],
Cell[1323081, 24869, 106, 2, 57, "Output"],
Cell[1323190, 24873, 522, 8, 198, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1323749, 24886, 875, 17, 357, "Input"],
Cell[1324627, 24905, 263, 4, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1324927, 24914, 551, 11, 201, "Input"],
Cell[1325481, 24927, 332, 6, 94, "Output"],
Cell[1325816, 24935, 297, 6, 35, "Print"],
Cell[1326116, 24943, 250, 4, 35, "Print"],
Cell[1326369, 24949, 316, 6, 35, "Print"],
Cell[1326688, 24957, 318, 7, 35, "Print"],
Cell[1327009, 24966, 295, 6, 35, "Print"],
Cell[1327307, 24974, 318, 7, 35, "Print"],
Cell[1327628, 24983, 224, 4, 35, "Print"],

Cell[CellGroupData[{
Cell[1327877, 24991, 120044, 2362, 279, 18979, 1110, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1447924, 27355, 122528, 2437, 279, 19798, 1164, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

